# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cline/oca_account.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'cline/oca_account.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cline_core.proto.cline import common_pb2 as cline_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x63line/oca_account.proto\x12\x05\x63line\x1a\x12\x63line/common.proto\"`\n\x0cOcaAuthState\x12%\n\x04user\x18\x01 \x01(\x0b\x32\x12.cline.OcaUserInfoH\x00\x88\x01\x01\x12\x14\n\x07\x61pi_key\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x07\n\x05_userB\n\n\x08_api_key\"d\n\x0bOcaUserInfo\x12\x0b\n\x03uid\x18\x01 \x01(\t\x12\x19\n\x0c\x64isplay_name\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x12\n\x05\x65mail\x18\x03 \x01(\tH\x01\x88\x01\x01\x42\x0f\n\r_display_nameB\x08\n\x06_email2\xdd\x01\n\x11OcaAccountService\x12<\n\x16ocaAccountLoginClicked\x12\x13.cline.EmptyRequest\x1a\r.cline.String\x12<\n\x17ocaAccountLogoutClicked\x12\x13.cline.EmptyRequest\x1a\x0c.cline.Empty\x12L\n\x1eocaSubscribeToAuthStatusUpdate\x12\x13.cline.EmptyRequest\x1a\x13.cline.OcaAuthState0\x01\x42\x33\n\x0f\x62ot.cline.protoP\x01Z\x1egithub.com/cline/grpc-go/clineb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cline.oca_account_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017bot.cline.protoP\001Z\036github.com/cline/grpc-go/cline'
  _globals['_OCAAUTHSTATE']._serialized_start=54
  _globals['_OCAAUTHSTATE']._serialized_end=150
  _globals['_OCAUSERINFO']._serialized_start=152
  _globals['_OCAUSERINFO']._serialized_end=252
  _globals['_OCAACCOUNTSERVICE']._serialized_start=255
  _globals['_OCAACCOUNTSERVICE']._serialized_end=476
# @@protoc_insertion_point(module_scope)
