# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cline/dictation.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'cline/dictation.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cline_core.proto.cline import common_pb2 as cline_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x63line/dictation.proto\x12\x05\x63line\x1a\x12\x63line/common.proto\"@\n\x16TranscribeAudioRequest\x12\x14\n\x0c\x61udio_base64\x18\x02 \x01(\t\x12\x10\n\x08language\x18\x03 \x01(\t\"1\n\x0fRecordingResult\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\r\n\x05\x65rror\x18\x02 \x01(\t\"E\n\rRecordedAudio\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x14\n\x0c\x61udio_base64\x18\x02 \x01(\t\x12\r\n\x05\x65rror\x18\x03 \x01(\t\"P\n\x0fRecordingStatus\x12\x14\n\x0cis_recording\x18\x01 \x01(\x08\x12\x18\n\x10\x64uration_seconds\x18\x02 \x01(\x01\x12\r\n\x05\x65rror\x18\x03 \x01(\t\",\n\rTranscription\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\r\n\x05\x65rror\x18\x02 \x01(\t2\xd8\x02\n\x10\x44ictationService\x12=\n\x0estartRecording\x12\x13.cline.EmptyRequest\x1a\x16.cline.RecordingResult\x12:\n\rstopRecording\x12\x13.cline.EmptyRequest\x1a\x14.cline.RecordedAudio\x12>\n\x0f\x63\x61ncelRecording\x12\x13.cline.EmptyRequest\x1a\x16.cline.RecordingResult\x12\x41\n\x12getRecordingStatus\x12\x13.cline.EmptyRequest\x1a\x16.cline.RecordingStatus\x12\x46\n\x0ftranscribeAudio\x12\x1d.cline.TranscribeAudioRequest\x1a\x14.cline.TranscriptionB3\n\x0f\x62ot.cline.protoP\x01Z\x1egithub.com/cline/grpc-go/clineb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cline.dictation_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017bot.cline.protoP\001Z\036github.com/cline/grpc-go/cline'
  _globals['_TRANSCRIBEAUDIOREQUEST']._serialized_start=52
  _globals['_TRANSCRIBEAUDIOREQUEST']._serialized_end=116
  _globals['_RECORDINGRESULT']._serialized_start=118
  _globals['_RECORDINGRESULT']._serialized_end=167
  _globals['_RECORDEDAUDIO']._serialized_start=169
  _globals['_RECORDEDAUDIO']._serialized_end=238
  _globals['_RECORDINGSTATUS']._serialized_start=240
  _globals['_RECORDINGSTATUS']._serialized_end=320
  _globals['_TRANSCRIPTION']._serialized_start=322
  _globals['_TRANSCRIPTION']._serialized_end=366
  _globals['_DICTATIONSERVICE']._serialized_start=369
  _globals['_DICTATIONSERVICE']._serialized_end=713
# @@protoc_insertion_point(module_scope)
