# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: host/diff.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'host/diff.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cline_core.proto.cline import common_pb2 as cline_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0fhost/diff.proto\x12\x04host\x1a\x12\x63line/common.proto\"\x84\x01\n\x0fOpenDiffRequest\x12&\n\x08metadata\x18\x01 \x01(\x0b\x32\x0f.cline.MetadataH\x00\x88\x01\x01\x12\x11\n\x04path\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x14\n\x07\x63ontent\x18\x03 \x01(\tH\x02\x88\x01\x01\x42\x0b\n\t_metadataB\x07\n\x05_pathB\n\n\x08_content\"4\n\x10OpenDiffResponse\x12\x14\n\x07\x64iff_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\n\n\x08_diff_id\"o\n\x16GetDocumentTextRequest\x12&\n\x08metadata\x18\x01 \x01(\x0b\x32\x0f.cline.MetadataH\x00\x88\x01\x01\x12\x14\n\x07\x64iff_id\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x0b\n\t_metadataB\n\n\x08_diff_id\";\n\x17GetDocumentTextResponse\x12\x14\n\x07\x63ontent\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\n\n\x08_content\"\xd9\x01\n\x12ReplaceTextRequest\x12&\n\x08metadata\x18\x01 \x01(\x0b\x32\x0f.cline.MetadataH\x00\x88\x01\x01\x12\x14\n\x07\x64iff_id\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x14\n\x07\x63ontent\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x17\n\nstart_line\x18\x04 \x01(\x05H\x03\x88\x01\x01\x12\x15\n\x08\x65nd_line\x18\x05 \x01(\x05H\x04\x88\x01\x01\x42\x0b\n\t_metadataB\n\n\x08_diff_idB\n\n\x08_contentB\r\n\x0b_start_lineB\x0b\n\t_end_line\"\x15\n\x13ReplaceTextResponse\"Q\n\x11ScrollDiffRequest\x12\x14\n\x07\x64iff_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x11\n\x04line\x18\x02 \x01(\x05H\x01\x88\x01\x01\x42\n\n\x08_diff_idB\x07\n\x05_line\"\x14\n\x12ScrollDiffResponse\"\x94\x01\n\x17TruncateDocumentRequest\x12&\n\x08metadata\x18\x01 \x01(\x0b\x32\x0f.cline.MetadataH\x00\x88\x01\x01\x12\x14\n\x07\x64iff_id\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x15\n\x08\x65nd_line\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\x0b\n\t_metadataB\n\n\x08_diff_idB\x0b\n\t_end_line\"\x1a\n\x18TruncateDocumentResponse\"\x16\n\x14\x43loseAllDiffsRequest\"\x17\n\x15\x43loseAllDiffsResponse\"l\n\x13SaveDocumentRequest\x12&\n\x08metadata\x18\x01 \x01(\x0b\x32\x0f.cline.MetadataH\x00\x88\x01\x01\x12\x14\n\x07\x64iff_id\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x0b\n\t_metadataB\n\n\x08_diff_id\"\x16\n\x14SaveDocumentResponse\"Z\n\x18OpenMultiFileDiffRequest\x12\x12\n\x05title\x18\x01 \x01(\tH\x00\x88\x01\x01\x12 \n\x05\x64iffs\x18\x02 \x03(\x0b\x32\x11.host.ContentDiffB\x08\n\x06_title\"\x8d\x01\n\x0b\x43ontentDiff\x12\x16\n\tfile_path\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x19\n\x0cleft_content\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x1a\n\rright_content\x18\x03 \x01(\tH\x02\x88\x01\x01\x42\x0c\n\n_file_pathB\x0f\n\r_left_contentB\x10\n\x0e_right_content\"\x1b\n\x19OpenMultiFileDiffResponse2\xd7\x04\n\x0b\x44iffService\x12\x39\n\x08openDiff\x12\x15.host.OpenDiffRequest\x1a\x16.host.OpenDiffResponse\x12N\n\x0fgetDocumentText\x12\x1c.host.GetDocumentTextRequest\x1a\x1d.host.GetDocumentTextResponse\x12\x42\n\x0breplaceText\x12\x18.host.ReplaceTextRequest\x1a\x19.host.ReplaceTextResponse\x12?\n\nscrollDiff\x12\x17.host.ScrollDiffRequest\x1a\x18.host.ScrollDiffResponse\x12Q\n\x10truncateDocument\x12\x1d.host.TruncateDocumentRequest\x1a\x1e.host.TruncateDocumentResponse\x12\x45\n\x0csaveDocument\x12\x19.host.SaveDocumentRequest\x1a\x1a.host.SaveDocumentResponse\x12H\n\rcloseAllDiffs\x12\x1a.host.CloseAllDiffsRequest\x1a\x1b.host.CloseAllDiffsResponse\x12T\n\x11openMultiFileDiff\x12\x1e.host.OpenMultiFileDiffRequest\x1a\x1f.host.OpenMultiFileDiffResponseB7\n\x14\x62ot.cline.host.protoP\x01Z\x1dgithub.com/cline/grpc-go/hostb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'host.diff_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\024bot.cline.host.protoP\001Z\035github.com/cline/grpc-go/host'
  _globals['_OPENDIFFREQUEST']._serialized_start=46
  _globals['_OPENDIFFREQUEST']._serialized_end=178
  _globals['_OPENDIFFRESPONSE']._serialized_start=180
  _globals['_OPENDIFFRESPONSE']._serialized_end=232
  _globals['_GETDOCUMENTTEXTREQUEST']._serialized_start=234
  _globals['_GETDOCUMENTTEXTREQUEST']._serialized_end=345
  _globals['_GETDOCUMENTTEXTRESPONSE']._serialized_start=347
  _globals['_GETDOCUMENTTEXTRESPONSE']._serialized_end=406
  _globals['_REPLACETEXTREQUEST']._serialized_start=409
  _globals['_REPLACETEXTREQUEST']._serialized_end=626
  _globals['_REPLACETEXTRESPONSE']._serialized_start=628
  _globals['_REPLACETEXTRESPONSE']._serialized_end=649
  _globals['_SCROLLDIFFREQUEST']._serialized_start=651
  _globals['_SCROLLDIFFREQUEST']._serialized_end=732
  _globals['_SCROLLDIFFRESPONSE']._serialized_start=734
  _globals['_SCROLLDIFFRESPONSE']._serialized_end=754
  _globals['_TRUNCATEDOCUMENTREQUEST']._serialized_start=757
  _globals['_TRUNCATEDOCUMENTREQUEST']._serialized_end=905
  _globals['_TRUNCATEDOCUMENTRESPONSE']._serialized_start=907
  _globals['_TRUNCATEDOCUMENTRESPONSE']._serialized_end=933
  _globals['_CLOSEALLDIFFSREQUEST']._serialized_start=935
  _globals['_CLOSEALLDIFFSREQUEST']._serialized_end=957
  _globals['_CLOSEALLDIFFSRESPONSE']._serialized_start=959
  _globals['_CLOSEALLDIFFSRESPONSE']._serialized_end=982
  _globals['_SAVEDOCUMENTREQUEST']._serialized_start=984
  _globals['_SAVEDOCUMENTREQUEST']._serialized_end=1092
  _globals['_SAVEDOCUMENTRESPONSE']._serialized_start=1094
  _globals['_SAVEDOCUMENTRESPONSE']._serialized_end=1116
  _globals['_OPENMULTIFILEDIFFREQUEST']._serialized_start=1118
  _globals['_OPENMULTIFILEDIFFREQUEST']._serialized_end=1208
  _globals['_CONTENTDIFF']._serialized_start=1211
  _globals['_CONTENTDIFF']._serialized_end=1352
  _globals['_OPENMULTIFILEDIFFRESPONSE']._serialized_start=1354
  _globals['_OPENMULTIFILEDIFFRESPONSE']._serialized_end=1381
  _globals['_DIFFSERVICE']._serialized_start=1384
  _globals['_DIFFSERVICE']._serialized_end=1983
# @@protoc_insertion_point(module_scope)
