# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cline/account.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'cline/account.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cline_core.proto.cline import common_pb2 as cline_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13\x63line/account.proto\x12\x05\x63line\x1a\x12\x63line/common.proto\"[\n\x17\x41uthStateChangedRequest\x12!\n\x08metadata\x18\x01 \x01(\x0b\x32\x0f.cline.Metadata\x12\x1d\n\x04user\x18\x02 \x01(\x0b\x32\x0f.cline.UserInfo\"8\n\tAuthState\x12\"\n\x04user\x18\x01 \x01(\x0b\x32\x0f.cline.UserInfoH\x00\x88\x01\x01\x42\x07\n\x05_user\"\xb3\x01\n\x08UserInfo\x12\x0b\n\x03uid\x18\x01 \x01(\t\x12\x19\n\x0c\x64isplay_name\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x12\n\x05\x65mail\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x16\n\tphoto_url\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x19\n\x0c\x61pp_base_url\x18\x05 \x01(\tH\x03\x88\x01\x01\x42\x0f\n\r_display_nameB\x08\n\x06_emailB\x0c\n\n_photo_urlB\x0f\n\r_app_base_url\"k\n\x10UserOrganization\x12\x0e\n\x06\x61\x63tive\x18\x01 \x01(\x08\x12\x11\n\tmember_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x17\n\x0forganization_id\x18\x04 \x01(\t\x12\r\n\x05roles\x18\x05 \x03(\t\"K\n\x19UserOrganizationsResponse\x12.\n\rorganizations\x18\x01 \x03(\x0b\x32\x17.cline.UserOrganization\"Q\n\x1dUserOrganizationUpdateRequest\x12\x1c\n\x0forganization_id\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x12\n\x10_organization_id\"\xab\x01\n\x0fUserCreditsData\x12*\n\x07\x62\x61lance\x18\x01 \x01(\x0b\x32\x19.cline.UserCreditsBalance\x12\x33\n\x12usage_transactions\x18\x02 \x03(\x0b\x32\x17.cline.UsageTransaction\x12\x37\n\x14payment_transactions\x18\x03 \x03(\x0b\x32\x19.cline.PaymentTransaction\"8\n\x1dGetOrganizationCreditsRequest\x12\x17\n\x0forganization_id\x18\x01 \x01(\t\"\x9f\x01\n\x17OrganizationCreditsData\x12*\n\x07\x62\x61lance\x18\x01 \x01(\x0b\x32\x19.cline.UserCreditsBalance\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\x12?\n\x12usage_transactions\x18\x03 \x03(\x0b\x32#.cline.OrganizationUsageTransaction\"-\n\x12UserCreditsBalance\x12\x17\n\x0f\x63urrent_balance\x18\x01 \x01(\x01\"\xae\x02\n\x10UsageTransaction\x12\"\n\x1a\x61i_inference_provider_name\x18\x01 \x01(\t\x12\x15\n\rai_model_name\x18\x02 \x01(\t\x12\x1a\n\x12\x61i_model_type_name\x18\x03 \x01(\t\x12\x19\n\x11\x63ompletion_tokens\x18\x04 \x01(\x05\x12\x10\n\x08\x63ost_usd\x18\x05 \x01(\x01\x12\x12\n\ncreated_at\x18\x06 \x01(\t\x12\x14\n\x0c\x63redits_used\x18\x07 \x01(\x01\x12\x15\n\rgeneration_id\x18\x08 \x01(\t\x12\x17\n\x0forganization_id\x18\t \x01(\t\x12\x15\n\rprompt_tokens\x18\n \x01(\x05\x12\x14\n\x0ctotal_tokens\x18\x0b \x01(\x05\x12\x0f\n\x07user_id\x18\x0c \x01(\t\"`\n\x12PaymentTransaction\x12\x0f\n\x07paid_at\x18\x01 \x01(\t\x12\x12\n\ncreator_id\x18\x02 \x01(\t\x12\x14\n\x0c\x61mount_cents\x18\x03 \x01(\x05\x12\x0f\n\x07\x63redits\x18\x04 \x01(\x01\"\xba\x02\n\x1cOrganizationUsageTransaction\x12\"\n\x1a\x61i_inference_provider_name\x18\x01 \x01(\t\x12\x15\n\rai_model_name\x18\x02 \x01(\t\x12\x1a\n\x12\x61i_model_type_name\x18\x03 \x01(\t\x12\x19\n\x11\x63ompletion_tokens\x18\x04 \x01(\x05\x12\x10\n\x08\x63ost_usd\x18\x05 \x01(\x01\x12\x12\n\ncreated_at\x18\x06 \x01(\t\x12\x14\n\x0c\x63redits_used\x18\x07 \x01(\x01\x12\x15\n\rgeneration_id\x18\x08 \x01(\t\x12\x17\n\x0forganization_id\x18\t \x01(\t\x12\x15\n\rprompt_tokens\x18\n \x01(\x05\x12\x14\n\x0ctotal_tokens\x18\x0b \x01(\x05\x12\x0f\n\x07user_id\x18\x0c \x01(\t2\xfa\x05\n\x0e\x41\x63\x63ountService\x12\x39\n\x13\x61\x63\x63ountLoginClicked\x12\x13.cline.EmptyRequest\x1a\r.cline.String\x12\x39\n\x14\x61\x63\x63ountLogoutClicked\x12\x13.cline.EmptyRequest\x1a\x0c.cline.Empty\x12\x46\n\x1bsubscribeToAuthStatusUpdate\x12\x13.cline.EmptyRequest\x1a\x10.cline.AuthState0\x01\x12\x44\n\x10\x61uthStateChanged\x12\x1e.cline.AuthStateChangedRequest\x1a\x10.cline.AuthState\x12=\n\x0egetUserCredits\x12\x13.cline.EmptyRequest\x1a\x16.cline.UserCreditsData\x12^\n\x16getOrganizationCredits\x12$.cline.GetOrganizationCreditsRequest\x1a\x1e.cline.OrganizationCreditsData\x12M\n\x14getUserOrganizations\x12\x13.cline.EmptyRequest\x1a .cline.UserOrganizationsResponse\x12I\n\x13setUserOrganization\x12$.cline.UserOrganizationUpdateRequest\x1a\x0c.cline.Empty\x12:\n\x15openrouterAuthClicked\x12\x13.cline.EmptyRequest\x1a\x0c.cline.Empty\x12\x39\n\x13requestyAuthClicked\x12\x14.cline.StringRequest\x1a\x0c.cline.Empty\x12\x34\n\x0egetRedirectUrl\x12\x13.cline.EmptyRequest\x1a\r.cline.StringB3\n\x0f\x62ot.cline.protoP\x01Z\x1egithub.com/cline/grpc-go/clineb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cline.account_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017bot.cline.protoP\001Z\036github.com/cline/grpc-go/cline'
  _globals['_AUTHSTATECHANGEDREQUEST']._serialized_start=50
  _globals['_AUTHSTATECHANGEDREQUEST']._serialized_end=141
  _globals['_AUTHSTATE']._serialized_start=143
  _globals['_AUTHSTATE']._serialized_end=199
  _globals['_USERINFO']._serialized_start=202
  _globals['_USERINFO']._serialized_end=381
  _globals['_USERORGANIZATION']._serialized_start=383
  _globals['_USERORGANIZATION']._serialized_end=490
  _globals['_USERORGANIZATIONSRESPONSE']._serialized_start=492
  _globals['_USERORGANIZATIONSRESPONSE']._serialized_end=567
  _globals['_USERORGANIZATIONUPDATEREQUEST']._serialized_start=569
  _globals['_USERORGANIZATIONUPDATEREQUEST']._serialized_end=650
  _globals['_USERCREDITSDATA']._serialized_start=653
  _globals['_USERCREDITSDATA']._serialized_end=824
  _globals['_GETORGANIZATIONCREDITSREQUEST']._serialized_start=826
  _globals['_GETORGANIZATIONCREDITSREQUEST']._serialized_end=882
  _globals['_ORGANIZATIONCREDITSDATA']._serialized_start=885
  _globals['_ORGANIZATIONCREDITSDATA']._serialized_end=1044
  _globals['_USERCREDITSBALANCE']._serialized_start=1046
  _globals['_USERCREDITSBALANCE']._serialized_end=1091
  _globals['_USAGETRANSACTION']._serialized_start=1094
  _globals['_USAGETRANSACTION']._serialized_end=1396
  _globals['_PAYMENTTRANSACTION']._serialized_start=1398
  _globals['_PAYMENTTRANSACTION']._serialized_end=1494
  _globals['_ORGANIZATIONUSAGETRANSACTION']._serialized_start=1497
  _globals['_ORGANIZATIONUSAGETRANSACTION']._serialized_end=1811
  _globals['_ACCOUNTSERVICE']._serialized_start=1814
  _globals['_ACCOUNTSERVICE']._serialized_end=2576
# @@protoc_insertion_point(module_scope)
