# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: host/window.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'host/window.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11host/window.proto\x12\x04host\"h\n\x17ShowTextDocumentRequest\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x33\n\x07options\x18\x03 \x01(\x0b\x32\x1d.host.ShowTextDocumentOptionsH\x00\x88\x01\x01\x42\n\n\x08_options\"\x95\x01\n\x17ShowTextDocumentOptions\x12\x14\n\x07preview\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x1b\n\x0epreserve_focus\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x18\n\x0bview_column\x18\x03 \x01(\x05H\x02\x88\x01\x01\x42\n\n\x08_previewB\x11\n\x0f_preserve_focusB\x0e\n\x0c_view_column\"d\n\x0eTextEditorInfo\x12\x15\n\rdocument_path\x18\x01 \x01(\t\x12\x18\n\x0bview_column\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\tis_active\x18\x03 \x01(\x08\x42\x0e\n\x0c_view_column\"\xb9\x01\n\x17ShowOpenDialogueRequest\x12\x1c\n\x0f\x63\x61n_select_many\x18\x02 \x01(\x08H\x00\x88\x01\x01\x12\x17\n\nopen_label\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x38\n\x07\x66ilters\x18\x04 \x01(\x0b\x32\".host.ShowOpenDialogueFilterOptionH\x02\x88\x01\x01\x42\x12\n\x10_can_select_manyB\r\n\x0b_open_labelB\n\n\x08_filters\"-\n\x1cShowOpenDialogueFilterOption\x12\r\n\x05\x66iles\x18\x01 \x03(\t\"\"\n\x11SelectedResources\x12\r\n\x05paths\x18\x01 \x03(\t\"\x8d\x01\n\x12ShowMessageRequest\x12#\n\x04type\x18\x01 \x01(\x0e\x32\x15.host.ShowMessageType\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x35\n\x07options\x18\x03 \x01(\x0b\x32\x1f.host.ShowMessageRequestOptionsH\x00\x88\x01\x01\x42\n\n\x08_options\"h\n\x19ShowMessageRequestOptions\x12\r\n\x05items\x18\x01 \x03(\t\x12\x12\n\x05modal\x18\x02 \x01(\x08H\x00\x88\x01\x01\x12\x13\n\x06\x64\x65tail\x18\x03 \x01(\tH\x01\x88\x01\x01\x42\x08\n\x06_modalB\t\n\x07_detail\"D\n\x10SelectedResponse\x12\x1c\n\x0fselected_option\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x12\n\x10_selected_option\"V\n\x15ShowSaveDialogRequest\x12\x31\n\x07options\x18\x01 \x01(\x0b\x32\x1b.host.ShowSaveDialogOptionsH\x00\x88\x01\x01\x42\n\n\x08_options\"\xc7\x01\n\x15ShowSaveDialogOptions\x12\x19\n\x0c\x64\x65\x66\x61ult_path\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x39\n\x07\x66ilters\x18\x02 \x03(\x0b\x32(.host.ShowSaveDialogOptions.FiltersEntry\x1aG\n\x0c\x46iltersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12&\n\x05value\x18\x02 \x01(\x0b\x32\x17.host.FileExtensionList:\x02\x38\x01\x42\x0f\n\r_default_path\"\'\n\x11\x46ileExtensionList\x12\x12\n\nextensions\x18\x01 \x03(\t\"F\n\x16ShowSaveDialogResponse\x12\x1a\n\rselected_path\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x10\n\x0e_selected_path\"b\n\x13ShowInputBoxRequest\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x06prompt\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x12\n\x05value\x18\x03 \x01(\tH\x01\x88\x01\x01\x42\t\n\x07_promptB\x08\n\x06_value\":\n\x14ShowInputBoxResponse\x12\x15\n\x08response\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_response\"$\n\x0fOpenFileRequest\x12\x11\n\tfile_path\x18\x01 \x01(\t\"\x12\n\x10OpenFileResponse\"3\n\x13OpenSettingsRequest\x12\x12\n\x05query\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x08\n\x06_query\"\x16\n\x14OpenSettingsResponse\"\x14\n\x12GetOpenTabsRequest\"$\n\x13GetOpenTabsResponse\x12\r\n\x05paths\x18\x01 \x03(\t\"\x17\n\x15GetVisibleTabsRequest\"\'\n\x16GetVisibleTabsResponse\x12\r\n\x05paths\x18\x01 \x03(\t\"\x18\n\x16GetActiveEditorRequest\"?\n\x17GetActiveEditorResponse\x12\x16\n\tfile_path\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x0c\n\n_file_path*:\n\x0fShowMessageType\x12\t\n\x05\x45RROR\x10\x00\x12\x0f\n\x0bINFORMATION\x10\x01\x12\x0b\n\x07WARNING\x10\x02\x32\xdc\x05\n\rWindowService\x12G\n\x10showTextDocument\x12\x1d.host.ShowTextDocumentRequest\x1a\x14.host.TextEditorInfo\x12J\n\x10showOpenDialogue\x12\x1d.host.ShowOpenDialogueRequest\x1a\x17.host.SelectedResources\x12?\n\x0bshowMessage\x12\x18.host.ShowMessageRequest\x1a\x16.host.SelectedResponse\x12\x45\n\x0cshowInputBox\x12\x19.host.ShowInputBoxRequest\x1a\x1a.host.ShowInputBoxResponse\x12K\n\x0eshowSaveDialog\x12\x1b.host.ShowSaveDialogRequest\x1a\x1c.host.ShowSaveDialogResponse\x12\x39\n\x08openFile\x12\x15.host.OpenFileRequest\x1a\x16.host.OpenFileResponse\x12\x45\n\x0copenSettings\x12\x19.host.OpenSettingsRequest\x1a\x1a.host.OpenSettingsResponse\x12\x42\n\x0bgetOpenTabs\x12\x18.host.GetOpenTabsRequest\x1a\x19.host.GetOpenTabsResponse\x12K\n\x0egetVisibleTabs\x12\x1b.host.GetVisibleTabsRequest\x1a\x1c.host.GetVisibleTabsResponse\x12N\n\x0fgetActiveEditor\x12\x1c.host.GetActiveEditorRequest\x1a\x1d.host.GetActiveEditorResponseB7\n\x14\x62ot.cline.host.protoP\x01Z\x1dgithub.com/cline/grpc-go/hostb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'host.window_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\024bot.cline.host.protoP\001Z\035github.com/cline/grpc-go/host'
  _globals['_SHOWSAVEDIALOGOPTIONS_FILTERSENTRY']._loaded_options = None
  _globals['_SHOWSAVEDIALOGOPTIONS_FILTERSENTRY']._serialized_options = b'8\001'
  _globals['_SHOWMESSAGETYPE']._serialized_start=1893
  _globals['_SHOWMESSAGETYPE']._serialized_end=1951
  _globals['_SHOWTEXTDOCUMENTREQUEST']._serialized_start=27
  _globals['_SHOWTEXTDOCUMENTREQUEST']._serialized_end=131
  _globals['_SHOWTEXTDOCUMENTOPTIONS']._serialized_start=134
  _globals['_SHOWTEXTDOCUMENTOPTIONS']._serialized_end=283
  _globals['_TEXTEDITORINFO']._serialized_start=285
  _globals['_TEXTEDITORINFO']._serialized_end=385
  _globals['_SHOWOPENDIALOGUEREQUEST']._serialized_start=388
  _globals['_SHOWOPENDIALOGUEREQUEST']._serialized_end=573
  _globals['_SHOWOPENDIALOGUEFILTEROPTION']._serialized_start=575
  _globals['_SHOWOPENDIALOGUEFILTEROPTION']._serialized_end=620
  _globals['_SELECTEDRESOURCES']._serialized_start=622
  _globals['_SELECTEDRESOURCES']._serialized_end=656
  _globals['_SHOWMESSAGEREQUEST']._serialized_start=659
  _globals['_SHOWMESSAGEREQUEST']._serialized_end=800
  _globals['_SHOWMESSAGEREQUESTOPTIONS']._serialized_start=802
  _globals['_SHOWMESSAGEREQUESTOPTIONS']._serialized_end=906
  _globals['_SELECTEDRESPONSE']._serialized_start=908
  _globals['_SELECTEDRESPONSE']._serialized_end=976
  _globals['_SHOWSAVEDIALOGREQUEST']._serialized_start=978
  _globals['_SHOWSAVEDIALOGREQUEST']._serialized_end=1064
  _globals['_SHOWSAVEDIALOGOPTIONS']._serialized_start=1067
  _globals['_SHOWSAVEDIALOGOPTIONS']._serialized_end=1266
  _globals['_SHOWSAVEDIALOGOPTIONS_FILTERSENTRY']._serialized_start=1178
  _globals['_SHOWSAVEDIALOGOPTIONS_FILTERSENTRY']._serialized_end=1249
  _globals['_FILEEXTENSIONLIST']._serialized_start=1268
  _globals['_FILEEXTENSIONLIST']._serialized_end=1307
  _globals['_SHOWSAVEDIALOGRESPONSE']._serialized_start=1309
  _globals['_SHOWSAVEDIALOGRESPONSE']._serialized_end=1379
  _globals['_SHOWINPUTBOXREQUEST']._serialized_start=1381
  _globals['_SHOWINPUTBOXREQUEST']._serialized_end=1479
  _globals['_SHOWINPUTBOXRESPONSE']._serialized_start=1481
  _globals['_SHOWINPUTBOXRESPONSE']._serialized_end=1539
  _globals['_OPENFILEREQUEST']._serialized_start=1541
  _globals['_OPENFILEREQUEST']._serialized_end=1577
  _globals['_OPENFILERESPONSE']._serialized_start=1579
  _globals['_OPENFILERESPONSE']._serialized_end=1597
  _globals['_OPENSETTINGSREQUEST']._serialized_start=1599
  _globals['_OPENSETTINGSREQUEST']._serialized_end=1650
  _globals['_OPENSETTINGSRESPONSE']._serialized_start=1652
  _globals['_OPENSETTINGSRESPONSE']._serialized_end=1674
  _globals['_GETOPENTABSREQUEST']._serialized_start=1676
  _globals['_GETOPENTABSREQUEST']._serialized_end=1696
  _globals['_GETOPENTABSRESPONSE']._serialized_start=1698
  _globals['_GETOPENTABSRESPONSE']._serialized_end=1734
  _globals['_GETVISIBLETABSREQUEST']._serialized_start=1736
  _globals['_GETVISIBLETABSREQUEST']._serialized_end=1759
  _globals['_GETVISIBLETABSRESPONSE']._serialized_start=1761
  _globals['_GETVISIBLETABSRESPONSE']._serialized_end=1800
  _globals['_GETACTIVEEDITORREQUEST']._serialized_start=1802
  _globals['_GETACTIVEEDITORREQUEST']._serialized_end=1826
  _globals['_GETACTIVEEDITORRESPONSE']._serialized_start=1828
  _globals['_GETACTIVEEDITORRESPONSE']._serialized_end=1891
  _globals['_WINDOWSERVICE']._serialized_start=1954
  _globals['_WINDOWSERVICE']._serialized_end=2686
# @@protoc_insertion_point(module_scope)
