# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cline/file.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'cline/file.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cline_core.proto.cline import common_pb2 as cline_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10\x63line/file.proto\x12\x05\x63line\x1a\x12\x63line/common.proto\"\xfe\x02\n\x0eRefreshedRules\x12<\n\x1aglobal_cline_rules_toggles\x18\x01 \x01(\x0b\x32\x18.cline.ClineRulesToggles\x12;\n\x19local_cline_rules_toggles\x18\x02 \x01(\x0b\x32\x18.cline.ClineRulesToggles\x12<\n\x1alocal_cursor_rules_toggles\x18\x03 \x01(\x0b\x32\x18.cline.ClineRulesToggles\x12>\n\x1clocal_windsurf_rules_toggles\x18\x04 \x01(\x0b\x32\x18.cline.ClineRulesToggles\x12\x38\n\x16local_workflow_toggles\x18\x05 \x01(\x0b\x32\x18.cline.ClineRulesToggles\x12\x39\n\x17global_workflow_toggles\x18\x06 \x01(\x0b\x32\x18.cline.ClineRulesToggles\"b\n\x19ToggleWindsurfRuleRequest\x12!\n\x08metadata\x18\x01 \x01(\x0b\x32\x0f.cline.Metadata\x12\x11\n\trule_path\x18\x02 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x03 \x01(\x08\"G\n\x14RelativePathsRequest\x12!\n\x08metadata\x18\x01 \x01(\x0b\x32\x0f.cline.Metadata\x12\x0c\n\x04uris\x18\x02 \x03(\t\"\x1e\n\rRelativePaths\x12\r\n\x05paths\x18\x01 \x03(\t\"\x92\x02\n\x11\x46ileSearchRequest\x12!\n\x08metadata\x18\x01 \x01(\x0b\x32\x0f.cline.Metadata\x12\r\n\x05query\x18\x02 \x01(\t\x12 \n\x13mentions_request_id\x18\x03 \x01(\tH\x00\x88\x01\x01\x12\x12\n\x05limit\x18\x04 \x01(\x05H\x01\x88\x01\x01\x12\x31\n\rselected_type\x18\x05 \x01(\x0e\x32\x15.cline.FileSearchTypeH\x02\x88\x01\x01\x12\x1b\n\x0eworkspace_hint\x18\x06 \x01(\tH\x03\x88\x01\x01\x42\x16\n\x14_mentions_request_idB\x08\n\x06_limitB\x10\n\x0e_selected_typeB\x11\n\x0f_workspace_hint\"o\n\x11\x46ileSearchResults\x12 \n\x07results\x18\x01 \x03(\x0b\x32\x0f.cline.FileInfo\x12 \n\x13mentions_request_id\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\x16\n\x14_mentions_request_id\"t\n\x08\x46ileInfo\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x12\n\x05label\x18\x03 \x01(\tH\x00\x88\x01\x01\x12\x1b\n\x0eworkspace_name\x18\x04 \x01(\tH\x01\x88\x01\x01\x42\x08\n\x06_labelB\x11\n\x0f_workspace_name\"/\n\nGitCommits\x12!\n\x07\x63ommits\x18\x01 \x03(\x0b\x32\x10.cline.GitCommit\"\\\n\tGitCommit\x12\x0c\n\x04hash\x18\x01 \x01(\t\x12\x12\n\nshort_hash\x18\x02 \x01(\t\x12\x0f\n\x07subject\x18\x03 \x01(\t\x12\x0e\n\x06\x61uthor\x18\x04 \x01(\t\x12\x0c\n\x04\x64\x61te\x18\x05 \x01(\t\"\xad\x01\n\x0fRuleFileRequest\x12!\n\x08metadata\x18\x01 \x01(\x0b\x32\x0f.cline.Metadata\x12\x11\n\tis_global\x18\x02 \x01(\x08\x12\x16\n\trule_path\x18\x03 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08\x66ilename\x18\x04 \x01(\tH\x01\x88\x01\x01\x12\x11\n\x04type\x18\x05 \x01(\tH\x02\x88\x01\x01\x42\x0c\n\n_rule_pathB\x0b\n\t_filenameB\x07\n\x05_type\"K\n\x08RuleFile\x12\x11\n\tfile_path\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\x16\n\x0e\x61lready_exists\x18\x03 \x01(\x08\"r\n\x16ToggleClineRuleRequest\x12!\n\x08metadata\x18\x01 \x01(\x0b\x32\x0f.cline.Metadata\x12\x11\n\tis_global\x18\x02 \x01(\x08\x12\x11\n\trule_path\x18\x03 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x04 \x01(\x08\"{\n\x11\x43lineRulesToggles\x12\x36\n\x07toggles\x18\x01 \x03(\x0b\x32%.cline.ClineRulesToggles.TogglesEntry\x1a.\n\x0cTogglesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\"\x8d\x01\n\x10ToggleClineRules\x12<\n\x1aglobal_cline_rules_toggles\x18\x01 \x01(\x0b\x32\x18.cline.ClineRulesToggles\x12;\n\x19local_cline_rules_toggles\x18\x02 \x01(\x0b\x32\x18.cline.ClineRulesToggles\"`\n\x17ToggleCursorRuleRequest\x12!\n\x08metadata\x18\x01 \x01(\x0b\x32\x0f.cline.Metadata\x12\x11\n\trule_path\x18\x02 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x03 \x01(\x08\"u\n\x15ToggleWorkflowRequest\x12!\n\x08metadata\x18\x01 \x01(\x0b\x32\x0f.cline.Metadata\x12\x15\n\rworkflow_path\x18\x02 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x03 \x01(\x08\x12\x11\n\tis_global\x18\x04 \x01(\x08*&\n\x0e\x46ileSearchType\x12\x08\n\x04\x46ILE\x10\x00\x12\n\n\x06\x46OLDER\x10\x01\x32\xc1\t\n\x0b\x46ileService\x12\x35\n\x0f\x63opyToClipboard\x12\x14.cline.StringRequest\x1a\x0c.cline.Empty\x12.\n\x08openFile\x12\x14.cline.StringRequest\x1a\x0c.cline.Empty\x12/\n\topenImage\x12\x14.cline.StringRequest\x1a\x0c.cline.Empty\x12\x31\n\x0bopenMention\x12\x14.cline.StringRequest\x1a\x0c.cline.Empty\x12\x39\n\x0e\x64\x65leteRuleFile\x12\x16.cline.RuleFileRequest\x1a\x0f.cline.RuleFile\x12\x39\n\x0e\x63reateRuleFile\x12\x16.cline.RuleFileRequest\x1a\x0f.cline.RuleFile\x12\x38\n\rsearchCommits\x12\x14.cline.StringRequest\x1a\x11.cline.GitCommits\x12\x39\n\x0bselectFiles\x12\x15.cline.BooleanRequest\x1a\x13.cline.StringArrays\x12\x45\n\x10getRelativePaths\x12\x1b.cline.RelativePathsRequest\x1a\x14.cline.RelativePaths\x12\x41\n\x0bsearchFiles\x12\x18.cline.FileSearchRequest\x1a\x18.cline.FileSearchResults\x12I\n\x0ftoggleClineRule\x12\x1d.cline.ToggleClineRuleRequest\x1a\x17.cline.ToggleClineRules\x12L\n\x10toggleCursorRule\x12\x1e.cline.ToggleCursorRuleRequest\x1a\x18.cline.ClineRulesToggles\x12P\n\x12toggleWindsurfRule\x12 .cline.ToggleWindsurfRuleRequest\x1a\x18.cline.ClineRulesToggles\x12:\n\x0crefreshRules\x12\x13.cline.EmptyRequest\x1a\x15.cline.RefreshedRules\x12\x41\n\x1bopenDiskConversationHistory\x12\x14.cline.StringRequest\x1a\x0c.cline.Empty\x12H\n\x0etoggleWorkflow\x12\x1c.cline.ToggleWorkflowRequest\x1a\x18.cline.ClineRulesToggles\x12H\n\x18ifFileExistsRelativePath\x12\x14.cline.StringRequest\x1a\x16.cline.BooleanResponse\x12:\n\x14openFileRelativePath\x12\x14.cline.StringRequest\x1a\x0c.cline.Empty\x12\x38\n\x12openFocusChainFile\x12\x14.cline.StringRequest\x1a\x0c.cline.EmptyB3\n\x0f\x62ot.cline.protoP\x01Z\x1egithub.com/cline/grpc-go/clineb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cline.file_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017bot.cline.protoP\001Z\036github.com/cline/grpc-go/cline'
  _globals['_CLINERULESTOGGLES_TOGGLESENTRY']._loaded_options = None
  _globals['_CLINERULESTOGGLES_TOGGLESENTRY']._serialized_options = b'8\001'
  _globals['_FILESEARCHTYPE']._serialized_start=2143
  _globals['_FILESEARCHTYPE']._serialized_end=2181
  _globals['_REFRESHEDRULES']._serialized_start=48
  _globals['_REFRESHEDRULES']._serialized_end=430
  _globals['_TOGGLEWINDSURFRULEREQUEST']._serialized_start=432
  _globals['_TOGGLEWINDSURFRULEREQUEST']._serialized_end=530
  _globals['_RELATIVEPATHSREQUEST']._serialized_start=532
  _globals['_RELATIVEPATHSREQUEST']._serialized_end=603
  _globals['_RELATIVEPATHS']._serialized_start=605
  _globals['_RELATIVEPATHS']._serialized_end=635
  _globals['_FILESEARCHREQUEST']._serialized_start=638
  _globals['_FILESEARCHREQUEST']._serialized_end=912
  _globals['_FILESEARCHRESULTS']._serialized_start=914
  _globals['_FILESEARCHRESULTS']._serialized_end=1025
  _globals['_FILEINFO']._serialized_start=1027
  _globals['_FILEINFO']._serialized_end=1143
  _globals['_GITCOMMITS']._serialized_start=1145
  _globals['_GITCOMMITS']._serialized_end=1192
  _globals['_GITCOMMIT']._serialized_start=1194
  _globals['_GITCOMMIT']._serialized_end=1286
  _globals['_RULEFILEREQUEST']._serialized_start=1289
  _globals['_RULEFILEREQUEST']._serialized_end=1462
  _globals['_RULEFILE']._serialized_start=1464
  _globals['_RULEFILE']._serialized_end=1539
  _globals['_TOGGLECLINERULEREQUEST']._serialized_start=1541
  _globals['_TOGGLECLINERULEREQUEST']._serialized_end=1655
  _globals['_CLINERULESTOGGLES']._serialized_start=1657
  _globals['_CLINERULESTOGGLES']._serialized_end=1780
  _globals['_CLINERULESTOGGLES_TOGGLESENTRY']._serialized_start=1734
  _globals['_CLINERULESTOGGLES_TOGGLESENTRY']._serialized_end=1780
  _globals['_TOGGLECLINERULES']._serialized_start=1783
  _globals['_TOGGLECLINERULES']._serialized_end=1924
  _globals['_TOGGLECURSORRULEREQUEST']._serialized_start=1926
  _globals['_TOGGLECURSORRULEREQUEST']._serialized_end=2022
  _globals['_TOGGLEWORKFLOWREQUEST']._serialized_start=2024
  _globals['_TOGGLEWORKFLOWREQUEST']._serialized_end=2141
  _globals['_FILESERVICE']._serialized_start=2184
  _globals['_FILESERVICE']._serialized_end=3401
# @@protoc_insertion_point(module_scope)
