# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cline/mcp.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'cline/mcp.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cline_core.proto.cline import common_pb2 as cline_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0f\x63line/mcp.proto\x12\x05\x63line\x1a\x12\x63line/common.proto\"b\n\x16ToggleMcpServerRequest\x12!\n\x08metadata\x18\x01 \x01(\x0b\x32\x0f.cline.Metadata\x12\x13\n\x0bserver_name\x18\x02 \x01(\t\x12\x10\n\x08\x64isabled\x18\x03 \x01(\x08\"b\n\x17UpdateMcpTimeoutRequest\x12!\n\x08metadata\x18\x01 \x01(\x0b\x32\x0f.cline.Metadata\x12\x13\n\x0bserver_name\x18\x02 \x01(\t\x12\x0f\n\x07timeout\x18\x03 \x01(\x05\"g\n\x19\x41\x64\x64RemoteMcpServerRequest\x12!\n\x08metadata\x18\x01 \x01(\x0b\x32\x0f.cline.Metadata\x12\x13\n\x0bserver_name\x18\x02 \x01(\t\x12\x12\n\nserver_url\x18\x03 \x01(\t\"\x80\x01\n\x1cToggleToolAutoApproveRequest\x12!\n\x08metadata\x18\x01 \x01(\x0b\x32\x0f.cline.Metadata\x12\x13\n\x0bserver_name\x18\x02 \x01(\t\x12\x12\n\ntool_names\x18\x03 \x03(\t\x12\x14\n\x0c\x61uto_approve\x18\x04 \x01(\x08\"\x99\x01\n\x07McpTool\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x18\n\x0b\x64\x65scription\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x19\n\x0cinput_schema\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x19\n\x0c\x61uto_approve\x18\x04 \x01(\x08H\x02\x88\x01\x01\x42\x0e\n\x0c_descriptionB\x0f\n\r_input_schemaB\x0f\n\r_auto_approve\"x\n\x0bMcpResource\x12\x0b\n\x03uri\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x16\n\tmime_type\x18\x03 \x01(\tH\x00\x88\x01\x01\x12\x18\n\x0b\x64\x65scription\x18\x04 \x01(\tH\x01\x88\x01\x01\x42\x0c\n\n_mime_typeB\x0e\n\x0c_description\"\x89\x01\n\x13McpResourceTemplate\x12\x14\n\x0curi_template\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x16\n\tmime_type\x18\x03 \x01(\tH\x00\x88\x01\x01\x12\x18\n\x0b\x64\x65scription\x18\x04 \x01(\tH\x01\x88\x01\x01\x42\x0c\n\n_mime_typeB\x0e\n\x0c_description\"\xb3\x02\n\tMcpServer\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06\x63onfig\x18\x02 \x01(\t\x12&\n\x06status\x18\x03 \x01(\x0e\x32\x16.cline.McpServerStatus\x12\x12\n\x05\x65rror\x18\x04 \x01(\tH\x00\x88\x01\x01\x12\x1d\n\x05tools\x18\x05 \x03(\x0b\x32\x0e.cline.McpTool\x12%\n\tresources\x18\x06 \x03(\x0b\x32\x12.cline.McpResource\x12\x36\n\x12resource_templates\x18\x07 \x03(\x0b\x32\x1a.cline.McpResourceTemplate\x12\x15\n\x08\x64isabled\x18\x08 \x01(\x08H\x01\x88\x01\x01\x12\x14\n\x07timeout\x18\t \x01(\x05H\x02\x88\x01\x01\x42\x08\n\x06_errorB\x0b\n\t_disabledB\n\n\x08_timeout\"3\n\nMcpServers\x12%\n\x0bmcp_servers\x18\x01 \x03(\x0b\x32\x10.cline.McpServer\"\xcb\x03\n\x12McpMarketplaceItem\x12\x0e\n\x06mcp_id\x18\x01 \x01(\t\x12\x12\n\ngithub_url\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0e\n\x06\x61uthor\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x14\n\x0c\x63odicon_icon\x18\x06 \x01(\t\x12\x10\n\x08logo_url\x18\x07 \x01(\t\x12\x10\n\x08\x63\x61tegory\x18\x08 \x01(\t\x12\x0c\n\x04tags\x18\t \x03(\t\x12\x18\n\x10requires_api_key\x18\n \x01(\x08\x12\x1b\n\x0ereadme_content\x18\x0b \x01(\tH\x00\x88\x01\x01\x12&\n\x19llms_installation_content\x18\x0c \x01(\tH\x01\x88\x01\x01\x12\x16\n\x0eis_recommended\x18\r \x01(\x08\x12\x14\n\x0cgithub_stars\x18\x0e \x01(\x05\x12\x16\n\x0e\x64ownload_count\x18\x0f \x01(\x05\x12\x12\n\ncreated_at\x18\x10 \x01(\t\x12\x12\n\nupdated_at\x18\x11 \x01(\t\x12\x18\n\x10last_github_sync\x18\x12 \x01(\tB\x11\n\x0f_readme_contentB\x1c\n\x1a_llms_installation_content\"A\n\x15McpMarketplaceCatalog\x12(\n\x05items\x18\x01 \x03(\x0b\x32\x19.cline.McpMarketplaceItem\"\xdf\x01\n\x13McpDownloadResponse\x12\x0e\n\x06mcp_id\x18\x01 \x01(\t\x12\x12\n\ngithub_url\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0e\n\x06\x61uthor\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x16\n\x0ereadme_content\x18\x06 \x01(\t\x12!\n\x19llms_installation_content\x18\x07 \x01(\t\x12\x18\n\x10requires_api_key\x18\x08 \x01(\x08\x12\x12\n\x05\x65rror\x18\t \x01(\tH\x00\x88\x01\x01\x42\x08\n\x06_error*x\n\x0fMcpServerStatus\x12\"\n\x1eMCP_SERVER_STATUS_DISCONNECTED\x10\x00\x12\x1f\n\x1bMCP_SERVER_STATUS_CONNECTED\x10\x01\x12 \n\x1cMCP_SERVER_STATUS_CONNECTING\x10\x02\x32\xc4\x06\n\nMcpService\x12\x43\n\x0ftoggleMcpServer\x12\x1d.cline.ToggleMcpServerRequest\x1a\x11.cline.McpServers\x12\x45\n\x10updateMcpTimeout\x12\x1e.cline.UpdateMcpTimeoutRequest\x1a\x11.cline.McpServers\x12I\n\x12\x61\x64\x64RemoteMcpServer\x12 .cline.AddRemoteMcpServerRequest\x1a\x11.cline.McpServers\x12?\n\x0b\x64ownloadMcp\x12\x14.cline.StringRequest\x1a\x1a.cline.McpDownloadResponse\x12;\n\x10restartMcpServer\x12\x14.cline.StringRequest\x1a\x11.cline.McpServers\x12:\n\x0f\x64\x65leteMcpServer\x12\x14.cline.StringRequest\x1a\x11.cline.McpServers\x12O\n\x15toggleToolAutoApprove\x12#.cline.ToggleToolAutoApproveRequest\x1a\x11.cline.McpServers\x12J\n\x15refreshMcpMarketplace\x12\x13.cline.EmptyRequest\x1a\x1c.cline.McpMarketplaceCatalog\x12\x34\n\x0fopenMcpSettings\x12\x13.cline.EmptyRequest\x1a\x0c.cline.Empty\x12W\n subscribeToMcpMarketplaceCatalog\x12\x13.cline.EmptyRequest\x1a\x1c.cline.McpMarketplaceCatalog0\x01\x12\x36\n\x13getLatestMcpServers\x12\x0c.cline.Empty\x1a\x11.cline.McpServers\x12\x41\n\x15subscribeToMcpServers\x12\x13.cline.EmptyRequest\x1a\x11.cline.McpServers0\x01\x42\x33\n\x0f\x62ot.cline.protoP\x01Z\x1egithub.com/cline/grpc-go/clineb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cline.mcp_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017bot.cline.protoP\001Z\036github.com/cline/grpc-go/cline'
  _globals['_MCPSERVERSTATUS']._serialized_start=2018
  _globals['_MCPSERVERSTATUS']._serialized_end=2138
  _globals['_TOGGLEMCPSERVERREQUEST']._serialized_start=46
  _globals['_TOGGLEMCPSERVERREQUEST']._serialized_end=144
  _globals['_UPDATEMCPTIMEOUTREQUEST']._serialized_start=146
  _globals['_UPDATEMCPTIMEOUTREQUEST']._serialized_end=244
  _globals['_ADDREMOTEMCPSERVERREQUEST']._serialized_start=246
  _globals['_ADDREMOTEMCPSERVERREQUEST']._serialized_end=349
  _globals['_TOGGLETOOLAUTOAPPROVEREQUEST']._serialized_start=352
  _globals['_TOGGLETOOLAUTOAPPROVEREQUEST']._serialized_end=480
  _globals['_MCPTOOL']._serialized_start=483
  _globals['_MCPTOOL']._serialized_end=636
  _globals['_MCPRESOURCE']._serialized_start=638
  _globals['_MCPRESOURCE']._serialized_end=758
  _globals['_MCPRESOURCETEMPLATE']._serialized_start=761
  _globals['_MCPRESOURCETEMPLATE']._serialized_end=898
  _globals['_MCPSERVER']._serialized_start=901
  _globals['_MCPSERVER']._serialized_end=1208
  _globals['_MCPSERVERS']._serialized_start=1210
  _globals['_MCPSERVERS']._serialized_end=1261
  _globals['_MCPMARKETPLACEITEM']._serialized_start=1264
  _globals['_MCPMARKETPLACEITEM']._serialized_end=1723
  _globals['_MCPMARKETPLACECATALOG']._serialized_start=1725
  _globals['_MCPMARKETPLACECATALOG']._serialized_end=1790
  _globals['_MCPDOWNLOADRESPONSE']._serialized_start=1793
  _globals['_MCPDOWNLOADRESPONSE']._serialized_end=2016
  _globals['_MCPSERVICE']._serialized_start=2141
  _globals['_MCPSERVICE']._serialized_end=2977
# @@protoc_insertion_point(module_scope)
