# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cline/checkpoints.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'cline/checkpoints.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cline_core.proto.cline import common_pb2 as cline_dot_common__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x63line/checkpoints.proto\x12\x05\x63line\x1a\x12\x63line/common.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x83\x01\n\x18\x43heckpointRestoreRequest\x12!\n\x08metadata\x18\x01 \x01(\x0b\x32\x0f.cline.Metadata\x12\x0e\n\x06number\x18\x02 \x01(\x03\x12\x14\n\x0crestore_type\x18\x03 \x01(\t\x12\x13\n\x06offset\x18\x04 \x01(\x03H\x00\x88\x01\x01\x42\t\n\x07_offset\"1\n\x1d\x43heckpointSubscriptionRequest\x12\x10\n\x08\x63wd_hash\x18\x01 \x01(\t\"\xbf\x02\n\x0f\x43heckpointEvent\x12\x37\n\toperation\x18\x01 \x01(\x0e\x32$.cline.CheckpointEvent.OperationType\x12\x10\n\x08\x63wd_hash\x18\x02 \x01(\t\x12\x11\n\tis_active\x18\x03 \x01(\x08\x12-\n\ttimestamp\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x14\n\x07task_id\x18\x05 \x01(\tH\x00\x88\x01\x01\x12\x18\n\x0b\x63ommit_hash\x18\x06 \x01(\tH\x01\x88\x01\x01\"S\n\rOperationType\x12\x13\n\x0f\x43HECKPOINT_INIT\x10\x00\x12\x15\n\x11\x43HECKPOINT_COMMIT\x10\x01\x12\x16\n\x12\x43HECKPOINT_RESTORE\x10\x02\x42\n\n\x08_task_idB\x0e\n\x0c_commit_hash\"s\n\x0bPathHashMap\x12\x33\n\tpath_hash\x18\x01 \x03(\x0b\x32 .cline.PathHashMap.PathHashEntry\x1a/\n\rPathHashEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x32\xa4\x02\n\x12\x43heckpointsService\x12\x33\n\x0e\x63heckpointDiff\x12\x13.cline.Int64Request\x1a\x0c.cline.Empty\x12\x42\n\x11\x63heckpointRestore\x12\x1f.cline.CheckpointRestoreRequest\x1a\x0c.cline.Empty\x12X\n\x16subscribeToCheckpoints\x12$.cline.CheckpointSubscriptionRequest\x1a\x16.cline.CheckpointEvent0\x01\x12;\n\ngetCwdHash\x12\x19.cline.StringArrayRequest\x1a\x12.cline.PathHashMapB3\n\x0f\x62ot.cline.protoP\x01Z\x1egithub.com/cline/grpc-go/clineb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cline.checkpoints_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017bot.cline.protoP\001Z\036github.com/cline/grpc-go/cline'
  _globals['_PATHHASHMAP_PATHHASHENTRY']._loaded_options = None
  _globals['_PATHHASHMAP_PATHHASHENTRY']._serialized_options = b'8\001'
  _globals['_CHECKPOINTRESTOREREQUEST']._serialized_start=88
  _globals['_CHECKPOINTRESTOREREQUEST']._serialized_end=219
  _globals['_CHECKPOINTSUBSCRIPTIONREQUEST']._serialized_start=221
  _globals['_CHECKPOINTSUBSCRIPTIONREQUEST']._serialized_end=270
  _globals['_CHECKPOINTEVENT']._serialized_start=273
  _globals['_CHECKPOINTEVENT']._serialized_end=592
  _globals['_CHECKPOINTEVENT_OPERATIONTYPE']._serialized_start=481
  _globals['_CHECKPOINTEVENT_OPERATIONTYPE']._serialized_end=564
  _globals['_PATHHASHMAP']._serialized_start=594
  _globals['_PATHHASHMAP']._serialized_end=709
  _globals['_PATHHASHMAP_PATHHASHENTRY']._serialized_start=662
  _globals['_PATHHASHMAP_PATHHASHENTRY']._serialized_end=709
  _globals['_CHECKPOINTSSERVICE']._serialized_start=712
  _globals['_CHECKPOINTSSERVICE']._serialized_end=1004
# @@protoc_insertion_point(module_scope)
