# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: host/env.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'host/env.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cline_core.proto.cline import common_pb2 as cline_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0ehost/env.proto\x12\x04host\x1a\x12\x63line/common.proto\"\xb4\x01\n\x16GetHostVersionResponse\x12\x15\n\x08platform\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x14\n\x07version\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x17\n\ncline_type\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x1a\n\rcline_version\x18\x04 \x01(\tH\x03\x88\x01\x01\x42\x0b\n\t_platformB\n\n\x08_versionB\r\n\x0b_cline_typeB\x10\n\x0e_cline_version\"A\n\x1cGetTelemetrySettingsResponse\x12!\n\nis_enabled\x18\x01 \x01(\x0e\x32\r.host.Setting\";\n\x16TelemetrySettingsEvent\x12!\n\nis_enabled\x18\x01 \x01(\x0e\x32\r.host.Setting*5\n\x07Setting\x12\x0f\n\x0bUNSUPPORTED\x10\x00\x12\x0b\n\x07\x45NABLED\x10\x01\x12\x0c\n\x08\x44ISABLED\x10\x02\x32\xd2\x03\n\nEnvService\x12\x38\n\x12\x63lipboardWriteText\x12\x14.cline.StringRequest\x1a\x0c.cline.Empty\x12\x37\n\x11\x63lipboardReadText\x12\x13.cline.EmptyRequest\x1a\r.cline.String\x12\x43\n\x0egetHostVersion\x12\x13.cline.EmptyRequest\x1a\x1c.host.GetHostVersionResponse\x12\x37\n\x11getIdeRedirectUri\x12\x13.cline.EmptyRequest\x1a\r.cline.String\x12O\n\x14getTelemetrySettings\x12\x13.cline.EmptyRequest\x1a\".host.GetTelemetrySettingsResponse\x12S\n\x1csubscribeToTelemetrySettings\x12\x13.cline.EmptyRequest\x1a\x1c.host.TelemetrySettingsEvent0\x01\x12-\n\x08shutdown\x12\x13.cline.EmptyRequest\x1a\x0c.cline.EmptyB7\n\x14\x62ot.cline.host.protoP\x01Z\x1dgithub.com/cline/grpc-go/hostb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'host.env_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\024bot.cline.host.protoP\001Z\035github.com/cline/grpc-go/host'
  _globals['_SETTING']._serialized_start=355
  _globals['_SETTING']._serialized_end=408
  _globals['_GETHOSTVERSIONRESPONSE']._serialized_start=45
  _globals['_GETHOSTVERSIONRESPONSE']._serialized_end=225
  _globals['_GETTELEMETRYSETTINGSRESPONSE']._serialized_start=227
  _globals['_GETTELEMETRYSETTINGSRESPONSE']._serialized_end=292
  _globals['_TELEMETRYSETTINGSEVENT']._serialized_start=294
  _globals['_TELEMETRYSETTINGSEVENT']._serialized_end=353
  _globals['_ENVSERVICE']._serialized_start=411
  _globals['_ENVSERVICE']._serialized_end=877
# @@protoc_insertion_point(module_scope)
