# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cline/task.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'cline/task.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cline_core.proto.cline import common_pb2 as cline_dot_common__pb2
from cline_core.proto.cline import state_pb2 as cline_dot_state__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10\x63line/task.proto\x12\x05\x63line\x1a\x12\x63line/common.proto\x1a\x11\x63line/state.proto\"\x9f\x01\n\x0eNewTaskRequest\x12!\n\x08metadata\x18\x01 \x01(\x0b\x32\x0f.cline.Metadata\x12\x0c\n\x04text\x18\x02 \x01(\t\x12\x0e\n\x06images\x18\x03 \x03(\t\x12\r\n\x05\x66iles\x18\x04 \x03(\t\x12+\n\rtask_settings\x18\x05 \x01(\x0b\x32\x0f.cline.SettingsH\x00\x88\x01\x01\x42\x10\n\x0e_task_settings\"_\n\x13TaskFavoriteRequest\x12!\n\x08metadata\x18\x01 \x01(\x0b\x32\x0f.cline.Metadata\x12\x0f\n\x07task_id\x18\x02 \x01(\t\x12\x14\n\x0cis_favorited\x18\x03 \x01(\x08\"\xbe\x01\n\x0cTaskResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04task\x18\x02 \x01(\t\x12\n\n\x02ts\x18\x03 \x01(\x03\x12\x14\n\x0cis_favorited\x18\x04 \x01(\x08\x12\x0c\n\x04size\x18\x05 \x01(\x03\x12\x12\n\ntotal_cost\x18\x06 \x01(\x01\x12\x11\n\ttokens_in\x18\x07 \x01(\x05\x12\x12\n\ntokens_out\x18\x08 \x01(\x05\x12\x14\n\x0c\x63\x61\x63he_writes\x18\t \x01(\x05\x12\x13\n\x0b\x63\x61\x63he_reads\x18\n \x01(\x05\"\x99\x01\n\x15GetTaskHistoryRequest\x12!\n\x08metadata\x18\x01 \x01(\x0b\x32\x0f.cline.Metadata\x12\x16\n\x0e\x66\x61vorites_only\x18\x02 \x01(\x08\x12\x14\n\x0csearch_query\x18\x03 \x01(\t\x12\x0f\n\x07sort_by\x18\x04 \x01(\t\x12\x1e\n\x16\x63urrent_workspace_only\x18\x05 \x01(\x08\"G\n\x10TaskHistoryArray\x12\x1e\n\x05tasks\x18\x01 \x03(\x0b\x32\x0f.cline.TaskItem\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"\xba\x01\n\x08TaskItem\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04task\x18\x02 \x01(\t\x12\n\n\x02ts\x18\x03 \x01(\x03\x12\x14\n\x0cis_favorited\x18\x04 \x01(\x08\x12\x0c\n\x04size\x18\x05 \x01(\x03\x12\x12\n\ntotal_cost\x18\x06 \x01(\x01\x12\x11\n\ttokens_in\x18\x07 \x01(\x05\x12\x12\n\ntokens_out\x18\x08 \x01(\x05\x12\x14\n\x0c\x63\x61\x63he_writes\x18\t \x01(\x05\x12\x13\n\x0b\x63\x61\x63he_reads\x18\n \x01(\x05\"{\n\x12\x41skResponseRequest\x12!\n\x08metadata\x18\x01 \x01(\x0b\x32\x0f.cline.Metadata\x12\x15\n\rresponse_type\x18\x02 \x01(\t\x12\x0c\n\x04text\x18\x03 \x01(\t\x12\x0e\n\x06images\x18\x04 \x03(\t\x12\r\n\x05\x66iles\x18\x05 \x03(\t\"[\n\x16\x45xecuteQuickWinRequest\x12!\n\x08metadata\x18\x01 \x01(\x0b\x32\x0f.cline.Metadata\x12\x0f\n\x07\x63ommand\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"2\n\x19\x44\x65leteAllTaskHistoryCount\x12\x15\n\rtasks_deleted\x18\x01 \x01(\x05\x32\x8d\x07\n\x0bTaskService\x12/\n\ncancelTask\x12\x13.cline.EmptyRequest\x1a\x0c.cline.Empty\x12<\n\x17\x63\x61ncelBackgroundCommand\x12\x13.cline.EmptyRequest\x1a\x0c.cline.Empty\x12.\n\tclearTask\x12\x13.cline.EmptyRequest\x1a\x0c.cline.Empty\x12\x36\n\x11getTotalTasksSize\x12\x13.cline.EmptyRequest\x1a\x0c.cline.Int64\x12=\n\x12\x64\x65leteTasksWithIds\x12\x19.cline.StringArrayRequest\x1a\x0c.cline.Empty\x12/\n\x07newTask\x12\x15.cline.NewTaskRequest\x1a\r.cline.String\x12;\n\x0eshowTaskWithId\x12\x14.cline.StringRequest\x1a\x13.cline.TaskResponse\x12\x36\n\x10\x65xportTaskWithId\x12\x14.cline.StringRequest\x1a\x0c.cline.Empty\x12>\n\x12toggleTaskFavorite\x12\x1a.cline.TaskFavoriteRequest\x1a\x0c.cline.Empty\x12G\n\x0egetTaskHistory\x12\x1c.cline.GetTaskHistoryRequest\x1a\x17.cline.TaskHistoryArray\x12\x36\n\x0b\x61skResponse\x12\x19.cline.AskResponseRequest\x1a\x0c.cline.Empty\x12\x32\n\x0ctaskFeedback\x12\x14.cline.StringRequest\x1a\x0c.cline.Empty\x12>\n\x19taskCompletionViewChanges\x12\x13.cline.Int64Request\x1a\x0c.cline.Empty\x12>\n\x0f\x65xecuteQuickWin\x12\x1d.cline.ExecuteQuickWinRequest\x1a\x0c.cline.Empty\x12M\n\x14\x64\x65leteAllTaskHistory\x12\x13.cline.EmptyRequest\x1a .cline.DeleteAllTaskHistoryCountB3\n\x0f\x62ot.cline.protoP\x01Z\x1egithub.com/cline/grpc-go/clineb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cline.task_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017bot.cline.protoP\001Z\036github.com/cline/grpc-go/cline'
  _globals['_NEWTASKREQUEST']._serialized_start=67
  _globals['_NEWTASKREQUEST']._serialized_end=226
  _globals['_TASKFAVORITEREQUEST']._serialized_start=228
  _globals['_TASKFAVORITEREQUEST']._serialized_end=323
  _globals['_TASKRESPONSE']._serialized_start=326
  _globals['_TASKRESPONSE']._serialized_end=516
  _globals['_GETTASKHISTORYREQUEST']._serialized_start=519
  _globals['_GETTASKHISTORYREQUEST']._serialized_end=672
  _globals['_TASKHISTORYARRAY']._serialized_start=674
  _globals['_TASKHISTORYARRAY']._serialized_end=745
  _globals['_TASKITEM']._serialized_start=748
  _globals['_TASKITEM']._serialized_end=934
  _globals['_ASKRESPONSEREQUEST']._serialized_start=936
  _globals['_ASKRESPONSEREQUEST']._serialized_end=1059
  _globals['_EXECUTEQUICKWINREQUEST']._serialized_start=1061
  _globals['_EXECUTEQUICKWINREQUEST']._serialized_end=1152
  _globals['_DELETEALLTASKHISTORYCOUNT']._serialized_start=1154
  _globals['_DELETEALLTASKHISTORYCOUNT']._serialized_end=1204
  _globals['_TASKSERVICE']._serialized_start=1207
  _globals['_TASKSERVICE']._serialized_end=2116
# @@protoc_insertion_point(module_scope)
