# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cline/common.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'cline/common.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12\x63line/common.proto\x12\x05\x63line\"\n\n\x08Metadata\"\x0e\n\x0c\x45mptyRequest\"\x07\n\x05\x45mpty\"\x1e\n\rStringRequest\x12\r\n\x05value\x18\x02 \x01(\t\"#\n\x12StringArrayRequest\x12\r\n\x05value\x18\x02 \x03(\t\"\x17\n\x06String\x12\r\n\x05value\x18\x01 \x01(\t\"\x1d\n\x0cInt64Request\x12\r\n\x05value\x18\x02 \x01(\x03\"\x16\n\x05Int64\x12\r\n\x05value\x18\x01 \x01(\x03\"\x1d\n\x0c\x42ytesRequest\x12\r\n\x05value\x18\x02 \x01(\x0c\"\x16\n\x05\x42ytes\x12\r\n\x05value\x18\x01 \x01(\x0c\"\x1f\n\x0e\x42ooleanRequest\x12\r\n\x05value\x18\x02 \x01(\x08\"\x18\n\x07\x42oolean\x12\r\n\x05value\x18\x01 \x01(\x08\" \n\x0f\x42ooleanResponse\x12\r\n\x05value\x18\x01 \x01(\x08\"\x1d\n\x0bStringArray\x12\x0e\n\x06values\x18\x01 \x03(\t\"0\n\x0cStringArrays\x12\x0f\n\x07values1\x18\x01 \x03(\t\x12\x0f\n\x07values2\x18\x02 \x03(\t\"*\n\x0cKeyValuePair\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"L\n\x0f\x46ileDiagnostics\x12\x11\n\tfile_path\x18\x01 \x01(\t\x12&\n\x0b\x64iagnostics\x18\x02 \x03(\x0b\x32\x11.cline.Diagnostic\"\x91\x01\n\nDiagnostic\x12\x0f\n\x07message\x18\x01 \x01(\t\x12%\n\x05range\x18\x02 \x01(\x0b\x32\x16.cline.DiagnosticRange\x12+\n\x08severity\x18\x03 \x01(\x0e\x32\x19.cline.DiagnosticSeverity\x12\x13\n\x06source\x18\x04 \x01(\tH\x00\x88\x01\x01\x42\t\n\x07_source\"c\n\x0f\x44iagnosticRange\x12(\n\x05start\x18\x01 \x01(\x0b\x32\x19.cline.DiagnosticPosition\x12&\n\x03\x65nd\x18\x02 \x01(\x0b\x32\x19.cline.DiagnosticPosition\"5\n\x12\x44iagnosticPosition\x12\x0c\n\x04line\x18\x01 \x01(\x05\x12\x11\n\tcharacter\x18\x02 \x01(\x05*s\n\x12\x44iagnosticSeverity\x12\x14\n\x10\x44IAGNOSTIC_ERROR\x10\x00\x12\x16\n\x12\x44IAGNOSTIC_WARNING\x10\x01\x12\x1a\n\x16\x44IAGNOSTIC_INFORMATION\x10\x02\x12\x13\n\x0f\x44IAGNOSTIC_HINT\x10\x03\x42\x33\n\x0f\x62ot.cline.protoP\x01Z\x1egithub.com/cline/grpc-go/clineb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cline.common_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017bot.cline.protoP\001Z\036github.com/cline/grpc-go/cline'
  _globals['_DIAGNOSTICSEVERITY']._serialized_start=870
  _globals['_DIAGNOSTICSEVERITY']._serialized_end=985
  _globals['_METADATA']._serialized_start=29
  _globals['_METADATA']._serialized_end=39
  _globals['_EMPTYREQUEST']._serialized_start=41
  _globals['_EMPTYREQUEST']._serialized_end=55
  _globals['_EMPTY']._serialized_start=57
  _globals['_EMPTY']._serialized_end=64
  _globals['_STRINGREQUEST']._serialized_start=66
  _globals['_STRINGREQUEST']._serialized_end=96
  _globals['_STRINGARRAYREQUEST']._serialized_start=98
  _globals['_STRINGARRAYREQUEST']._serialized_end=133
  _globals['_STRING']._serialized_start=135
  _globals['_STRING']._serialized_end=158
  _globals['_INT64REQUEST']._serialized_start=160
  _globals['_INT64REQUEST']._serialized_end=189
  _globals['_INT64']._serialized_start=191
  _globals['_INT64']._serialized_end=213
  _globals['_BYTESREQUEST']._serialized_start=215
  _globals['_BYTESREQUEST']._serialized_end=244
  _globals['_BYTES']._serialized_start=246
  _globals['_BYTES']._serialized_end=268
  _globals['_BOOLEANREQUEST']._serialized_start=270
  _globals['_BOOLEANREQUEST']._serialized_end=301
  _globals['_BOOLEAN']._serialized_start=303
  _globals['_BOOLEAN']._serialized_end=327
  _globals['_BOOLEANRESPONSE']._serialized_start=329
  _globals['_BOOLEANRESPONSE']._serialized_end=361
  _globals['_STRINGARRAY']._serialized_start=363
  _globals['_STRINGARRAY']._serialized_end=392
  _globals['_STRINGARRAYS']._serialized_start=394
  _globals['_STRINGARRAYS']._serialized_end=442
  _globals['_KEYVALUEPAIR']._serialized_start=444
  _globals['_KEYVALUEPAIR']._serialized_end=486
  _globals['_FILEDIAGNOSTICS']._serialized_start=488
  _globals['_FILEDIAGNOSTICS']._serialized_end=564
  _globals['_DIAGNOSTIC']._serialized_start=567
  _globals['_DIAGNOSTIC']._serialized_end=712
  _globals['_DIAGNOSTICRANGE']._serialized_start=714
  _globals['_DIAGNOSTICRANGE']._serialized_end=813
  _globals['_DIAGNOSTICPOSITION']._serialized_start=815
  _globals['_DIAGNOSTICPOSITION']._serialized_end=868
# @@protoc_insertion_point(module_scope)
