# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: host/workspace.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'host/workspace.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cline_core.proto.cline import common_pb2 as cline_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14host/workspace.proto\x12\x04host\x1a\x12\x63line/common.proto\"2\n\x18GetWorkspacePathsRequest\x12\x0f\n\x02id\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x05\n\x03_id\"B\n\x19GetWorkspacePathsResponse\x12\x0f\n\x02id\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\r\n\x05paths\x18\x02 \x03(\tB\x05\n\x03_id\"F\n\x1eSaveOpenDocumentIfDirtyRequest\x12\x16\n\tfile_path\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\x0c\n\n_file_path\"G\n\x1fSaveOpenDocumentIfDirtyResponse\x12\x16\n\twas_saved\x18\x01 \x01(\x08H\x00\x88\x01\x01\x42\x0c\n\n_was_saved\"L\n\x15GetDiagnosticsRequest\x12&\n\x08metadata\x18\x01 \x01(\x0b\x32\x0f.cline.MetadataH\x00\x88\x01\x01\x42\x0b\n\t_metadata\"J\n\x16GetDiagnosticsResponse\x12\x30\n\x10\x66ile_diagnostics\x18\x01 \x03(\x0b\x32\x16.cline.FileDiagnostics\"\xd2\x01\n\x1bSearchWorkspaceItemsRequest\x12\r\n\x05query\x18\x01 \x01(\t\x12\x12\n\x05limit\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12L\n\rselected_type\x18\x03 \x01(\x0e\x32\x30.host.SearchWorkspaceItemsRequest.SearchItemTypeH\x01\x88\x01\x01\"&\n\x0eSearchItemType\x12\x08\n\x04\x46ILE\x10\x00\x12\n\n\x06\x46OLDER\x10\x01\x42\x08\n\x06_limitB\x10\n\x0e_selected_type\"\xd6\x01\n\x1cSearchWorkspaceItemsResponse\x12<\n\x05items\x18\x01 \x03(\x0b\x32-.host.SearchWorkspaceItemsResponse.SearchItem\x1ax\n\nSearchItem\x12\x0c\n\x04path\x18\x01 \x01(\t\x12>\n\x04type\x18\x02 \x01(\x0e\x32\x30.host.SearchWorkspaceItemsRequest.SearchItemType\x12\x12\n\x05label\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x08\n\x06_label\"\x1a\n\x18OpenProblemsPanelRequest\"\x1b\n\x19OpenProblemsPanelResponse\".\n\x1eOpenInFileExplorerPanelRequest\x12\x0c\n\x04path\x18\x01 \x01(\t\"!\n\x1fOpenInFileExplorerPanelResponse\"\x1e\n\x1cOpenClineSidebarPanelRequest\"\x1f\n\x1dOpenClineSidebarPanelResponse\"\x15\n\x13OpenTerminalRequest\"\x16\n\x14OpenTerminalResponse\"2\n\x1f\x45xecuteCommandInTerminalRequest\x12\x0f\n\x07\x63ommand\x18\x01 \x01(\t\"3\n ExecuteCommandInTerminalResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x32\xf4\x05\n\x10WorkspaceService\x12T\n\x11getWorkspacePaths\x12\x1e.host.GetWorkspacePathsRequest\x1a\x1f.host.GetWorkspacePathsResponse\x12\x66\n\x17saveOpenDocumentIfDirty\x12$.host.SaveOpenDocumentIfDirtyRequest\x1a%.host.SaveOpenDocumentIfDirtyResponse\x12K\n\x0egetDiagnostics\x12\x1b.host.GetDiagnosticsRequest\x1a\x1c.host.GetDiagnosticsResponse\x12T\n\x11openProblemsPanel\x12\x1e.host.OpenProblemsPanelRequest\x1a\x1f.host.OpenProblemsPanelResponse\x12\x66\n\x17openInFileExplorerPanel\x12$.host.OpenInFileExplorerPanelRequest\x1a%.host.OpenInFileExplorerPanelResponse\x12`\n\x15openClineSidebarPanel\x12\".host.OpenClineSidebarPanelRequest\x1a#.host.OpenClineSidebarPanelResponse\x12J\n\x11openTerminalPanel\x12\x19.host.OpenTerminalRequest\x1a\x1a.host.OpenTerminalResponse\x12i\n\x18\x65xecuteCommandInTerminal\x12%.host.ExecuteCommandInTerminalRequest\x1a&.host.ExecuteCommandInTerminalResponseB7\n\x14\x62ot.cline.host.protoP\x01Z\x1dgithub.com/cline/grpc-go/hostb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'host.workspace_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\024bot.cline.host.protoP\001Z\035github.com/cline/grpc-go/host'
  _globals['_GETWORKSPACEPATHSREQUEST']._serialized_start=50
  _globals['_GETWORKSPACEPATHSREQUEST']._serialized_end=100
  _globals['_GETWORKSPACEPATHSRESPONSE']._serialized_start=102
  _globals['_GETWORKSPACEPATHSRESPONSE']._serialized_end=168
  _globals['_SAVEOPENDOCUMENTIFDIRTYREQUEST']._serialized_start=170
  _globals['_SAVEOPENDOCUMENTIFDIRTYREQUEST']._serialized_end=240
  _globals['_SAVEOPENDOCUMENTIFDIRTYRESPONSE']._serialized_start=242
  _globals['_SAVEOPENDOCUMENTIFDIRTYRESPONSE']._serialized_end=313
  _globals['_GETDIAGNOSTICSREQUEST']._serialized_start=315
  _globals['_GETDIAGNOSTICSREQUEST']._serialized_end=391
  _globals['_GETDIAGNOSTICSRESPONSE']._serialized_start=393
  _globals['_GETDIAGNOSTICSRESPONSE']._serialized_end=467
  _globals['_SEARCHWORKSPACEITEMSREQUEST']._serialized_start=470
  _globals['_SEARCHWORKSPACEITEMSREQUEST']._serialized_end=680
  _globals['_SEARCHWORKSPACEITEMSREQUEST_SEARCHITEMTYPE']._serialized_start=614
  _globals['_SEARCHWORKSPACEITEMSREQUEST_SEARCHITEMTYPE']._serialized_end=652
  _globals['_SEARCHWORKSPACEITEMSRESPONSE']._serialized_start=683
  _globals['_SEARCHWORKSPACEITEMSRESPONSE']._serialized_end=897
  _globals['_SEARCHWORKSPACEITEMSRESPONSE_SEARCHITEM']._serialized_start=777
  _globals['_SEARCHWORKSPACEITEMSRESPONSE_SEARCHITEM']._serialized_end=897
  _globals['_OPENPROBLEMSPANELREQUEST']._serialized_start=899
  _globals['_OPENPROBLEMSPANELREQUEST']._serialized_end=925
  _globals['_OPENPROBLEMSPANELRESPONSE']._serialized_start=927
  _globals['_OPENPROBLEMSPANELRESPONSE']._serialized_end=954
  _globals['_OPENINFILEEXPLORERPANELREQUEST']._serialized_start=956
  _globals['_OPENINFILEEXPLORERPANELREQUEST']._serialized_end=1002
  _globals['_OPENINFILEEXPLORERPANELRESPONSE']._serialized_start=1004
  _globals['_OPENINFILEEXPLORERPANELRESPONSE']._serialized_end=1037
  _globals['_OPENCLINESIDEBARPANELREQUEST']._serialized_start=1039
  _globals['_OPENCLINESIDEBARPANELREQUEST']._serialized_end=1069
  _globals['_OPENCLINESIDEBARPANELRESPONSE']._serialized_start=1071
  _globals['_OPENCLINESIDEBARPANELRESPONSE']._serialized_end=1102
  _globals['_OPENTERMINALREQUEST']._serialized_start=1104
  _globals['_OPENTERMINALREQUEST']._serialized_end=1125
  _globals['_OPENTERMINALRESPONSE']._serialized_start=1127
  _globals['_OPENTERMINALRESPONSE']._serialized_end=1149
  _globals['_EXECUTECOMMANDINTERMINALREQUEST']._serialized_start=1151
  _globals['_EXECUTECOMMANDINTERMINALREQUEST']._serialized_end=1201
  _globals['_EXECUTECOMMANDINTERMINALRESPONSE']._serialized_start=1203
  _globals['_EXECUTECOMMANDINTERMINALRESPONSE']._serialized_end=1254
  _globals['_WORKSPACESERVICE']._serialized_start=1257
  _globals['_WORKSPACESERVICE']._serialized_end=2013
# @@protoc_insertion_point(module_scope)
