# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from cline_core.proto.cline import common_pb2 as cline_dot_common__pb2
from cline_core.proto.cline import state_pb2 as cline_dot_state__pb2

GRPC_GENERATED_VERSION = '1.76.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + ' but the generated code in cline/state_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class StateServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.getLatestState = channel.unary_unary(
                '/cline.StateService/getLatestState',
                request_serializer=cline_dot_common__pb2.EmptyRequest.SerializeToString,
                response_deserializer=cline_dot_state__pb2.State.FromString,
                _registered_method=True)
        self.updateTerminalConnectionTimeout = channel.unary_unary(
                '/cline.StateService/updateTerminalConnectionTimeout',
                request_serializer=cline_dot_state__pb2.UpdateTerminalConnectionTimeoutRequest.SerializeToString,
                response_deserializer=cline_dot_state__pb2.UpdateTerminalConnectionTimeoutResponse.FromString,
                _registered_method=True)
        self.updateTerminalReuseEnabled = channel.unary_unary(
                '/cline.StateService/updateTerminalReuseEnabled',
                request_serializer=cline_dot_common__pb2.BooleanRequest.SerializeToString,
                response_deserializer=cline_dot_common__pb2.Empty.FromString,
                _registered_method=True)
        self.getAvailableTerminalProfiles = channel.unary_unary(
                '/cline.StateService/getAvailableTerminalProfiles',
                request_serializer=cline_dot_common__pb2.EmptyRequest.SerializeToString,
                response_deserializer=cline_dot_state__pb2.TerminalProfiles.FromString,
                _registered_method=True)
        self.subscribeToState = channel.unary_stream(
                '/cline.StateService/subscribeToState',
                request_serializer=cline_dot_common__pb2.EmptyRequest.SerializeToString,
                response_deserializer=cline_dot_state__pb2.State.FromString,
                _registered_method=True)
        self.toggleFavoriteModel = channel.unary_unary(
                '/cline.StateService/toggleFavoriteModel',
                request_serializer=cline_dot_common__pb2.StringRequest.SerializeToString,
                response_deserializer=cline_dot_common__pb2.Empty.FromString,
                _registered_method=True)
        self.resetState = channel.unary_unary(
                '/cline.StateService/resetState',
                request_serializer=cline_dot_state__pb2.ResetStateRequest.SerializeToString,
                response_deserializer=cline_dot_common__pb2.Empty.FromString,
                _registered_method=True)
        self.togglePlanActModeProto = channel.unary_unary(
                '/cline.StateService/togglePlanActModeProto',
                request_serializer=cline_dot_state__pb2.TogglePlanActModeRequest.SerializeToString,
                response_deserializer=cline_dot_common__pb2.Boolean.FromString,
                _registered_method=True)
        self.updateAutoApprovalSettings = channel.unary_unary(
                '/cline.StateService/updateAutoApprovalSettings',
                request_serializer=cline_dot_state__pb2.AutoApprovalSettingsRequest.SerializeToString,
                response_deserializer=cline_dot_common__pb2.Empty.FromString,
                _registered_method=True)
        self.updateSettings = channel.unary_unary(
                '/cline.StateService/updateSettings',
                request_serializer=cline_dot_state__pb2.UpdateSettingsRequest.SerializeToString,
                response_deserializer=cline_dot_common__pb2.Empty.FromString,
                _registered_method=True)
        self.updateSettingsCli = channel.unary_unary(
                '/cline.StateService/updateSettingsCli',
                request_serializer=cline_dot_state__pb2.UpdateSettingsRequestCli.SerializeToString,
                response_deserializer=cline_dot_common__pb2.Empty.FromString,
                _registered_method=True)
        self.updateTaskSettings = channel.unary_unary(
                '/cline.StateService/updateTaskSettings',
                request_serializer=cline_dot_state__pb2.UpdateTaskSettingsRequest.SerializeToString,
                response_deserializer=cline_dot_common__pb2.Empty.FromString,
                _registered_method=True)
        self.updateTelemetrySetting = channel.unary_unary(
                '/cline.StateService/updateTelemetrySetting',
                request_serializer=cline_dot_state__pb2.TelemetrySettingRequest.SerializeToString,
                response_deserializer=cline_dot_common__pb2.Empty.FromString,
                _registered_method=True)
        self.setWelcomeViewCompleted = channel.unary_unary(
                '/cline.StateService/setWelcomeViewCompleted',
                request_serializer=cline_dot_common__pb2.BooleanRequest.SerializeToString,
                response_deserializer=cline_dot_common__pb2.Empty.FromString,
                _registered_method=True)
        self.updateInfoBannerVersion = channel.unary_unary(
                '/cline.StateService/updateInfoBannerVersion',
                request_serializer=cline_dot_common__pb2.Int64Request.SerializeToString,
                response_deserializer=cline_dot_common__pb2.Empty.FromString,
                _registered_method=True)
        self.updateModelBannerVersion = channel.unary_unary(
                '/cline.StateService/updateModelBannerVersion',
                request_serializer=cline_dot_common__pb2.Int64Request.SerializeToString,
                response_deserializer=cline_dot_common__pb2.Empty.FromString,
                _registered_method=True)
        self.updateCliBannerVersion = channel.unary_unary(
                '/cline.StateService/updateCliBannerVersion',
                request_serializer=cline_dot_common__pb2.Int64Request.SerializeToString,
                response_deserializer=cline_dot_common__pb2.Empty.FromString,
                _registered_method=True)
        self.installClineCli = channel.unary_unary(
                '/cline.StateService/installClineCli',
                request_serializer=cline_dot_common__pb2.EmptyRequest.SerializeToString,
                response_deserializer=cline_dot_common__pb2.Empty.FromString,
                _registered_method=True)
        self.checkCliInstallation = channel.unary_unary(
                '/cline.StateService/checkCliInstallation',
                request_serializer=cline_dot_common__pb2.EmptyRequest.SerializeToString,
                response_deserializer=cline_dot_common__pb2.Boolean.FromString,
                _registered_method=True)
        self.getProcessInfo = channel.unary_unary(
                '/cline.StateService/getProcessInfo',
                request_serializer=cline_dot_common__pb2.EmptyRequest.SerializeToString,
                response_deserializer=cline_dot_state__pb2.ProcessInfo.FromString,
                _registered_method=True)


class StateServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def getLatestState(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def updateTerminalConnectionTimeout(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def updateTerminalReuseEnabled(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getAvailableTerminalProfiles(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def subscribeToState(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def toggleFavoriteModel(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def resetState(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def togglePlanActModeProto(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def updateAutoApprovalSettings(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def updateSettings(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def updateSettingsCli(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def updateTaskSettings(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def updateTelemetrySetting(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def setWelcomeViewCompleted(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def updateInfoBannerVersion(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def updateModelBannerVersion(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def updateCliBannerVersion(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def installClineCli(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def checkCliInstallation(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getProcessInfo(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_StateServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'getLatestState': grpc.unary_unary_rpc_method_handler(
                    servicer.getLatestState,
                    request_deserializer=cline_dot_common__pb2.EmptyRequest.FromString,
                    response_serializer=cline_dot_state__pb2.State.SerializeToString,
            ),
            'updateTerminalConnectionTimeout': grpc.unary_unary_rpc_method_handler(
                    servicer.updateTerminalConnectionTimeout,
                    request_deserializer=cline_dot_state__pb2.UpdateTerminalConnectionTimeoutRequest.FromString,
                    response_serializer=cline_dot_state__pb2.UpdateTerminalConnectionTimeoutResponse.SerializeToString,
            ),
            'updateTerminalReuseEnabled': grpc.unary_unary_rpc_method_handler(
                    servicer.updateTerminalReuseEnabled,
                    request_deserializer=cline_dot_common__pb2.BooleanRequest.FromString,
                    response_serializer=cline_dot_common__pb2.Empty.SerializeToString,
            ),
            'getAvailableTerminalProfiles': grpc.unary_unary_rpc_method_handler(
                    servicer.getAvailableTerminalProfiles,
                    request_deserializer=cline_dot_common__pb2.EmptyRequest.FromString,
                    response_serializer=cline_dot_state__pb2.TerminalProfiles.SerializeToString,
            ),
            'subscribeToState': grpc.unary_stream_rpc_method_handler(
                    servicer.subscribeToState,
                    request_deserializer=cline_dot_common__pb2.EmptyRequest.FromString,
                    response_serializer=cline_dot_state__pb2.State.SerializeToString,
            ),
            'toggleFavoriteModel': grpc.unary_unary_rpc_method_handler(
                    servicer.toggleFavoriteModel,
                    request_deserializer=cline_dot_common__pb2.StringRequest.FromString,
                    response_serializer=cline_dot_common__pb2.Empty.SerializeToString,
            ),
            'resetState': grpc.unary_unary_rpc_method_handler(
                    servicer.resetState,
                    request_deserializer=cline_dot_state__pb2.ResetStateRequest.FromString,
                    response_serializer=cline_dot_common__pb2.Empty.SerializeToString,
            ),
            'togglePlanActModeProto': grpc.unary_unary_rpc_method_handler(
                    servicer.togglePlanActModeProto,
                    request_deserializer=cline_dot_state__pb2.TogglePlanActModeRequest.FromString,
                    response_serializer=cline_dot_common__pb2.Boolean.SerializeToString,
            ),
            'updateAutoApprovalSettings': grpc.unary_unary_rpc_method_handler(
                    servicer.updateAutoApprovalSettings,
                    request_deserializer=cline_dot_state__pb2.AutoApprovalSettingsRequest.FromString,
                    response_serializer=cline_dot_common__pb2.Empty.SerializeToString,
            ),
            'updateSettings': grpc.unary_unary_rpc_method_handler(
                    servicer.updateSettings,
                    request_deserializer=cline_dot_state__pb2.UpdateSettingsRequest.FromString,
                    response_serializer=cline_dot_common__pb2.Empty.SerializeToString,
            ),
            'updateSettingsCli': grpc.unary_unary_rpc_method_handler(
                    servicer.updateSettingsCli,
                    request_deserializer=cline_dot_state__pb2.UpdateSettingsRequestCli.FromString,
                    response_serializer=cline_dot_common__pb2.Empty.SerializeToString,
            ),
            'updateTaskSettings': grpc.unary_unary_rpc_method_handler(
                    servicer.updateTaskSettings,
                    request_deserializer=cline_dot_state__pb2.UpdateTaskSettingsRequest.FromString,
                    response_serializer=cline_dot_common__pb2.Empty.SerializeToString,
            ),
            'updateTelemetrySetting': grpc.unary_unary_rpc_method_handler(
                    servicer.updateTelemetrySetting,
                    request_deserializer=cline_dot_state__pb2.TelemetrySettingRequest.FromString,
                    response_serializer=cline_dot_common__pb2.Empty.SerializeToString,
            ),
            'setWelcomeViewCompleted': grpc.unary_unary_rpc_method_handler(
                    servicer.setWelcomeViewCompleted,
                    request_deserializer=cline_dot_common__pb2.BooleanRequest.FromString,
                    response_serializer=cline_dot_common__pb2.Empty.SerializeToString,
            ),
            'updateInfoBannerVersion': grpc.unary_unary_rpc_method_handler(
                    servicer.updateInfoBannerVersion,
                    request_deserializer=cline_dot_common__pb2.Int64Request.FromString,
                    response_serializer=cline_dot_common__pb2.Empty.SerializeToString,
            ),
            'updateModelBannerVersion': grpc.unary_unary_rpc_method_handler(
                    servicer.updateModelBannerVersion,
                    request_deserializer=cline_dot_common__pb2.Int64Request.FromString,
                    response_serializer=cline_dot_common__pb2.Empty.SerializeToString,
            ),
            'updateCliBannerVersion': grpc.unary_unary_rpc_method_handler(
                    servicer.updateCliBannerVersion,
                    request_deserializer=cline_dot_common__pb2.Int64Request.FromString,
                    response_serializer=cline_dot_common__pb2.Empty.SerializeToString,
            ),
            'installClineCli': grpc.unary_unary_rpc_method_handler(
                    servicer.installClineCli,
                    request_deserializer=cline_dot_common__pb2.EmptyRequest.FromString,
                    response_serializer=cline_dot_common__pb2.Empty.SerializeToString,
            ),
            'checkCliInstallation': grpc.unary_unary_rpc_method_handler(
                    servicer.checkCliInstallation,
                    request_deserializer=cline_dot_common__pb2.EmptyRequest.FromString,
                    response_serializer=cline_dot_common__pb2.Boolean.SerializeToString,
            ),
            'getProcessInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.getProcessInfo,
                    request_deserializer=cline_dot_common__pb2.EmptyRequest.FromString,
                    response_serializer=cline_dot_state__pb2.ProcessInfo.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'cline.StateService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('cline.StateService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class StateService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def getLatestState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.StateService/getLatestState',
            cline_dot_common__pb2.EmptyRequest.SerializeToString,
            cline_dot_state__pb2.State.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def updateTerminalConnectionTimeout(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.StateService/updateTerminalConnectionTimeout',
            cline_dot_state__pb2.UpdateTerminalConnectionTimeoutRequest.SerializeToString,
            cline_dot_state__pb2.UpdateTerminalConnectionTimeoutResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def updateTerminalReuseEnabled(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.StateService/updateTerminalReuseEnabled',
            cline_dot_common__pb2.BooleanRequest.SerializeToString,
            cline_dot_common__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def getAvailableTerminalProfiles(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.StateService/getAvailableTerminalProfiles',
            cline_dot_common__pb2.EmptyRequest.SerializeToString,
            cline_dot_state__pb2.TerminalProfiles.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def subscribeToState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/cline.StateService/subscribeToState',
            cline_dot_common__pb2.EmptyRequest.SerializeToString,
            cline_dot_state__pb2.State.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def toggleFavoriteModel(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.StateService/toggleFavoriteModel',
            cline_dot_common__pb2.StringRequest.SerializeToString,
            cline_dot_common__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def resetState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.StateService/resetState',
            cline_dot_state__pb2.ResetStateRequest.SerializeToString,
            cline_dot_common__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def togglePlanActModeProto(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.StateService/togglePlanActModeProto',
            cline_dot_state__pb2.TogglePlanActModeRequest.SerializeToString,
            cline_dot_common__pb2.Boolean.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def updateAutoApprovalSettings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.StateService/updateAutoApprovalSettings',
            cline_dot_state__pb2.AutoApprovalSettingsRequest.SerializeToString,
            cline_dot_common__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def updateSettings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.StateService/updateSettings',
            cline_dot_state__pb2.UpdateSettingsRequest.SerializeToString,
            cline_dot_common__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def updateSettingsCli(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.StateService/updateSettingsCli',
            cline_dot_state__pb2.UpdateSettingsRequestCli.SerializeToString,
            cline_dot_common__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def updateTaskSettings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.StateService/updateTaskSettings',
            cline_dot_state__pb2.UpdateTaskSettingsRequest.SerializeToString,
            cline_dot_common__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def updateTelemetrySetting(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.StateService/updateTelemetrySetting',
            cline_dot_state__pb2.TelemetrySettingRequest.SerializeToString,
            cline_dot_common__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def setWelcomeViewCompleted(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.StateService/setWelcomeViewCompleted',
            cline_dot_common__pb2.BooleanRequest.SerializeToString,
            cline_dot_common__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def updateInfoBannerVersion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.StateService/updateInfoBannerVersion',
            cline_dot_common__pb2.Int64Request.SerializeToString,
            cline_dot_common__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def updateModelBannerVersion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.StateService/updateModelBannerVersion',
            cline_dot_common__pb2.Int64Request.SerializeToString,
            cline_dot_common__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def updateCliBannerVersion(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.StateService/updateCliBannerVersion',
            cline_dot_common__pb2.Int64Request.SerializeToString,
            cline_dot_common__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def installClineCli(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.StateService/installClineCli',
            cline_dot_common__pb2.EmptyRequest.SerializeToString,
            cline_dot_common__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def checkCliInstallation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.StateService/checkCliInstallation',
            cline_dot_common__pb2.EmptyRequest.SerializeToString,
            cline_dot_common__pb2.Boolean.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def getProcessInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/cline.StateService/getProcessInfo',
            cline_dot_common__pb2.EmptyRequest.SerializeToString,
            cline_dot_state__pb2.ProcessInfo.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
