# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cline/hooks.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'cline/hooks.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x63line/hooks.proto\x12\x05\x63line\"\x8e\x04\n\tHookInput\x12\x15\n\rcline_version\x18\x01 \x01(\t\x12\x11\n\thook_name\x18\x02 \x01(\t\x12\x11\n\ttimestamp\x18\x03 \x01(\t\x12\x0f\n\x07task_id\x18\x04 \x01(\t\x12\x17\n\x0fworkspace_roots\x18\x05 \x03(\t\x12\x0f\n\x07user_id\x18\x06 \x01(\t\x12-\n\x0cpre_tool_use\x18\n \x01(\x0b\x32\x15.cline.PreToolUseDataH\x00\x12/\n\rpost_tool_use\x18\x0b \x01(\x0b\x32\x16.cline.PostToolUseDataH\x00\x12\x39\n\x12user_prompt_submit\x18\x0c \x01(\x0b\x32\x1b.cline.UserPromptSubmitDataH\x00\x12*\n\ntask_start\x18\r \x01(\x0b\x32\x14.cline.TaskStartDataH\x00\x12,\n\x0btask_resume\x18\x0e \x01(\x0b\x32\x15.cline.TaskResumeDataH\x00\x12,\n\x0btask_cancel\x18\x0f \x01(\x0b\x32\x15.cline.TaskCancelDataH\x00\x12\x30\n\rtask_complete\x18\x10 \x01(\x0b\x32\x17.cline.TaskCompleteDataH\x00\x12,\n\x0bpre_compact\x18\x11 \x01(\x0b\x32\x15.cline.PreCompactDataH\x00\x42\x06\n\x04\x64\x61ta\"Q\n\nHookOutput\x12\x1c\n\x14\x63ontext_modification\x18\x01 \x01(\t\x12\x0e\n\x06\x63\x61ncel\x18\x02 \x01(\x08\x12\x15\n\rerror_message\x18\x03 \x01(\t\"\x91\x01\n\x0ePreToolUseData\x12\x11\n\ttool_name\x18\x01 \x01(\t\x12\x39\n\nparameters\x18\x02 \x03(\x0b\x32%.cline.PreToolUseData.ParametersEntry\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xcf\x01\n\x0fPostToolUseData\x12\x11\n\ttool_name\x18\x01 \x01(\t\x12:\n\nparameters\x18\x02 \x03(\x0b\x32&.cline.PostToolUseData.ParametersEntry\x12\x0e\n\x06result\x18\x03 \x01(\t\x12\x0f\n\x07success\x18\x04 \x01(\x08\x12\x19\n\x11\x65xecution_time_ms\x18\x05 \x01(\x03\x1a\x31\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\";\n\x14UserPromptSubmitData\x12\x0e\n\x06prompt\x18\x01 \x01(\t\x12\x13\n\x0b\x61ttachments\x18\x02 \x03(\t\"\x83\x01\n\rTaskStartData\x12=\n\rtask_metadata\x18\x01 \x03(\x0b\x32&.cline.TaskStartData.TaskMetadataEntry\x1a\x33\n\x11TaskMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xfd\x01\n\x0eTaskResumeData\x12>\n\rtask_metadata\x18\x01 \x03(\x0b\x32\'.cline.TaskResumeData.TaskMetadataEntry\x12@\n\x0eprevious_state\x18\x02 \x03(\x0b\x32(.cline.TaskResumeData.PreviousStateEntry\x1a\x33\n\x11TaskMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x34\n\x12PreviousStateEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x85\x01\n\x0eTaskCancelData\x12>\n\rtask_metadata\x18\x01 \x03(\x0b\x32\'.cline.TaskCancelData.TaskMetadataEntry\x1a\x33\n\x11TaskMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x89\x01\n\x10TaskCompleteData\x12@\n\rtask_metadata\x18\x01 \x03(\x0b\x32).cline.TaskCompleteData.TaskMetadataEntry\x1a\x33\n\x11TaskMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"`\n\x0ePreCompactData\x12\x14\n\x0c\x63ontext_size\x18\x01 \x01(\x03\x12\x1b\n\x13messages_to_compact\x18\x02 \x01(\x05\x12\x1b\n\x13\x63ompaction_strategy\x18\x03 \x01(\tB3\n\x0f\x62ot.cline.protoP\x01Z\x1egithub.com/cline/grpc-go/clineb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cline.hooks_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017bot.cline.protoP\001Z\036github.com/cline/grpc-go/cline'
  _globals['_PRETOOLUSEDATA_PARAMETERSENTRY']._loaded_options = None
  _globals['_PRETOOLUSEDATA_PARAMETERSENTRY']._serialized_options = b'8\001'
  _globals['_POSTTOOLUSEDATA_PARAMETERSENTRY']._loaded_options = None
  _globals['_POSTTOOLUSEDATA_PARAMETERSENTRY']._serialized_options = b'8\001'
  _globals['_TASKSTARTDATA_TASKMETADATAENTRY']._loaded_options = None
  _globals['_TASKSTARTDATA_TASKMETADATAENTRY']._serialized_options = b'8\001'
  _globals['_TASKRESUMEDATA_TASKMETADATAENTRY']._loaded_options = None
  _globals['_TASKRESUMEDATA_TASKMETADATAENTRY']._serialized_options = b'8\001'
  _globals['_TASKRESUMEDATA_PREVIOUSSTATEENTRY']._loaded_options = None
  _globals['_TASKRESUMEDATA_PREVIOUSSTATEENTRY']._serialized_options = b'8\001'
  _globals['_TASKCANCELDATA_TASKMETADATAENTRY']._loaded_options = None
  _globals['_TASKCANCELDATA_TASKMETADATAENTRY']._serialized_options = b'8\001'
  _globals['_TASKCOMPLETEDATA_TASKMETADATAENTRY']._loaded_options = None
  _globals['_TASKCOMPLETEDATA_TASKMETADATAENTRY']._serialized_options = b'8\001'
  _globals['_HOOKINPUT']._serialized_start=29
  _globals['_HOOKINPUT']._serialized_end=555
  _globals['_HOOKOUTPUT']._serialized_start=557
  _globals['_HOOKOUTPUT']._serialized_end=638
  _globals['_PRETOOLUSEDATA']._serialized_start=641
  _globals['_PRETOOLUSEDATA']._serialized_end=786
  _globals['_PRETOOLUSEDATA_PARAMETERSENTRY']._serialized_start=737
  _globals['_PRETOOLUSEDATA_PARAMETERSENTRY']._serialized_end=786
  _globals['_POSTTOOLUSEDATA']._serialized_start=789
  _globals['_POSTTOOLUSEDATA']._serialized_end=996
  _globals['_POSTTOOLUSEDATA_PARAMETERSENTRY']._serialized_start=737
  _globals['_POSTTOOLUSEDATA_PARAMETERSENTRY']._serialized_end=786
  _globals['_USERPROMPTSUBMITDATA']._serialized_start=998
  _globals['_USERPROMPTSUBMITDATA']._serialized_end=1057
  _globals['_TASKSTARTDATA']._serialized_start=1060
  _globals['_TASKSTARTDATA']._serialized_end=1191
  _globals['_TASKSTARTDATA_TASKMETADATAENTRY']._serialized_start=1140
  _globals['_TASKSTARTDATA_TASKMETADATAENTRY']._serialized_end=1191
  _globals['_TASKRESUMEDATA']._serialized_start=1194
  _globals['_TASKRESUMEDATA']._serialized_end=1447
  _globals['_TASKRESUMEDATA_TASKMETADATAENTRY']._serialized_start=1140
  _globals['_TASKRESUMEDATA_TASKMETADATAENTRY']._serialized_end=1191
  _globals['_TASKRESUMEDATA_PREVIOUSSTATEENTRY']._serialized_start=1395
  _globals['_TASKRESUMEDATA_PREVIOUSSTATEENTRY']._serialized_end=1447
  _globals['_TASKCANCELDATA']._serialized_start=1450
  _globals['_TASKCANCELDATA']._serialized_end=1583
  _globals['_TASKCANCELDATA_TASKMETADATAENTRY']._serialized_start=1140
  _globals['_TASKCANCELDATA_TASKMETADATAENTRY']._serialized_end=1191
  _globals['_TASKCOMPLETEDATA']._serialized_start=1586
  _globals['_TASKCOMPLETEDATA']._serialized_end=1723
  _globals['_TASKCOMPLETEDATA_TASKMETADATAENTRY']._serialized_start=1140
  _globals['_TASKCOMPLETEDATA_TASKMETADATAENTRY']._serialized_end=1191
  _globals['_PRECOMPACTDATA']._serialized_start=1725
  _globals['_PRECOMPACTDATA']._serialized_end=1821
# @@protoc_insertion_point(module_scope)
