# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cline/commands.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'cline/commands.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cline_core.proto.cline import common_pb2 as cline_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14\x63line/commands.proto\x12\x05\x63line\x1a\x12\x63line/common.proto\"\xb0\x01\n\x0e\x43ommandContext\x12\x16\n\tfile_path\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1a\n\rselected_text\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x15\n\x08language\x18\x03 \x01(\tH\x02\x88\x01\x01\x12&\n\x0b\x64iagnostics\x18\x04 \x03(\x0b\x32\x11.cline.DiagnosticB\x0c\n\n_file_pathB\x10\n\x0e_selected_textB\x0b\n\t_language2\xeb\x01\n\x0f\x43ommandsService\x12\x31\n\naddToCline\x12\x15.cline.CommandContext\x1a\x0c.cline.Empty\x12\x33\n\x0c\x66ixWithCline\x12\x15.cline.CommandContext\x1a\x0c.cline.Empty\x12\x37\n\x10\x65xplainWithCline\x12\x15.cline.CommandContext\x1a\x0c.cline.Empty\x12\x37\n\x10improveWithCline\x12\x15.cline.CommandContext\x1a\x0c.cline.EmptyB3\n\x0f\x62ot.cline.protoP\x01Z\x1egithub.com/cline/grpc-go/clineb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cline.commands_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017bot.cline.protoP\001Z\036github.com/cline/grpc-go/cline'
  _globals['_COMMANDCONTEXT']._serialized_start=52
  _globals['_COMMANDCONTEXT']._serialized_end=228
  _globals['_COMMANDSSERVICE']._serialized_start=231
  _globals['_COMMANDSSERVICE']._serialized_end=466
# @@protoc_insertion_point(module_scope)
