# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: host/testing.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'host/testing.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12host/testing.proto\x12\x04host\"\x17\n\x15GetWebviewHtmlRequest\"4\n\x16GetWebviewHtmlResponse\x12\x11\n\x04html\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x07\n\x05_html2]\n\x0eTestingService\x12K\n\x0egetWebviewHtml\x12\x1b.host.GetWebviewHtmlRequest\x1a\x1c.host.GetWebviewHtmlResponseB7\n\x14\x62ot.cline.host.protoP\x01Z\x1dgithub.com/cline/grpc-go/hostb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'host.testing_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\024bot.cline.host.protoP\001Z\035github.com/cline/grpc-go/host'
  _globals['_GETWEBVIEWHTMLREQUEST']._serialized_start=28
  _globals['_GETWEBVIEWHTMLREQUEST']._serialized_end=51
  _globals['_GETWEBVIEWHTMLRESPONSE']._serialized_start=53
  _globals['_GETWEBVIEWHTMLRESPONSE']._serialized_end=105
  _globals['_TESTINGSERVICE']._serialized_start=107
  _globals['_TESTINGSERVICE']._serialized_end=200
# @@protoc_insertion_point(module_scope)
