# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cline/models.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'cline/models.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cline_core.proto.cline import common_pb2 as cline_dot_common__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12\x63line/models.proto\x12\x05\x63line\x1a\x12\x63line/common.proto\x1a google/protobuf/field_mask.proto\"G\n\x13VsCodeLmModelsArray\x12\x30\n\x06models\x18\x01 \x03(\x0b\x32 .cline.LanguageModelChatSelector\"\x95\x01\n\x19LanguageModelChatSelector\x12\x13\n\x06vendor\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06\x66\x61mily\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x14\n\x07version\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x0f\n\x02id\x18\x04 \x01(\tH\x03\x88\x01\x01\x42\t\n\x07_vendorB\t\n\x07_familyB\n\n\x08_versionB\x05\n\x03_id\"/\n\tPriceTier\x12\x13\n\x0btoken_limit\x18\x01 \x01(\x03\x12\r\n\x05price\x18\x02 \x01(\x01\"\x92\x01\n\x0eThinkingConfig\x12\x17\n\nmax_budget\x18\x01 \x01(\x03H\x00\x88\x01\x01\x12\x19\n\x0coutput_price\x18\x02 \x01(\x01H\x01\x88\x01\x01\x12,\n\x12output_price_tiers\x18\x03 \x03(\x0b\x32\x10.cline.PriceTierB\r\n\x0b_max_budgetB\x0f\n\r_output_price\"\xe7\x01\n\tModelTier\x12\x16\n\x0e\x63ontext_window\x18\x01 \x01(\x03\x12\x18\n\x0binput_price\x18\x02 \x01(\x01H\x00\x88\x01\x01\x12\x19\n\x0coutput_price\x18\x03 \x01(\x01H\x01\x88\x01\x01\x12\x1f\n\x12\x63\x61\x63he_writes_price\x18\x04 \x01(\x01H\x02\x88\x01\x01\x12\x1e\n\x11\x63\x61\x63he_reads_price\x18\x05 \x01(\x01H\x03\x88\x01\x01\x42\x0e\n\x0c_input_priceB\x0f\n\r_output_priceB\x15\n\x13_cache_writes_priceB\x14\n\x12_cache_reads_price\"\xda\x04\n\x13OpenRouterModelInfo\x12\x17\n\nmax_tokens\x18\x01 \x01(\x03H\x00\x88\x01\x01\x12\x1b\n\x0e\x63ontext_window\x18\x02 \x01(\x03H\x01\x88\x01\x01\x12\x1c\n\x0fsupports_images\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\x1d\n\x15supports_prompt_cache\x18\x04 \x01(\x08\x12\x18\n\x0binput_price\x18\x05 \x01(\x01H\x03\x88\x01\x01\x12\x19\n\x0coutput_price\x18\x06 \x01(\x01H\x04\x88\x01\x01\x12\x1f\n\x12\x63\x61\x63he_writes_price\x18\x07 \x01(\x01H\x05\x88\x01\x01\x12\x1e\n\x11\x63\x61\x63he_reads_price\x18\x08 \x01(\x01H\x06\x88\x01\x01\x12\x18\n\x0b\x64\x65scription\x18\t \x01(\tH\x07\x88\x01\x01\x12\x33\n\x0fthinking_config\x18\n \x01(\x0b\x32\x15.cline.ThinkingConfigH\x08\x88\x01\x01\x12%\n\x18supports_global_endpoint\x18\x0b \x01(\x08H\t\x88\x01\x01\x12\x1f\n\x05tiers\x18\x0c \x03(\x0b\x32\x10.cline.ModelTierB\r\n\x0b_max_tokensB\x11\n\x0f_context_windowB\x12\n\x10_supports_imagesB\x0e\n\x0c_input_priceB\x0f\n\r_output_priceB\x15\n\x13_cache_writes_priceB\x14\n\x12_cache_reads_priceB\x0e\n\x0c_descriptionB\x12\n\x10_thinking_configB\x1b\n\x19_supports_global_endpoint\"\xac\x01\n\x1dOpenRouterCompatibleModelInfo\x12@\n\x06models\x18\x01 \x03(\x0b\x32\x30.cline.OpenRouterCompatibleModelInfo.ModelsEntry\x1aI\n\x0bModelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x1a.cline.OpenRouterModelInfo:\x02\x38\x01\"[\n\x13OpenAiModelsRequest\x12!\n\x08metadata\x18\x01 \x01(\x0b\x32\x0f.cline.Metadata\x12\x10\n\x08\x62\x61se_url\x18\x02 \x01(\t\x12\x0f\n\x07\x61pi_key\x18\x03 \x01(\t\"\xa2\x01\n\x16SapAiCoreModelsRequest\x12!\n\x08metadata\x18\x01 \x01(\x0b\x32\x0f.cline.Metadata\x12\x11\n\tclient_id\x18\x02 \x01(\t\x12\x15\n\rclient_secret\x18\x03 \x01(\t\x12\x10\n\x08\x62\x61se_url\x18\x04 \x01(\t\x12\x11\n\ttoken_url\x18\x05 \x01(\t\x12\x16\n\x0eresource_group\x18\x06 \x01(\t\"E\n\x18SapAiCoreModelDeployment\x12\x12\n\nmodel_name\x18\x01 \x01(\t\x12\x15\n\rdeployment_id\x18\x02 \x01(\t\"p\n\x17SapAiCoreModelsResponse\x12\x34\n\x0b\x64\x65ployments\x18\x01 \x03(\x0b\x32\x1f.cline.SapAiCoreModelDeployment\x12\x1f\n\x17orchestration_available\x18\x02 \x01(\x08\"\xf8\x0f\n\x10ModelsApiSecrets\x12\x14\n\x07\x61pi_key\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1a\n\rcline_api_key\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x1d\n\x10lite_llm_api_key\x18\x03 \x01(\tH\x02\x88\x01\x01\x12 \n\x13open_router_api_key\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x1b\n\x0e\x61ws_access_key\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x1b\n\x0e\x61ws_secret_key\x18\x06 \x01(\tH\x05\x88\x01\x01\x12\x1e\n\x11\x61ws_session_token\x18\x07 \x01(\tH\x06\x88\x01\x01\x12 \n\x13\x61ws_bedrock_api_key\x18\x08 \x01(\tH\x07\x88\x01\x01\x12\x1c\n\x0fopen_ai_api_key\x18\t \x01(\tH\x08\x88\x01\x01\x12\x1b\n\x0eollama_api_key\x18\n \x01(\tH\t\x88\x01\x01\x12\x1b\n\x0egemini_api_key\x18\x0b \x01(\tH\n\x88\x01\x01\x12#\n\x16open_ai_native_api_key\x18\x0c \x01(\tH\x0b\x88\x01\x01\x12\x1e\n\x11\x64\x65\x65p_seek_api_key\x18\r \x01(\tH\x0c\x88\x01\x01\x12\x1d\n\x10requesty_api_key\x18\x0e \x01(\tH\r\x88\x01\x01\x12\x1d\n\x10together_api_key\x18\x0f \x01(\tH\x0e\x88\x01\x01\x12\x1e\n\x11\x66ireworks_api_key\x18\x10 \x01(\tH\x0f\x88\x01\x01\x12\x19\n\x0cqwen_api_key\x18\x11 \x01(\tH\x10\x88\x01\x01\x12\x1b\n\x0e\x64oubao_api_key\x18\x12 \x01(\tH\x11\x88\x01\x01\x12\x1c\n\x0fmistral_api_key\x18\x13 \x01(\tH\x12\x88\x01\x01\x12\x1b\n\x0enebius_api_key\x18\x14 \x01(\tH\x13\x88\x01\x01\x12\x1c\n\x0f\x61sksage_api_key\x18\x15 \x01(\tH\x14\x88\x01\x01\x12\x18\n\x0bxai_api_key\x18\x16 \x01(\tH\x15\x88\x01\x01\x12\x1e\n\x11sambanova_api_key\x18\x17 \x01(\tH\x16\x88\x01\x01\x12\x1d\n\x10\x63\x65rebras_api_key\x18\x18 \x01(\tH\x17\x88\x01\x01\x12\"\n\x15sap_ai_core_client_id\x18\x19 \x01(\tH\x18\x88\x01\x01\x12&\n\x19sap_ai_core_client_secret\x18\x1a \x01(\tH\x19\x88\x01\x01\x12\x1d\n\x10moonshot_api_key\x18\x1b \x01(\tH\x1a\x88\x01\x01\x12\x1d\n\x10\x63line_account_id\x18\x1c \x01(\tH\x1b\x88\x01\x01\x12\x19\n\x0cgroq_api_key\x18\x1d \x01(\tH\x1c\x88\x01\x01\x12!\n\x14hugging_face_api_key\x18\x1e \x01(\tH\x1d\x88\x01\x01\x12&\n\x19huawei_cloud_maas_api_key\x18\x1f \x01(\tH\x1e\x88\x01\x01\x12\x1c\n\x0f\x62\x61seten_api_key\x18  \x01(\tH\x1f\x88\x01\x01\x12\x18\n\x0bzai_api_key\x18! \x01(\tH \x88\x01\x01\x12&\n\x19vercel_ai_gateway_api_key\x18\" \x01(\tH!\x88\x01\x01\x12\x19\n\x0c\x64ify_api_key\x18# \x01(\tH\"\x88\x01\x01\x12\x18\n\x0boca_api_key\x18$ \x01(\tH#\x88\x01\x01\x12\x1e\n\x11oca_refresh_token\x18% \x01(\tH$\x88\x01\x01\x12\x1c\n\x0fminimax_api_key\x18& \x01(\tH%\x88\x01\x01\x12\x1d\n\x10\x61ihubmix_api_key\x18\' \x01(\tH&\x88\x01\x01\x42\n\n\x08_api_keyB\x10\n\x0e_cline_api_keyB\x13\n\x11_lite_llm_api_keyB\x16\n\x14_open_router_api_keyB\x11\n\x0f_aws_access_keyB\x11\n\x0f_aws_secret_keyB\x14\n\x12_aws_session_tokenB\x16\n\x14_aws_bedrock_api_keyB\x12\n\x10_open_ai_api_keyB\x11\n\x0f_ollama_api_keyB\x11\n\x0f_gemini_api_keyB\x19\n\x17_open_ai_native_api_keyB\x14\n\x12_deep_seek_api_keyB\x13\n\x11_requesty_api_keyB\x13\n\x11_together_api_keyB\x14\n\x12_fireworks_api_keyB\x0f\n\r_qwen_api_keyB\x11\n\x0f_doubao_api_keyB\x12\n\x10_mistral_api_keyB\x11\n\x0f_nebius_api_keyB\x12\n\x10_asksage_api_keyB\x0e\n\x0c_xai_api_keyB\x14\n\x12_sambanova_api_keyB\x13\n\x11_cerebras_api_keyB\x18\n\x16_sap_ai_core_client_idB\x1c\n\x1a_sap_ai_core_client_secretB\x13\n\x11_moonshot_api_keyB\x13\n\x11_cline_account_idB\x0f\n\r_groq_api_keyB\x17\n\x15_hugging_face_api_keyB\x1c\n\x1a_huawei_cloud_maas_api_keyB\x12\n\x10_baseten_api_keyB\x0e\n\x0c_zai_api_keyB\x1c\n\x1a_vercel_ai_gateway_api_keyB\x0f\n\r_dify_api_keyB\x0e\n\x0c_oca_api_keyB\x14\n\x12_oca_refresh_tokenB\x12\n\x10_minimax_api_keyB\x13\n\x11_aihubmix_api_key\"\xbb\x44\n\x10ModelsApiOptions\x12\x11\n\x04ulid\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1e\n\x11lite_llm_base_url\x18\x02 \x01(\tH\x01\x88\x01\x01\x12&\n\x19lite_llm_use_prompt_cache\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\x43\n\x0fopen_ai_headers\x18\x04 \x03(\x0b\x32*.cline.ModelsApiOptions.OpenAiHeadersEntry\x12\x1f\n\x12\x61nthropic_base_url\x18\x05 \x01(\tH\x03\x88\x01\x01\x12)\n\x1copen_router_provider_sorting\x18\x06 \x01(\tH\x04\x88\x01\x01\x12\x17\n\naws_region\x18\x07 \x01(\tH\x05\x88\x01\x01\x12+\n\x1e\x61ws_use_cross_region_inference\x18\x08 \x01(\x08H\x06\x88\x01\x01\x12)\n\x1c\x61ws_bedrock_use_prompt_cache\x18\t \x01(\x08H\x07\x88\x01\x01\x12\x1c\n\x0f\x61ws_use_profile\x18\n \x01(\x08H\x08\x88\x01\x01\x12\x18\n\x0b\x61ws_profile\x18\x0b \x01(\tH\t\x88\x01\x01\x12!\n\x14\x61ws_bedrock_endpoint\x18\x0c \x01(\tH\n\x88\x01\x01\x12\x1d\n\x10\x63laude_code_path\x18\r \x01(\tH\x0b\x88\x01\x01\x12\x1e\n\x11vertex_project_id\x18\x0e \x01(\tH\x0c\x88\x01\x01\x12\x1a\n\rvertex_region\x18\x0f \x01(\tH\r\x88\x01\x01\x12\x1d\n\x10open_ai_base_url\x18\x10 \x01(\tH\x0e\x88\x01\x01\x12\x1c\n\x0follama_base_url\x18\x11 \x01(\tH\x0f\x88\x01\x01\x12\'\n\x1aollama_api_options_ctx_num\x18\x12 \x01(\tH\x10\x88\x01\x01\x12\x1f\n\x12lm_studio_base_url\x18\x13 \x01(\tH\x11\x88\x01\x01\x12\x1c\n\x0fgemini_base_url\x18\x14 \x01(\tH\x12\x88\x01\x01\x12\x1e\n\x11requesty_base_url\x18\x15 \x01(\tH\x13\x88\x01\x01\x12\x32\n%fireworks_model_max_completion_tokens\x18\x16 \x01(\x03H\x14\x88\x01\x01\x12\'\n\x1a\x66ireworks_model_max_tokens\x18\x17 \x01(\x03H\x15\x88\x01\x01\x12\x1e\n\x11\x61zure_api_version\x18\x18 \x01(\tH\x16\x88\x01\x01\x12\x1a\n\rqwen_api_line\x18\x19 \x01(\tH\x17\x88\x01\x01\x12\x1c\n\x0f\x61sksage_api_url\x18\x1a \x01(\tH\x18\x88\x01\x01\x12\x1f\n\x12request_timeout_ms\x18\x1b \x01(\x03H\x19\x88\x01\x01\x12\"\n\x15sap_ai_resource_group\x18\x1c \x01(\tH\x1a\x88\x01\x01\x12\"\n\x15sap_ai_core_token_url\x18\x1d \x01(\tH\x1b\x88\x01\x01\x12!\n\x14sap_ai_core_base_url\x18\x1e \x01(\tH\x1c\x88\x01\x01\x12/\n\"sap_ai_core_use_orchestration_mode\x18\x1f \x01(\x08H\x1d\x88\x01\x01\x12\x1e\n\x11moonshot_api_line\x18  \x01(\tH\x1e\x88\x01\x01\x12\x1f\n\x12\x61ws_authentication\x18! \x01(\tH\x1f\x88\x01\x01\x12\x19\n\x0czai_api_line\x18\" \x01(\tH \x88\x01\x01\x12!\n\x14lm_studio_max_tokens\x18# \x01(\tH!\x88\x01\x01\x12!\n\x14qwen_code_oauth_path\x18$ \x01(\tH\"\x88\x01\x01\x12\x1a\n\rdify_base_url\x18% \x01(\tH#\x88\x01\x01\x12\x19\n\x0coca_base_url\x18& \x01(\tH$\x88\x01\x01\x12\x15\n\x08oca_mode\x18\' \x01(\tH%\x88\x01\x01\x12%\n\x18\x61ws_use_global_inference\x18( \x01(\x08H&\x88\x01\x01\x12\x1d\n\x10minimax_api_line\x18) \x01(\tH\'\x88\x01\x01\x12\x1e\n\x11\x61ihubmix_base_url\x18* \x01(\tH(\x88\x01\x01\x12\x1e\n\x11\x61ihubmix_app_code\x18+ \x01(\tH)\x88\x01\x01\x12\x37\n\x16plan_mode_api_provider\x18\x64 \x01(\x0e\x32\x12.cline.ApiProviderH*\x88\x01\x01\x12#\n\x16plan_mode_api_model_id\x18\x65 \x01(\tH+\x88\x01\x01\x12-\n plan_mode_thinking_budget_tokens\x18\x66 \x01(\x03H,\x88\x01\x01\x12\'\n\x1aplan_mode_reasoning_effort\x18g \x01(\tH-\x88\x01\x01\x12R\n#plan_mode_vs_code_lm_model_selector\x18h \x01(\x0b\x32 .cline.LanguageModelChatSelectorH.\x88\x01\x01\x12\x32\n%plan_mode_aws_bedrock_custom_selected\x18i \x01(\x08H/\x88\x01\x01\x12\x37\n*plan_mode_aws_bedrock_custom_model_base_id\x18j \x01(\tH0\x88\x01\x01\x12+\n\x1eplan_mode_open_router_model_id\x18k \x01(\tH1\x88\x01\x01\x12I\n plan_mode_open_router_model_info\x18l \x01(\x0b\x32\x1a.cline.OpenRouterModelInfoH2\x88\x01\x01\x12\'\n\x1aplan_mode_open_ai_model_id\x18m \x01(\tH3\x88\x01\x01\x12K\n\x1cplan_mode_open_ai_model_info\x18n \x01(\x0b\x32 .cline.OpenAiCompatibleModelInfoH4\x88\x01\x01\x12&\n\x19plan_mode_ollama_model_id\x18o \x01(\tH5\x88\x01\x01\x12)\n\x1cplan_mode_lm_studio_model_id\x18p \x01(\tH6\x88\x01\x01\x12(\n\x1bplan_mode_lite_llm_model_id\x18q \x01(\tH7\x88\x01\x01\x12\x43\n\x1dplan_mode_lite_llm_model_info\x18r \x01(\x0b\x32\x17.cline.LiteLLMModelInfoH8\x88\x01\x01\x12(\n\x1bplan_mode_requesty_model_id\x18s \x01(\tH9\x88\x01\x01\x12\x46\n\x1dplan_mode_requesty_model_info\x18t \x01(\x0b\x32\x1a.cline.OpenRouterModelInfoH:\x88\x01\x01\x12(\n\x1bplan_mode_together_model_id\x18u \x01(\tH;\x88\x01\x01\x12)\n\x1cplan_mode_fireworks_model_id\x18v \x01(\tH<\x88\x01\x01\x12+\n\x1eplan_mode_sap_ai_core_model_id\x18w \x01(\tH=\x88\x01\x01\x12\x30\n#plan_mode_sap_ai_core_deployment_id\x18x \x01(\tH>\x88\x01\x01\x12$\n\x17plan_mode_groq_model_id\x18y \x01(\tH?\x88\x01\x01\x12\x42\n\x19plan_mode_groq_model_info\x18z \x01(\x0b\x32\x1a.cline.OpenRouterModelInfoH@\x88\x01\x01\x12,\n\x1fplan_mode_hugging_face_model_id\x18{ \x01(\tHA\x88\x01\x01\x12J\n!plan_mode_hugging_face_model_info\x18| \x01(\x0b\x32\x1a.cline.OpenRouterModelInfoHB\x88\x01\x01\x12\x31\n$plan_mode_huawei_cloud_maas_model_id\x18} \x01(\tHC\x88\x01\x01\x12O\n&plan_mode_huawei_cloud_maas_model_info\x18~ \x01(\x0b\x32\x1a.cline.OpenRouterModelInfoHD\x88\x01\x01\x12\'\n\x1aplan_mode_baseten_model_id\x18\x7f \x01(\tHE\x88\x01\x01\x12\x46\n\x1cplan_mode_baseten_model_info\x18\x80\x01 \x01(\x0b\x32\x1a.cline.OpenRouterModelInfoHF\x88\x01\x01\x12\x32\n$plan_mode_vercel_ai_gateway_model_id\x18\x81\x01 \x01(\tHG\x88\x01\x01\x12P\n&plan_mode_vercel_ai_gateway_model_info\x18\x82\x01 \x01(\x0b\x32\x1a.cline.OpenRouterModelInfoHH\x88\x01\x01\x12$\n\x16plan_mode_oca_model_id\x18\x83\x01 \x01(\tHI\x88\x01\x01\x12;\n\x18plan_mode_oca_model_info\x18\x84\x01 \x01(\x0b\x32\x13.cline.OcaModelInfoHJ\x88\x01\x01\x12)\n\x1bplan_mode_aihubmix_model_id\x18\x85\x01 \x01(\tHK\x88\x01\x01\x12M\n\x1dplan_mode_aihubmix_model_info\x18\x86\x01 \x01(\x0b\x32 .cline.OpenAiCompatibleModelInfoHL\x88\x01\x01\x12\x37\n\x15\x61\x63t_mode_api_provider\x18\xc8\x01 \x01(\x0e\x32\x12.cline.ApiProviderHM\x88\x01\x01\x12#\n\x15\x61\x63t_mode_api_model_id\x18\xc9\x01 \x01(\tHN\x88\x01\x01\x12-\n\x1f\x61\x63t_mode_thinking_budget_tokens\x18\xca\x01 \x01(\x03HO\x88\x01\x01\x12\'\n\x19\x61\x63t_mode_reasoning_effort\x18\xcb\x01 \x01(\tHP\x88\x01\x01\x12R\n\"act_mode_vs_code_lm_model_selector\x18\xcc\x01 \x01(\x0b\x32 .cline.LanguageModelChatSelectorHQ\x88\x01\x01\x12\x32\n$act_mode_aws_bedrock_custom_selected\x18\xcd\x01 \x01(\x08HR\x88\x01\x01\x12\x37\n)act_mode_aws_bedrock_custom_model_base_id\x18\xce\x01 \x01(\tHS\x88\x01\x01\x12+\n\x1d\x61\x63t_mode_open_router_model_id\x18\xcf\x01 \x01(\tHT\x88\x01\x01\x12I\n\x1f\x61\x63t_mode_open_router_model_info\x18\xd0\x01 \x01(\x0b\x32\x1a.cline.OpenRouterModelInfoHU\x88\x01\x01\x12\'\n\x19\x61\x63t_mode_open_ai_model_id\x18\xd1\x01 \x01(\tHV\x88\x01\x01\x12K\n\x1b\x61\x63t_mode_open_ai_model_info\x18\xd2\x01 \x01(\x0b\x32 .cline.OpenAiCompatibleModelInfoHW\x88\x01\x01\x12&\n\x18\x61\x63t_mode_ollama_model_id\x18\xd3\x01 \x01(\tHX\x88\x01\x01\x12)\n\x1b\x61\x63t_mode_lm_studio_model_id\x18\xd4\x01 \x01(\tHY\x88\x01\x01\x12(\n\x1a\x61\x63t_mode_lite_llm_model_id\x18\xd5\x01 \x01(\tHZ\x88\x01\x01\x12\x43\n\x1c\x61\x63t_mode_lite_llm_model_info\x18\xd6\x01 \x01(\x0b\x32\x17.cline.LiteLLMModelInfoH[\x88\x01\x01\x12(\n\x1a\x61\x63t_mode_requesty_model_id\x18\xd7\x01 \x01(\tH\\\x88\x01\x01\x12\x46\n\x1c\x61\x63t_mode_requesty_model_info\x18\xd8\x01 \x01(\x0b\x32\x1a.cline.OpenRouterModelInfoH]\x88\x01\x01\x12(\n\x1a\x61\x63t_mode_together_model_id\x18\xd9\x01 \x01(\tH^\x88\x01\x01\x12)\n\x1b\x61\x63t_mode_fireworks_model_id\x18\xda\x01 \x01(\tH_\x88\x01\x01\x12+\n\x1d\x61\x63t_mode_sap_ai_core_model_id\x18\xdb\x01 \x01(\tH`\x88\x01\x01\x12\x30\n\"act_mode_sap_ai_core_deployment_id\x18\xdc\x01 \x01(\tHa\x88\x01\x01\x12$\n\x16\x61\x63t_mode_groq_model_id\x18\xdd\x01 \x01(\tHb\x88\x01\x01\x12\x42\n\x18\x61\x63t_mode_groq_model_info\x18\xde\x01 \x01(\x0b\x32\x1a.cline.OpenRouterModelInfoHc\x88\x01\x01\x12,\n\x1e\x61\x63t_mode_hugging_face_model_id\x18\xdf\x01 \x01(\tHd\x88\x01\x01\x12J\n act_mode_hugging_face_model_info\x18\xe0\x01 \x01(\x0b\x32\x1a.cline.OpenRouterModelInfoHe\x88\x01\x01\x12\x31\n#act_mode_huawei_cloud_maas_model_id\x18\xe1\x01 \x01(\tHf\x88\x01\x01\x12O\n%act_mode_huawei_cloud_maas_model_info\x18\xe2\x01 \x01(\x0b\x32\x1a.cline.OpenRouterModelInfoHg\x88\x01\x01\x12\'\n\x19\x61\x63t_mode_baseten_model_id\x18\xe3\x01 \x01(\tHh\x88\x01\x01\x12\x45\n\x1b\x61\x63t_mode_baseten_model_info\x18\xe4\x01 \x01(\x0b\x32\x1a.cline.OpenRouterModelInfoHi\x88\x01\x01\x12\x31\n#act_mode_vercel_ai_gateway_model_id\x18\xe5\x01 \x01(\tHj\x88\x01\x01\x12O\n%act_mode_vercel_ai_gateway_model_info\x18\xe6\x01 \x01(\x0b\x32\x1a.cline.OpenRouterModelInfoHk\x88\x01\x01\x12#\n\x15\x61\x63t_mode_oca_model_id\x18\xe7\x01 \x01(\tHl\x88\x01\x01\x12:\n\x17\x61\x63t_mode_oca_model_info\x18\xe8\x01 \x01(\x0b\x32\x13.cline.OcaModelInfoHm\x88\x01\x01\x12(\n\x1a\x61\x63t_mode_aihubmix_model_id\x18\xe9\x01 \x01(\tHn\x88\x01\x01\x12L\n\x1c\x61\x63t_mode_aihubmix_model_info\x18\xea\x01 \x01(\x0b\x32 .cline.OpenAiCompatibleModelInfoHo\x88\x01\x01\x1a\x34\n\x12OpenAiHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x07\n\x05_ulidB\x14\n\x12_lite_llm_base_urlB\x1c\n\x1a_lite_llm_use_prompt_cacheB\x15\n\x13_anthropic_base_urlB\x1f\n\x1d_open_router_provider_sortingB\r\n\x0b_aws_regionB!\n\x1f_aws_use_cross_region_inferenceB\x1f\n\x1d_aws_bedrock_use_prompt_cacheB\x12\n\x10_aws_use_profileB\x0e\n\x0c_aws_profileB\x17\n\x15_aws_bedrock_endpointB\x13\n\x11_claude_code_pathB\x14\n\x12_vertex_project_idB\x10\n\x0e_vertex_regionB\x13\n\x11_open_ai_base_urlB\x12\n\x10_ollama_base_urlB\x1d\n\x1b_ollama_api_options_ctx_numB\x15\n\x13_lm_studio_base_urlB\x12\n\x10_gemini_base_urlB\x14\n\x12_requesty_base_urlB(\n&_fireworks_model_max_completion_tokensB\x1d\n\x1b_fireworks_model_max_tokensB\x14\n\x12_azure_api_versionB\x10\n\x0e_qwen_api_lineB\x12\n\x10_asksage_api_urlB\x15\n\x13_request_timeout_msB\x18\n\x16_sap_ai_resource_groupB\x18\n\x16_sap_ai_core_token_urlB\x17\n\x15_sap_ai_core_base_urlB%\n#_sap_ai_core_use_orchestration_modeB\x14\n\x12_moonshot_api_lineB\x15\n\x13_aws_authenticationB\x0f\n\r_zai_api_lineB\x17\n\x15_lm_studio_max_tokensB\x17\n\x15_qwen_code_oauth_pathB\x10\n\x0e_dify_base_urlB\x0f\n\r_oca_base_urlB\x0b\n\t_oca_modeB\x1b\n\x19_aws_use_global_inferenceB\x13\n\x11_minimax_api_lineB\x14\n\x12_aihubmix_base_urlB\x14\n\x12_aihubmix_app_codeB\x19\n\x17_plan_mode_api_providerB\x19\n\x17_plan_mode_api_model_idB#\n!_plan_mode_thinking_budget_tokensB\x1d\n\x1b_plan_mode_reasoning_effortB&\n$_plan_mode_vs_code_lm_model_selectorB(\n&_plan_mode_aws_bedrock_custom_selectedB-\n+_plan_mode_aws_bedrock_custom_model_base_idB!\n\x1f_plan_mode_open_router_model_idB#\n!_plan_mode_open_router_model_infoB\x1d\n\x1b_plan_mode_open_ai_model_idB\x1f\n\x1d_plan_mode_open_ai_model_infoB\x1c\n\x1a_plan_mode_ollama_model_idB\x1f\n\x1d_plan_mode_lm_studio_model_idB\x1e\n\x1c_plan_mode_lite_llm_model_idB \n\x1e_plan_mode_lite_llm_model_infoB\x1e\n\x1c_plan_mode_requesty_model_idB \n\x1e_plan_mode_requesty_model_infoB\x1e\n\x1c_plan_mode_together_model_idB\x1f\n\x1d_plan_mode_fireworks_model_idB!\n\x1f_plan_mode_sap_ai_core_model_idB&\n$_plan_mode_sap_ai_core_deployment_idB\x1a\n\x18_plan_mode_groq_model_idB\x1c\n\x1a_plan_mode_groq_model_infoB\"\n _plan_mode_hugging_face_model_idB$\n\"_plan_mode_hugging_face_model_infoB\'\n%_plan_mode_huawei_cloud_maas_model_idB)\n\'_plan_mode_huawei_cloud_maas_model_infoB\x1d\n\x1b_plan_mode_baseten_model_idB\x1f\n\x1d_plan_mode_baseten_model_infoB\'\n%_plan_mode_vercel_ai_gateway_model_idB)\n\'_plan_mode_vercel_ai_gateway_model_infoB\x19\n\x17_plan_mode_oca_model_idB\x1b\n\x19_plan_mode_oca_model_infoB\x1e\n\x1c_plan_mode_aihubmix_model_idB \n\x1e_plan_mode_aihubmix_model_infoB\x18\n\x16_act_mode_api_providerB\x18\n\x16_act_mode_api_model_idB\"\n _act_mode_thinking_budget_tokensB\x1c\n\x1a_act_mode_reasoning_effortB%\n#_act_mode_vs_code_lm_model_selectorB\'\n%_act_mode_aws_bedrock_custom_selectedB,\n*_act_mode_aws_bedrock_custom_model_base_idB \n\x1e_act_mode_open_router_model_idB\"\n _act_mode_open_router_model_infoB\x1c\n\x1a_act_mode_open_ai_model_idB\x1e\n\x1c_act_mode_open_ai_model_infoB\x1b\n\x19_act_mode_ollama_model_idB\x1e\n\x1c_act_mode_lm_studio_model_idB\x1d\n\x1b_act_mode_lite_llm_model_idB\x1f\n\x1d_act_mode_lite_llm_model_infoB\x1d\n\x1b_act_mode_requesty_model_idB\x1f\n\x1d_act_mode_requesty_model_infoB\x1d\n\x1b_act_mode_together_model_idB\x1e\n\x1c_act_mode_fireworks_model_idB \n\x1e_act_mode_sap_ai_core_model_idB%\n#_act_mode_sap_ai_core_deployment_idB\x19\n\x17_act_mode_groq_model_idB\x1b\n\x19_act_mode_groq_model_infoB!\n\x1f_act_mode_hugging_face_model_idB#\n!_act_mode_hugging_face_model_infoB&\n$_act_mode_huawei_cloud_maas_model_idB(\n&_act_mode_huawei_cloud_maas_model_infoB\x1c\n\x1a_act_mode_baseten_model_idB\x1e\n\x1c_act_mode_baseten_model_infoB&\n$_act_mode_vercel_ai_gateway_model_idB(\n&_act_mode_vercel_ai_gateway_model_infoB\x18\n\x16_act_mode_oca_model_idB\x1a\n\x18_act_mode_oca_model_infoB\x1d\n\x1b_act_mode_aihubmix_model_idB\x1f\n\x1d_act_mode_aihubmix_model_info\"|\n\x1dUpdateApiConfigurationRequest\x12!\n\x08metadata\x18\x01 \x01(\x0b\x32\x0f.cline.Metadata\x12\x38\n\x11\x61pi_configuration\x18\x02 \x01(\x0b\x32\x1d.cline.ModelsApiConfiguration\"f\n\x10\x41piConfiguration\x12(\n\x07options\x18\x01 \x01(\x0b\x32\x17.cline.ModelsApiOptions\x12(\n\x07secrets\x18\x02 \x01(\x0b\x32\x17.cline.ModelsApiSecrets\"\xaa\x01\n UpdateApiConfigurationRequestNew\x12!\n\x08metadata\x18\x01 \x01(\x0b\x32\x0f.cline.Metadata\x12\x32\n\x11\x61pi_configuration\x18\x02 \x01(\x0b\x32\x17.cline.ApiConfiguration\x12/\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\xb4\x01\n$UpdateApiConfigurationPartialRequest\x12!\n\x08metadata\x18\x01 \x01(\x0b\x32\x0f.cline.Metadata\x12\x38\n\x11\x61pi_configuration\x18\x02 \x01(\x0b\x32\x1d.cline.ModelsApiConfiguration\x12/\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\xa2\x05\n\x0cOcaModelInfo\x12\x17\n\nmax_tokens\x18\x01 \x01(\x03H\x00\x88\x01\x01\x12\x1b\n\x0e\x63ontext_window\x18\x02 \x01(\x03H\x01\x88\x01\x01\x12\x1c\n\x0fsupports_images\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\x1d\n\x15supports_prompt_cache\x18\x04 \x01(\x08\x12\x18\n\x0binput_price\x18\x05 \x01(\x01H\x03\x88\x01\x01\x12\x19\n\x0coutput_price\x18\x06 \x01(\x01H\x04\x88\x01\x01\x12\x33\n\x0fthinking_config\x18\x07 \x01(\x0b\x32\x15.cline.ThinkingConfigH\x05\x88\x01\x01\x12\x1f\n\x12\x63\x61\x63he_writes_price\x18\t \x01(\x01H\x06\x88\x01\x01\x12\x1e\n\x11\x63\x61\x63he_reads_price\x18\n \x01(\x01H\x07\x88\x01\x01\x12\x18\n\x0b\x64\x65scription\x18\x0b \x01(\tH\x08\x88\x01\x01\x12\x18\n\x0btemperature\x18\r \x01(\x01H\t\x88\x01\x01\x12\x1b\n\x0esurvey_content\x18\x0e \x01(\tH\n\x88\x01\x01\x12\x16\n\tsurvey_id\x18\x0f \x01(\tH\x0b\x88\x01\x01\x12\x13\n\x06\x62\x61nner\x18\x10 \x01(\tH\x0c\x88\x01\x01\x12\x12\n\nmodel_name\x18\x11 \x01(\tB\r\n\x0b_max_tokensB\x11\n\x0f_context_windowB\x12\n\x10_supports_imagesB\x0e\n\x0c_input_priceB\x0f\n\r_output_priceB\x12\n\x10_thinking_configB\x15\n\x13_cache_writes_priceB\x14\n\x12_cache_reads_priceB\x0e\n\x0c_descriptionB\x0e\n\x0c_temperatureB\x11\n\x0f_survey_contentB\x0c\n\n_survey_idB\t\n\x07_banner\"\xb5\x01\n\x16OcaCompatibleModelInfo\x12\x39\n\x06models\x18\x01 \x03(\x0b\x32).cline.OcaCompatibleModelInfo.ModelsEntry\x12\x12\n\x05\x65rror\x18\x02 \x01(\tH\x00\x88\x01\x01\x1a\x42\n\x0bModelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\"\n\x05value\x18\x02 \x01(\x0b\x32\x13.cline.OcaModelInfo:\x02\x38\x01\x42\x08\n\x06_error\"\xc8\x05\n\x19OpenAiCompatibleModelInfo\x12\x17\n\nmax_tokens\x18\x01 \x01(\x03H\x00\x88\x01\x01\x12\x1b\n\x0e\x63ontext_window\x18\x02 \x01(\x03H\x01\x88\x01\x01\x12\x1c\n\x0fsupports_images\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\x1d\n\x15supports_prompt_cache\x18\x04 \x01(\x08\x12\x18\n\x0binput_price\x18\x05 \x01(\x01H\x03\x88\x01\x01\x12\x19\n\x0coutput_price\x18\x06 \x01(\x01H\x04\x88\x01\x01\x12\x33\n\x0fthinking_config\x18\x07 \x01(\x0b\x32\x15.cline.ThinkingConfigH\x05\x88\x01\x01\x12%\n\x18supports_global_endpoint\x18\x08 \x01(\x08H\x06\x88\x01\x01\x12\x1f\n\x12\x63\x61\x63he_writes_price\x18\t \x01(\x01H\x07\x88\x01\x01\x12\x1e\n\x11\x63\x61\x63he_reads_price\x18\n \x01(\x01H\x08\x88\x01\x01\x12\x18\n\x0b\x64\x65scription\x18\x0b \x01(\tH\t\x88\x01\x01\x12\x1f\n\x05tiers\x18\x0c \x03(\x0b\x32\x10.cline.ModelTier\x12\x18\n\x0btemperature\x18\r \x01(\x01H\n\x88\x01\x01\x12\"\n\x15is_r1_format_required\x18\x0e \x01(\x08H\x0b\x88\x01\x01\x42\r\n\x0b_max_tokensB\x11\n\x0f_context_windowB\x12\n\x10_supports_imagesB\x0e\n\x0c_input_priceB\x0f\n\r_output_priceB\x12\n\x10_thinking_configB\x1b\n\x19_supports_global_endpointB\x15\n\x13_cache_writes_priceB\x14\n\x12_cache_reads_priceB\x0e\n\x0c_descriptionB\x0e\n\x0c_temperatureB\x18\n\x16_is_r1_format_required\"\x81\x05\n\x10LiteLLMModelInfo\x12\x17\n\nmax_tokens\x18\x01 \x01(\x03H\x00\x88\x01\x01\x12\x1b\n\x0e\x63ontext_window\x18\x02 \x01(\x03H\x01\x88\x01\x01\x12\x1c\n\x0fsupports_images\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12\x1d\n\x15supports_prompt_cache\x18\x04 \x01(\x08\x12\x18\n\x0binput_price\x18\x05 \x01(\x01H\x03\x88\x01\x01\x12\x19\n\x0coutput_price\x18\x06 \x01(\x01H\x04\x88\x01\x01\x12\x33\n\x0fthinking_config\x18\x07 \x01(\x0b\x32\x15.cline.ThinkingConfigH\x05\x88\x01\x01\x12%\n\x18supports_global_endpoint\x18\x08 \x01(\x08H\x06\x88\x01\x01\x12\x1f\n\x12\x63\x61\x63he_writes_price\x18\t \x01(\x01H\x07\x88\x01\x01\x12\x1e\n\x11\x63\x61\x63he_reads_price\x18\n \x01(\x01H\x08\x88\x01\x01\x12\x18\n\x0b\x64\x65scription\x18\x0b \x01(\tH\t\x88\x01\x01\x12\x1f\n\x05tiers\x18\x0c \x03(\x0b\x32\x10.cline.ModelTier\x12\x18\n\x0btemperature\x18\r \x01(\x01H\n\x88\x01\x01\x42\r\n\x0b_max_tokensB\x11\n\x0f_context_windowB\x12\n\x10_supports_imagesB\x0e\n\x0c_input_priceB\x0f\n\r_output_priceB\x12\n\x10_thinking_configB\x1b\n\x19_supports_global_endpointB\x15\n\x13_cache_writes_priceB\x14\n\x12_cache_reads_priceB\x0e\n\x0c_descriptionB\x0e\n\x0c_temperature\"\xf8W\n\x16ModelsApiConfiguration\x12\x14\n\x07\x61pi_key\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1a\n\rcline_api_key\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x11\n\x04ulid\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x1e\n\x11lite_llm_base_url\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x1d\n\x10lite_llm_api_key\x18\x05 \x01(\tH\x04\x88\x01\x01\x12&\n\x19lite_llm_use_prompt_cache\x18\x06 \x01(\x08H\x05\x88\x01\x01\x12I\n\x0fopen_ai_headers\x18\x07 \x03(\x0b\x32\x30.cline.ModelsApiConfiguration.OpenAiHeadersEntry\x12\x1f\n\x12\x61nthropic_base_url\x18\x08 \x01(\tH\x06\x88\x01\x01\x12 \n\x13open_router_api_key\x18\t \x01(\tH\x07\x88\x01\x01\x12)\n\x1copen_router_provider_sorting\x18\n \x01(\tH\x08\x88\x01\x01\x12\x1b\n\x0e\x61ws_access_key\x18\x0b \x01(\tH\t\x88\x01\x01\x12\x1b\n\x0e\x61ws_secret_key\x18\x0c \x01(\tH\n\x88\x01\x01\x12\x1e\n\x11\x61ws_session_token\x18\r \x01(\tH\x0b\x88\x01\x01\x12\x17\n\naws_region\x18\x0e \x01(\tH\x0c\x88\x01\x01\x12+\n\x1e\x61ws_use_cross_region_inference\x18\x0f \x01(\x08H\r\x88\x01\x01\x12)\n\x1c\x61ws_bedrock_use_prompt_cache\x18\x10 \x01(\x08H\x0e\x88\x01\x01\x12\x1c\n\x0f\x61ws_use_profile\x18\x11 \x01(\x08H\x0f\x88\x01\x01\x12\x18\n\x0b\x61ws_profile\x18\x12 \x01(\tH\x10\x88\x01\x01\x12!\n\x14\x61ws_bedrock_endpoint\x18\x13 \x01(\tH\x11\x88\x01\x01\x12\x1d\n\x10\x63laude_code_path\x18\x14 \x01(\tH\x12\x88\x01\x01\x12\x1e\n\x11vertex_project_id\x18\x15 \x01(\tH\x13\x88\x01\x01\x12\x1a\n\rvertex_region\x18\x16 \x01(\tH\x14\x88\x01\x01\x12\x1d\n\x10open_ai_base_url\x18\x17 \x01(\tH\x15\x88\x01\x01\x12\x1c\n\x0fopen_ai_api_key\x18\x18 \x01(\tH\x16\x88\x01\x01\x12\x1c\n\x0follama_base_url\x18\x19 \x01(\tH\x17\x88\x01\x01\x12\'\n\x1aollama_api_options_ctx_num\x18\x1a \x01(\tH\x18\x88\x01\x01\x12\x1f\n\x12lm_studio_base_url\x18\x1b \x01(\tH\x19\x88\x01\x01\x12\x1b\n\x0egemini_api_key\x18\x1c \x01(\tH\x1a\x88\x01\x01\x12\x1c\n\x0fgemini_base_url\x18\x1d \x01(\tH\x1b\x88\x01\x01\x12#\n\x16open_ai_native_api_key\x18\x1e \x01(\tH\x1c\x88\x01\x01\x12\x1e\n\x11\x64\x65\x65p_seek_api_key\x18\x1f \x01(\tH\x1d\x88\x01\x01\x12\x1d\n\x10requesty_api_key\x18  \x01(\tH\x1e\x88\x01\x01\x12\x1e\n\x11requesty_base_url\x18! \x01(\tH\x1f\x88\x01\x01\x12\x1d\n\x10together_api_key\x18\" \x01(\tH \x88\x01\x01\x12\x1e\n\x11\x66ireworks_api_key\x18# \x01(\tH!\x88\x01\x01\x12\x32\n%fireworks_model_max_completion_tokens\x18$ \x01(\x03H\"\x88\x01\x01\x12\'\n\x1a\x66ireworks_model_max_tokens\x18% \x01(\x03H#\x88\x01\x01\x12\x19\n\x0cqwen_api_key\x18& \x01(\tH$\x88\x01\x01\x12\x1b\n\x0e\x64oubao_api_key\x18\' \x01(\tH%\x88\x01\x01\x12\x1c\n\x0fmistral_api_key\x18( \x01(\tH&\x88\x01\x01\x12\x1e\n\x11\x61zure_api_version\x18) \x01(\tH\'\x88\x01\x01\x12\x1a\n\rqwen_api_line\x18* \x01(\tH(\x88\x01\x01\x12\x1b\n\x0enebius_api_key\x18+ \x01(\tH)\x88\x01\x01\x12\x1c\n\x0f\x61sksage_api_url\x18, \x01(\tH*\x88\x01\x01\x12\x1c\n\x0f\x61sksage_api_key\x18- \x01(\tH+\x88\x01\x01\x12\x18\n\x0bxai_api_key\x18. \x01(\tH,\x88\x01\x01\x12\x1e\n\x11sambanova_api_key\x18/ \x01(\tH-\x88\x01\x01\x12\x1d\n\x10\x63\x65rebras_api_key\x18\x30 \x01(\tH.\x88\x01\x01\x12\x1f\n\x12request_timeout_ms\x18\x31 \x01(\x03H/\x88\x01\x01\x12\"\n\x15sap_ai_core_client_id\x18\x32 \x01(\tH0\x88\x01\x01\x12&\n\x19sap_ai_core_client_secret\x18\x33 \x01(\tH1\x88\x01\x01\x12\"\n\x15sap_ai_resource_group\x18\x34 \x01(\tH2\x88\x01\x01\x12\"\n\x15sap_ai_core_token_url\x18\x35 \x01(\tH3\x88\x01\x01\x12!\n\x14sap_ai_core_base_url\x18\x36 \x01(\tH4\x88\x01\x01\x12/\n\"sap_ai_core_use_orchestration_mode\x18\x37 \x01(\x08H5\x88\x01\x01\x12\x1d\n\x10moonshot_api_key\x18\x38 \x01(\tH6\x88\x01\x01\x12\x1e\n\x11moonshot_api_line\x18\x39 \x01(\tH7\x88\x01\x01\x12\x1f\n\x12\x61ws_authentication\x18: \x01(\tH8\x88\x01\x01\x12 \n\x13\x61ws_bedrock_api_key\x18; \x01(\tH9\x88\x01\x01\x12\x1d\n\x10\x63line_account_id\x18< \x01(\tH:\x88\x01\x01\x12\x19\n\x0cgroq_api_key\x18= \x01(\tH;\x88\x01\x01\x12!\n\x14hugging_face_api_key\x18> \x01(\tH<\x88\x01\x01\x12&\n\x19huawei_cloud_maas_api_key\x18? \x01(\tH=\x88\x01\x01\x12\x1c\n\x0f\x62\x61seten_api_key\x18@ \x01(\tH>\x88\x01\x01\x12\x1b\n\x0eollama_api_key\x18\x41 \x01(\tH?\x88\x01\x01\x12\x18\n\x0bzai_api_key\x18\x42 \x01(\tH@\x88\x01\x01\x12\x19\n\x0czai_api_line\x18\x43 \x01(\tHA\x88\x01\x01\x12!\n\x14lm_studio_max_tokens\x18\x44 \x01(\tHB\x88\x01\x01\x12&\n\x19vercel_ai_gateway_api_key\x18\x45 \x01(\tHC\x88\x01\x01\x12!\n\x14qwen_code_oauth_path\x18\x46 \x01(\tHD\x88\x01\x01\x12\x19\n\x0c\x64ify_api_key\x18G \x01(\tHE\x88\x01\x01\x12\x1a\n\rdify_base_url\x18H \x01(\tHF\x88\x01\x01\x12\x19\n\x0coca_base_url\x18I \x01(\tHG\x88\x01\x01\x12\x18\n\x0boca_api_key\x18J \x01(\tHH\x88\x01\x01\x12\x1e\n\x11oca_refresh_token\x18K \x01(\tHI\x88\x01\x01\x12\x15\n\x08oca_mode\x18L \x01(\tHJ\x88\x01\x01\x12%\n\x18\x61ws_use_global_inference\x18M \x01(\x08HK\x88\x01\x01\x12\x1c\n\x0fminimax_api_key\x18N \x01(\tHL\x88\x01\x01\x12\x1d\n\x10minimax_api_line\x18O \x01(\tHM\x88\x01\x01\x12\x1b\n\x0ehicap_model_id\x18P \x01(\tHN\x88\x01\x01\x12\x1a\n\rhicap_api_key\x18Q \x01(\tHO\x88\x01\x01\x12\x1d\n\x10\x61ihubmix_api_key\x18R \x01(\tHP\x88\x01\x01\x12\x1e\n\x11\x61ihubmix_base_url\x18S \x01(\tHQ\x88\x01\x01\x12\x1e\n\x11\x61ihubmix_app_code\x18T \x01(\tHR\x88\x01\x01\x12\x37\n\x16plan_mode_api_provider\x18\x64 \x01(\x0e\x32\x12.cline.ApiProviderHS\x88\x01\x01\x12#\n\x16plan_mode_api_model_id\x18\x65 \x01(\tHT\x88\x01\x01\x12-\n plan_mode_thinking_budget_tokens\x18\x66 \x01(\x03HU\x88\x01\x01\x12\'\n\x1aplan_mode_reasoning_effort\x18g \x01(\tHV\x88\x01\x01\x12R\n#plan_mode_vs_code_lm_model_selector\x18h \x01(\x0b\x32 .cline.LanguageModelChatSelectorHW\x88\x01\x01\x12\x32\n%plan_mode_aws_bedrock_custom_selected\x18i \x01(\x08HX\x88\x01\x01\x12\x37\n*plan_mode_aws_bedrock_custom_model_base_id\x18j \x01(\tHY\x88\x01\x01\x12+\n\x1eplan_mode_open_router_model_id\x18k \x01(\tHZ\x88\x01\x01\x12I\n plan_mode_open_router_model_info\x18l \x01(\x0b\x32\x1a.cline.OpenRouterModelInfoH[\x88\x01\x01\x12\'\n\x1aplan_mode_open_ai_model_id\x18m \x01(\tH\\\x88\x01\x01\x12K\n\x1cplan_mode_open_ai_model_info\x18n \x01(\x0b\x32 .cline.OpenAiCompatibleModelInfoH]\x88\x01\x01\x12&\n\x19plan_mode_ollama_model_id\x18o \x01(\tH^\x88\x01\x01\x12)\n\x1cplan_mode_lm_studio_model_id\x18p \x01(\tH_\x88\x01\x01\x12(\n\x1bplan_mode_lite_llm_model_id\x18q \x01(\tH`\x88\x01\x01\x12\x43\n\x1dplan_mode_lite_llm_model_info\x18r \x01(\x0b\x32\x17.cline.LiteLLMModelInfoHa\x88\x01\x01\x12(\n\x1bplan_mode_requesty_model_id\x18s \x01(\tHb\x88\x01\x01\x12\x46\n\x1dplan_mode_requesty_model_info\x18t \x01(\x0b\x32\x1a.cline.OpenRouterModelInfoHc\x88\x01\x01\x12(\n\x1bplan_mode_together_model_id\x18u \x01(\tHd\x88\x01\x01\x12)\n\x1cplan_mode_fireworks_model_id\x18v \x01(\tHe\x88\x01\x01\x12+\n\x1eplan_mode_sap_ai_core_model_id\x18w \x01(\tHf\x88\x01\x01\x12\x30\n#plan_mode_sap_ai_core_deployment_id\x18x \x01(\tHg\x88\x01\x01\x12$\n\x17plan_mode_groq_model_id\x18y \x01(\tHh\x88\x01\x01\x12\x42\n\x19plan_mode_groq_model_info\x18z \x01(\x0b\x32\x1a.cline.OpenRouterModelInfoHi\x88\x01\x01\x12,\n\x1fplan_mode_hugging_face_model_id\x18{ \x01(\tHj\x88\x01\x01\x12J\n!plan_mode_hugging_face_model_info\x18| \x01(\x0b\x32\x1a.cline.OpenRouterModelInfoHk\x88\x01\x01\x12\x31\n$plan_mode_huawei_cloud_maas_model_id\x18} \x01(\tHl\x88\x01\x01\x12O\n&plan_mode_huawei_cloud_maas_model_info\x18~ \x01(\x0b\x32\x1a.cline.OpenRouterModelInfoHm\x88\x01\x01\x12\'\n\x1aplan_mode_baseten_model_id\x18\x7f \x01(\tHn\x88\x01\x01\x12\x46\n\x1cplan_mode_baseten_model_info\x18\x80\x01 \x01(\x0b\x32\x1a.cline.OpenRouterModelInfoHo\x88\x01\x01\x12\x32\n$plan_mode_vercel_ai_gateway_model_id\x18\x81\x01 \x01(\tHp\x88\x01\x01\x12P\n&plan_mode_vercel_ai_gateway_model_info\x18\x82\x01 \x01(\x0b\x32\x1a.cline.OpenRouterModelInfoHq\x88\x01\x01\x12$\n\x16plan_mode_oca_model_id\x18\x83\x01 \x01(\tHr\x88\x01\x01\x12;\n\x18plan_mode_oca_model_info\x18\x84\x01 \x01(\x0b\x32\x13.cline.OcaModelInfoHs\x88\x01\x01\x12&\n\x18plan_mode_hicap_model_id\x18\x85\x01 \x01(\tHt\x88\x01\x01\x12\x44\n\x1aplan_mode_hicap_model_info\x18\x86\x01 \x01(\x0b\x32\x1a.cline.OpenRouterModelInfoHu\x88\x01\x01\x12)\n\x1bplan_mode_aihubmix_model_id\x18\x87\x01 \x01(\tHv\x88\x01\x01\x12M\n\x1dplan_mode_aihubmix_model_info\x18\x88\x01 \x01(\x0b\x32 .cline.OpenAiCompatibleModelInfoHw\x88\x01\x01\x12\x37\n\x15\x61\x63t_mode_api_provider\x18\xc8\x01 \x01(\x0e\x32\x12.cline.ApiProviderHx\x88\x01\x01\x12#\n\x15\x61\x63t_mode_api_model_id\x18\xc9\x01 \x01(\tHy\x88\x01\x01\x12-\n\x1f\x61\x63t_mode_thinking_budget_tokens\x18\xca\x01 \x01(\x03Hz\x88\x01\x01\x12\'\n\x19\x61\x63t_mode_reasoning_effort\x18\xcb\x01 \x01(\tH{\x88\x01\x01\x12R\n\"act_mode_vs_code_lm_model_selector\x18\xcc\x01 \x01(\x0b\x32 .cline.LanguageModelChatSelectorH|\x88\x01\x01\x12\x32\n$act_mode_aws_bedrock_custom_selected\x18\xcd\x01 \x01(\x08H}\x88\x01\x01\x12\x37\n)act_mode_aws_bedrock_custom_model_base_id\x18\xce\x01 \x01(\tH~\x88\x01\x01\x12+\n\x1d\x61\x63t_mode_open_router_model_id\x18\xcf\x01 \x01(\tH\x7f\x88\x01\x01\x12J\n\x1f\x61\x63t_mode_open_router_model_info\x18\xd0\x01 \x01(\x0b\x32\x1a.cline.OpenRouterModelInfoH\x80\x01\x88\x01\x01\x12(\n\x19\x61\x63t_mode_open_ai_model_id\x18\xd1\x01 \x01(\tH\x81\x01\x88\x01\x01\x12L\n\x1b\x61\x63t_mode_open_ai_model_info\x18\xd2\x01 \x01(\x0b\x32 .cline.OpenAiCompatibleModelInfoH\x82\x01\x88\x01\x01\x12\'\n\x18\x61\x63t_mode_ollama_model_id\x18\xd3\x01 \x01(\tH\x83\x01\x88\x01\x01\x12*\n\x1b\x61\x63t_mode_lm_studio_model_id\x18\xd4\x01 \x01(\tH\x84\x01\x88\x01\x01\x12)\n\x1a\x61\x63t_mode_lite_llm_model_id\x18\xd5\x01 \x01(\tH\x85\x01\x88\x01\x01\x12\x44\n\x1c\x61\x63t_mode_lite_llm_model_info\x18\xd6\x01 \x01(\x0b\x32\x17.cline.LiteLLMModelInfoH\x86\x01\x88\x01\x01\x12)\n\x1a\x61\x63t_mode_requesty_model_id\x18\xd7\x01 \x01(\tH\x87\x01\x88\x01\x01\x12G\n\x1c\x61\x63t_mode_requesty_model_info\x18\xd8\x01 \x01(\x0b\x32\x1a.cline.OpenRouterModelInfoH\x88\x01\x88\x01\x01\x12)\n\x1a\x61\x63t_mode_together_model_id\x18\xd9\x01 \x01(\tH\x89\x01\x88\x01\x01\x12*\n\x1b\x61\x63t_mode_fireworks_model_id\x18\xda\x01 \x01(\tH\x8a\x01\x88\x01\x01\x12,\n\x1d\x61\x63t_mode_sap_ai_core_model_id\x18\xdb\x01 \x01(\tH\x8b\x01\x88\x01\x01\x12\x31\n\"act_mode_sap_ai_core_deployment_id\x18\xdc\x01 \x01(\tH\x8c\x01\x88\x01\x01\x12%\n\x16\x61\x63t_mode_groq_model_id\x18\xdd\x01 \x01(\tH\x8d\x01\x88\x01\x01\x12\x43\n\x18\x61\x63t_mode_groq_model_info\x18\xde\x01 \x01(\x0b\x32\x1a.cline.OpenRouterModelInfoH\x8e\x01\x88\x01\x01\x12-\n\x1e\x61\x63t_mode_hugging_face_model_id\x18\xdf\x01 \x01(\tH\x8f\x01\x88\x01\x01\x12K\n act_mode_hugging_face_model_info\x18\xe0\x01 \x01(\x0b\x32\x1a.cline.OpenRouterModelInfoH\x90\x01\x88\x01\x01\x12\x32\n#act_mode_huawei_cloud_maas_model_id\x18\xe1\x01 \x01(\tH\x91\x01\x88\x01\x01\x12P\n%act_mode_huawei_cloud_maas_model_info\x18\xe2\x01 \x01(\x0b\x32\x1a.cline.OpenRouterModelInfoH\x92\x01\x88\x01\x01\x12(\n\x19\x61\x63t_mode_baseten_model_id\x18\xe3\x01 \x01(\tH\x93\x01\x88\x01\x01\x12\x46\n\x1b\x61\x63t_mode_baseten_model_info\x18\xe4\x01 \x01(\x0b\x32\x1a.cline.OpenRouterModelInfoH\x94\x01\x88\x01\x01\x12\x32\n#act_mode_vercel_ai_gateway_model_id\x18\xe5\x01 \x01(\tH\x95\x01\x88\x01\x01\x12P\n%act_mode_vercel_ai_gateway_model_info\x18\xe6\x01 \x01(\x0b\x32\x1a.cline.OpenRouterModelInfoH\x96\x01\x88\x01\x01\x12$\n\x15\x61\x63t_mode_oca_model_id\x18\xe7\x01 \x01(\tH\x97\x01\x88\x01\x01\x12;\n\x17\x61\x63t_mode_oca_model_info\x18\xe8\x01 \x01(\x0b\x32\x13.cline.OcaModelInfoH\x98\x01\x88\x01\x01\x12&\n\x17\x61\x63t_mode_hicap_model_id\x18\xe9\x01 \x01(\tH\x99\x01\x88\x01\x01\x12\x44\n\x19\x61\x63t_mode_hicap_model_info\x18\xea\x01 \x01(\x0b\x32\x1a.cline.OpenRouterModelInfoH\x9a\x01\x88\x01\x01\x12)\n\x1a\x61\x63t_mode_aihubmix_model_id\x18\xeb\x01 \x01(\tH\x9b\x01\x88\x01\x01\x12M\n\x1c\x61\x63t_mode_aihubmix_model_info\x18\xec\x01 \x01(\x0b\x32 .cline.OpenAiCompatibleModelInfoH\x9c\x01\x88\x01\x01\x1a\x34\n\x12OpenAiHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\n\n\x08_api_keyB\x10\n\x0e_cline_api_keyB\x07\n\x05_ulidB\x14\n\x12_lite_llm_base_urlB\x13\n\x11_lite_llm_api_keyB\x1c\n\x1a_lite_llm_use_prompt_cacheB\x15\n\x13_anthropic_base_urlB\x16\n\x14_open_router_api_keyB\x1f\n\x1d_open_router_provider_sortingB\x11\n\x0f_aws_access_keyB\x11\n\x0f_aws_secret_keyB\x14\n\x12_aws_session_tokenB\r\n\x0b_aws_regionB!\n\x1f_aws_use_cross_region_inferenceB\x1f\n\x1d_aws_bedrock_use_prompt_cacheB\x12\n\x10_aws_use_profileB\x0e\n\x0c_aws_profileB\x17\n\x15_aws_bedrock_endpointB\x13\n\x11_claude_code_pathB\x14\n\x12_vertex_project_idB\x10\n\x0e_vertex_regionB\x13\n\x11_open_ai_base_urlB\x12\n\x10_open_ai_api_keyB\x12\n\x10_ollama_base_urlB\x1d\n\x1b_ollama_api_options_ctx_numB\x15\n\x13_lm_studio_base_urlB\x11\n\x0f_gemini_api_keyB\x12\n\x10_gemini_base_urlB\x19\n\x17_open_ai_native_api_keyB\x14\n\x12_deep_seek_api_keyB\x13\n\x11_requesty_api_keyB\x14\n\x12_requesty_base_urlB\x13\n\x11_together_api_keyB\x14\n\x12_fireworks_api_keyB(\n&_fireworks_model_max_completion_tokensB\x1d\n\x1b_fireworks_model_max_tokensB\x0f\n\r_qwen_api_keyB\x11\n\x0f_doubao_api_keyB\x12\n\x10_mistral_api_keyB\x14\n\x12_azure_api_versionB\x10\n\x0e_qwen_api_lineB\x11\n\x0f_nebius_api_keyB\x12\n\x10_asksage_api_urlB\x12\n\x10_asksage_api_keyB\x0e\n\x0c_xai_api_keyB\x14\n\x12_sambanova_api_keyB\x13\n\x11_cerebras_api_keyB\x15\n\x13_request_timeout_msB\x18\n\x16_sap_ai_core_client_idB\x1c\n\x1a_sap_ai_core_client_secretB\x18\n\x16_sap_ai_resource_groupB\x18\n\x16_sap_ai_core_token_urlB\x17\n\x15_sap_ai_core_base_urlB%\n#_sap_ai_core_use_orchestration_modeB\x13\n\x11_moonshot_api_keyB\x14\n\x12_moonshot_api_lineB\x15\n\x13_aws_authenticationB\x16\n\x14_aws_bedrock_api_keyB\x13\n\x11_cline_account_idB\x0f\n\r_groq_api_keyB\x17\n\x15_hugging_face_api_keyB\x1c\n\x1a_huawei_cloud_maas_api_keyB\x12\n\x10_baseten_api_keyB\x11\n\x0f_ollama_api_keyB\x0e\n\x0c_zai_api_keyB\x0f\n\r_zai_api_lineB\x17\n\x15_lm_studio_max_tokensB\x1c\n\x1a_vercel_ai_gateway_api_keyB\x17\n\x15_qwen_code_oauth_pathB\x0f\n\r_dify_api_keyB\x10\n\x0e_dify_base_urlB\x0f\n\r_oca_base_urlB\x0e\n\x0c_oca_api_keyB\x14\n\x12_oca_refresh_tokenB\x0b\n\t_oca_modeB\x1b\n\x19_aws_use_global_inferenceB\x12\n\x10_minimax_api_keyB\x13\n\x11_minimax_api_lineB\x11\n\x0f_hicap_model_idB\x10\n\x0e_hicap_api_keyB\x13\n\x11_aihubmix_api_keyB\x14\n\x12_aihubmix_base_urlB\x14\n\x12_aihubmix_app_codeB\x19\n\x17_plan_mode_api_providerB\x19\n\x17_plan_mode_api_model_idB#\n!_plan_mode_thinking_budget_tokensB\x1d\n\x1b_plan_mode_reasoning_effortB&\n$_plan_mode_vs_code_lm_model_selectorB(\n&_plan_mode_aws_bedrock_custom_selectedB-\n+_plan_mode_aws_bedrock_custom_model_base_idB!\n\x1f_plan_mode_open_router_model_idB#\n!_plan_mode_open_router_model_infoB\x1d\n\x1b_plan_mode_open_ai_model_idB\x1f\n\x1d_plan_mode_open_ai_model_infoB\x1c\n\x1a_plan_mode_ollama_model_idB\x1f\n\x1d_plan_mode_lm_studio_model_idB\x1e\n\x1c_plan_mode_lite_llm_model_idB \n\x1e_plan_mode_lite_llm_model_infoB\x1e\n\x1c_plan_mode_requesty_model_idB \n\x1e_plan_mode_requesty_model_infoB\x1e\n\x1c_plan_mode_together_model_idB\x1f\n\x1d_plan_mode_fireworks_model_idB!\n\x1f_plan_mode_sap_ai_core_model_idB&\n$_plan_mode_sap_ai_core_deployment_idB\x1a\n\x18_plan_mode_groq_model_idB\x1c\n\x1a_plan_mode_groq_model_infoB\"\n _plan_mode_hugging_face_model_idB$\n\"_plan_mode_hugging_face_model_infoB\'\n%_plan_mode_huawei_cloud_maas_model_idB)\n\'_plan_mode_huawei_cloud_maas_model_infoB\x1d\n\x1b_plan_mode_baseten_model_idB\x1f\n\x1d_plan_mode_baseten_model_infoB\'\n%_plan_mode_vercel_ai_gateway_model_idB)\n\'_plan_mode_vercel_ai_gateway_model_infoB\x19\n\x17_plan_mode_oca_model_idB\x1b\n\x19_plan_mode_oca_model_infoB\x1b\n\x19_plan_mode_hicap_model_idB\x1d\n\x1b_plan_mode_hicap_model_infoB\x1e\n\x1c_plan_mode_aihubmix_model_idB \n\x1e_plan_mode_aihubmix_model_infoB\x18\n\x16_act_mode_api_providerB\x18\n\x16_act_mode_api_model_idB\"\n _act_mode_thinking_budget_tokensB\x1c\n\x1a_act_mode_reasoning_effortB%\n#_act_mode_vs_code_lm_model_selectorB\'\n%_act_mode_aws_bedrock_custom_selectedB,\n*_act_mode_aws_bedrock_custom_model_base_idB \n\x1e_act_mode_open_router_model_idB\"\n _act_mode_open_router_model_infoB\x1c\n\x1a_act_mode_open_ai_model_idB\x1e\n\x1c_act_mode_open_ai_model_infoB\x1b\n\x19_act_mode_ollama_model_idB\x1e\n\x1c_act_mode_lm_studio_model_idB\x1d\n\x1b_act_mode_lite_llm_model_idB\x1f\n\x1d_act_mode_lite_llm_model_infoB\x1d\n\x1b_act_mode_requesty_model_idB\x1f\n\x1d_act_mode_requesty_model_infoB\x1d\n\x1b_act_mode_together_model_idB\x1e\n\x1c_act_mode_fireworks_model_idB \n\x1e_act_mode_sap_ai_core_model_idB%\n#_act_mode_sap_ai_core_deployment_idB\x19\n\x17_act_mode_groq_model_idB\x1b\n\x19_act_mode_groq_model_infoB!\n\x1f_act_mode_hugging_face_model_idB#\n!_act_mode_hugging_face_model_infoB&\n$_act_mode_huawei_cloud_maas_model_idB(\n&_act_mode_huawei_cloud_maas_model_infoB\x1c\n\x1a_act_mode_baseten_model_idB\x1e\n\x1c_act_mode_baseten_model_infoB&\n$_act_mode_vercel_ai_gateway_model_idB(\n&_act_mode_vercel_ai_gateway_model_infoB\x18\n\x16_act_mode_oca_model_idB\x1a\n\x18_act_mode_oca_model_infoB\x1a\n\x18_act_mode_hicap_model_idB\x1c\n\x1a_act_mode_hicap_model_infoB\x1d\n\x1b_act_mode_aihubmix_model_idB\x1f\n\x1d_act_mode_aihubmix_model_info*\xa1\x04\n\x0b\x41piProvider\x12\r\n\tANTHROPIC\x10\x00\x12\x0e\n\nOPENROUTER\x10\x01\x12\x0b\n\x07\x42\x45\x44ROCK\x10\x02\x12\n\n\x06VERTEX\x10\x03\x12\n\n\x06OPENAI\x10\x04\x12\n\n\x06OLLAMA\x10\x05\x12\x0c\n\x08LMSTUDIO\x10\x06\x12\n\n\x06GEMINI\x10\x07\x12\x11\n\rOPENAI_NATIVE\x10\x08\x12\x0c\n\x08REQUESTY\x10\t\x12\x0c\n\x08TOGETHER\x10\n\x12\x0c\n\x08\x44\x45\x45PSEEK\x10\x0b\x12\x08\n\x04QWEN\x10\x0c\x12\n\n\x06\x44OUBAO\x10\r\x12\x0b\n\x07MISTRAL\x10\x0e\x12\r\n\tVSCODE_LM\x10\x0f\x12\t\n\x05\x43LINE\x10\x10\x12\x0b\n\x07LITELLM\x10\x11\x12\n\n\x06NEBIUS\x10\x12\x12\r\n\tFIREWORKS\x10\x13\x12\x0b\n\x07\x41SKSAGE\x10\x14\x12\x07\n\x03XAI\x10\x15\x12\r\n\tSAMBANOVA\x10\x16\x12\x0c\n\x08\x43\x45REBRAS\x10\x17\x12\x08\n\x04GROQ\x10\x18\x12\r\n\tSAPAICORE\x10\x19\x12\x0f\n\x0b\x43LAUDE_CODE\x10\x1a\x12\x0c\n\x08MOONSHOT\x10\x1b\x12\x0f\n\x0bHUGGINGFACE\x10\x1c\x12\x15\n\x11HUAWEI_CLOUD_MAAS\x10\x1d\x12\x0b\n\x07\x42\x41SETEN\x10\x1e\x12\x07\n\x03ZAI\x10\x1f\x12\x15\n\x11VERCEL_AI_GATEWAY\x10 \x12\r\n\tQWEN_CODE\x10!\x12\x08\n\x04\x44IFY\x10\"\x12\x07\n\x03OCA\x10#\x12\x0b\n\x07MINIMAX\x10$\x12\t\n\x05HICAP\x10%\x12\x0c\n\x08\x41IHUBMIX\x10&2\xe0\n\n\rModelsService\x12;\n\x0fgetOllamaModels\x12\x14.cline.StringRequest\x1a\x12.cline.StringArray\x12=\n\x11getLmStudioModels\x12\x14.cline.StringRequest\x1a\x12.cline.StringArray\x12\x44\n\x11getVsCodeLmModels\x12\x13.cline.EmptyRequest\x1a\x1a.cline.VsCodeLmModelsArray\x12W\n\x1arefreshOpenRouterModelsRpc\x12\x13.cline.EmptyRequest\x1a$.cline.OpenRouterCompatibleModelInfo\x12U\n\x18refreshHuggingFaceModels\x12\x13.cline.EmptyRequest\x1a$.cline.OpenRouterCompatibleModelInfo\x12\x45\n\x13refreshOpenAiModels\x12\x1a.cline.OpenAiModelsRequest\x1a\x12.cline.StringArray\x12R\n\x15refreshRequestyModels\x12\x13.cline.EmptyRequest\x1a$.cline.OpenRouterCompatibleModelInfo\x12O\n\x12refreshHicapModels\x12\x13.cline.EmptyRequest\x1a$.cline.OpenRouterCompatibleModelInfo\x12Z\n\x1bsubscribeToOpenRouterModels\x12\x13.cline.EmptyRequest\x1a$.cline.OpenRouterCompatibleModelInfo0\x01\x12Q\n\x1bupdateApiConfigurationProto\x12$.cline.UpdateApiConfigurationRequest\x1a\x0c.cline.Empty\x12O\n\x16updateApiConfiguration\x12\'.cline.UpdateApiConfigurationRequestNew\x1a\x0c.cline.Empty\x12Z\n\x1dupdateApiConfigurationPartial\x12+.cline.UpdateApiConfigurationPartialRequest\x1a\x0c.cline.Empty\x12Q\n\x14refreshGroqModelsRpc\x12\x13.cline.EmptyRequest\x1a$.cline.OpenRouterCompatibleModelInfo\x12T\n\x17refreshBasetenModelsRpc\x12\x13.cline.EmptyRequest\x1a$.cline.OpenRouterCompatibleModelInfo\x12S\n\x12getSapAiCoreModels\x12\x1d.cline.SapAiCoreModelsRequest\x1a\x1e.cline.SapAiCoreModelsResponse\x12G\n\x10refreshOcaModels\x12\x14.cline.StringRequest\x1a\x1d.cline.OcaCompatibleModelInfo\x12N\n\x11getAihubmixModels\x12\x13.cline.EmptyRequest\x1a$.cline.OpenRouterCompatibleModelInfoB3\n\x0f\x62ot.cline.protoP\x01Z\x1egithub.com/cline/grpc-go/clineb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cline.models_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017bot.cline.protoP\001Z\036github.com/cline/grpc-go/cline'
  _globals['_OPENROUTERCOMPATIBLEMODELINFO_MODELSENTRY']._loaded_options = None
  _globals['_OPENROUTERCOMPATIBLEMODELINFO_MODELSENTRY']._serialized_options = b'8\001'
  _globals['_MODELSAPIOPTIONS_OPENAIHEADERSENTRY']._loaded_options = None
  _globals['_MODELSAPIOPTIONS_OPENAIHEADERSENTRY']._serialized_options = b'8\001'
  _globals['_OCACOMPATIBLEMODELINFO_MODELSENTRY']._loaded_options = None
  _globals['_OCACOMPATIBLEMODELINFO_MODELSENTRY']._serialized_options = b'8\001'
  _globals['_MODELSAPICONFIGURATION_OPENAIHEADERSENTRY']._loaded_options = None
  _globals['_MODELSAPICONFIGURATION_OPENAIHEADERSENTRY']._serialized_options = b'8\001'
  _globals['_APIPROVIDER']._serialized_start=26838
  _globals['_APIPROVIDER']._serialized_end=27383
  _globals['_VSCODELMMODELSARRAY']._serialized_start=83
  _globals['_VSCODELMMODELSARRAY']._serialized_end=154
  _globals['_LANGUAGEMODELCHATSELECTOR']._serialized_start=157
  _globals['_LANGUAGEMODELCHATSELECTOR']._serialized_end=306
  _globals['_PRICETIER']._serialized_start=308
  _globals['_PRICETIER']._serialized_end=355
  _globals['_THINKINGCONFIG']._serialized_start=358
  _globals['_THINKINGCONFIG']._serialized_end=504
  _globals['_MODELTIER']._serialized_start=507
  _globals['_MODELTIER']._serialized_end=738
  _globals['_OPENROUTERMODELINFO']._serialized_start=741
  _globals['_OPENROUTERMODELINFO']._serialized_end=1343
  _globals['_OPENROUTERCOMPATIBLEMODELINFO']._serialized_start=1346
  _globals['_OPENROUTERCOMPATIBLEMODELINFO']._serialized_end=1518
  _globals['_OPENROUTERCOMPATIBLEMODELINFO_MODELSENTRY']._serialized_start=1445
  _globals['_OPENROUTERCOMPATIBLEMODELINFO_MODELSENTRY']._serialized_end=1518
  _globals['_OPENAIMODELSREQUEST']._serialized_start=1520
  _globals['_OPENAIMODELSREQUEST']._serialized_end=1611
  _globals['_SAPAICOREMODELSREQUEST']._serialized_start=1614
  _globals['_SAPAICOREMODELSREQUEST']._serialized_end=1776
  _globals['_SAPAICOREMODELDEPLOYMENT']._serialized_start=1778
  _globals['_SAPAICOREMODELDEPLOYMENT']._serialized_end=1847
  _globals['_SAPAICOREMODELSRESPONSE']._serialized_start=1849
  _globals['_SAPAICOREMODELSRESPONSE']._serialized_end=1961
  _globals['_MODELSAPISECRETS']._serialized_start=1964
  _globals['_MODELSAPISECRETS']._serialized_end=4004
  _globals['_MODELSAPIOPTIONS']._serialized_start=4007
  _globals['_MODELSAPIOPTIONS']._serialized_end=12770
  _globals['_MODELSAPIOPTIONS_OPENAIHEADERSENTRY']._serialized_start=9352
  _globals['_MODELSAPIOPTIONS_OPENAIHEADERSENTRY']._serialized_end=9404
  _globals['_UPDATEAPICONFIGURATIONREQUEST']._serialized_start=12772
  _globals['_UPDATEAPICONFIGURATIONREQUEST']._serialized_end=12896
  _globals['_APICONFIGURATION']._serialized_start=12898
  _globals['_APICONFIGURATION']._serialized_end=13000
  _globals['_UPDATEAPICONFIGURATIONREQUESTNEW']._serialized_start=13003
  _globals['_UPDATEAPICONFIGURATIONREQUESTNEW']._serialized_end=13173
  _globals['_UPDATEAPICONFIGURATIONPARTIALREQUEST']._serialized_start=13176
  _globals['_UPDATEAPICONFIGURATIONPARTIALREQUEST']._serialized_end=13356
  _globals['_OCAMODELINFO']._serialized_start=13359
  _globals['_OCAMODELINFO']._serialized_end=14033
  _globals['_OCACOMPATIBLEMODELINFO']._serialized_start=14036
  _globals['_OCACOMPATIBLEMODELINFO']._serialized_end=14217
  _globals['_OCACOMPATIBLEMODELINFO_MODELSENTRY']._serialized_start=14141
  _globals['_OCACOMPATIBLEMODELINFO_MODELSENTRY']._serialized_end=14207
  _globals['_OPENAICOMPATIBLEMODELINFO']._serialized_start=14220
  _globals['_OPENAICOMPATIBLEMODELINFO']._serialized_end=14932
  _globals['_LITELLMMODELINFO']._serialized_start=14935
  _globals['_LITELLMMODELINFO']._serialized_end=15576
  _globals['_MODELSAPICONFIGURATION']._serialized_start=15579
  _globals['_MODELSAPICONFIGURATION']._serialized_end=26835
  _globals['_MODELSAPICONFIGURATION_OPENAIHEADERSENTRY']._serialized_start=9352
  _globals['_MODELSAPICONFIGURATION_OPENAIHEADERSENTRY']._serialized_end=9404
  _globals['_MODELSSERVICE']._serialized_start=27386
  _globals['_MODELSSERVICE']._serialized_end=28762
# @@protoc_insertion_point(module_scope)
