# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cline/web.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'cline/web.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cline_core.proto.cline import common_pb2 as cline_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0f\x63line/web.proto\x12\x05\x63line\x1a\x12\x63line/common.proto\"+\n\nIsImageUrl\x12\x10\n\x08is_image\x18\x01 \x01(\x08\x12\x0b\n\x03url\x18\x02 \x01(\t\"p\n\rOpenGraphData\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\r\n\x05image\x18\x03 \x01(\t\x12\x0b\n\x03url\x18\x04 \x01(\t\x12\x11\n\tsite_name\x18\x05 \x01(\t\x12\x0c\n\x04type\x18\x06 \x01(\t2\xbf\x01\n\nWebService\x12:\n\x0f\x63heckIsImageUrl\x12\x14.cline.StringRequest\x1a\x11.cline.IsImageUrl\x12@\n\x12\x66\x65tchOpenGraphData\x12\x14.cline.StringRequest\x1a\x14.cline.OpenGraphData\x12\x33\n\ropenInBrowser\x12\x14.cline.StringRequest\x1a\x0c.cline.EmptyB3\n\x0f\x62ot.cline.protoP\x01Z\x1egithub.com/cline/grpc-go/clineb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cline.web_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017bot.cline.protoP\001Z\036github.com/cline/grpc-go/cline'
  _globals['_ISIMAGEURL']._serialized_start=46
  _globals['_ISIMAGEURL']._serialized_end=89
  _globals['_OPENGRAPHDATA']._serialized_start=91
  _globals['_OPENGRAPHDATA']._serialized_end=203
  _globals['_WEBSERVICE']._serialized_start=206
  _globals['_WEBSERVICE']._serialized_end=397
# @@protoc_insertion_point(module_scope)
