# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cline/browser.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'cline/browser.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cline_core.proto.cline import common_pb2 as cline_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13\x63line/browser.proto\x12\x05\x63line\x1a\x12\x63line/common.proto\"\\\n\x15\x42rowserConnectionInfo\x12\x14\n\x0cis_connected\x18\x01 \x01(\x08\x12\x11\n\tis_remote\x18\x02 \x01(\x08\x12\x11\n\x04host\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x07\n\x05_host\"Y\n\x11\x42rowserConnection\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x15\n\x08\x65ndpoint\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_endpoint\".\n\nChromePath\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x12\n\nis_bundled\x18\x02 \x01(\x08\")\n\x08Viewport\x12\r\n\x05width\x18\x01 \x01(\x05\x12\x0e\n\x06height\x18\x02 \x01(\x05\"\xcc\x02\n\x0f\x42rowserSettings\x12!\n\x08viewport\x18\x01 \x01(\x0b\x32\x0f.cline.Viewport\x12 \n\x13remote_browser_host\x18\x02 \x01(\tH\x00\x88\x01\x01\x12#\n\x16remote_browser_enabled\x18\x03 \x01(\x08H\x01\x88\x01\x01\x12#\n\x16\x63hrome_executable_path\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x1d\n\x10\x64isable_tool_use\x18\x05 \x01(\x08H\x03\x88\x01\x01\x12\x18\n\x0b\x63ustom_args\x18\x06 \x01(\tH\x04\x88\x01\x01\x42\x16\n\x14_remote_browser_hostB\x19\n\x17_remote_browser_enabledB\x19\n\x17_chrome_executable_pathB\x13\n\x11_disable_tool_useB\x0e\n\x0c_custom_args\"\xfc\x02\n\x1cUpdateBrowserSettingsRequest\x12!\n\x08metadata\x18\x01 \x01(\x0b\x32\x0f.cline.Metadata\x12!\n\x08viewport\x18\x02 \x01(\x0b\x32\x0f.cline.Viewport\x12 \n\x13remote_browser_host\x18\x03 \x01(\tH\x00\x88\x01\x01\x12#\n\x16remote_browser_enabled\x18\x04 \x01(\x08H\x01\x88\x01\x01\x12#\n\x16\x63hrome_executable_path\x18\x05 \x01(\tH\x02\x88\x01\x01\x12\x1d\n\x10\x64isable_tool_use\x18\x06 \x01(\x08H\x03\x88\x01\x01\x12\x18\n\x0b\x63ustom_args\x18\x07 \x01(\tH\x04\x88\x01\x01\x42\x16\n\x14_remote_browser_hostB\x19\n\x17_remote_browser_enabledB\x19\n\x17_chrome_executable_pathB\x13\n\x11_disable_tool_useB\x0e\n\x0c_custom_args2\xea\x02\n\x0e\x42rowserService\x12M\n\x18getBrowserConnectionInfo\x12\x13.cline.EmptyRequest\x1a\x1c.cline.BrowserConnectionInfo\x12G\n\x15testBrowserConnection\x12\x14.cline.StringRequest\x1a\x18.cline.BrowserConnection\x12@\n\x0f\x64iscoverBrowser\x12\x13.cline.EmptyRequest\x1a\x18.cline.BrowserConnection\x12?\n\x15getDetectedChromePath\x12\x13.cline.EmptyRequest\x1a\x11.cline.ChromePath\x12=\n\x17relaunchChromeDebugMode\x12\x13.cline.EmptyRequest\x1a\r.cline.StringB3\n\x0f\x62ot.cline.protoP\x01Z\x1egithub.com/cline/grpc-go/clineb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cline.browser_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017bot.cline.protoP\001Z\036github.com/cline/grpc-go/cline'
  _globals['_BROWSERCONNECTIONINFO']._serialized_start=50
  _globals['_BROWSERCONNECTIONINFO']._serialized_end=142
  _globals['_BROWSERCONNECTION']._serialized_start=144
  _globals['_BROWSERCONNECTION']._serialized_end=233
  _globals['_CHROMEPATH']._serialized_start=235
  _globals['_CHROMEPATH']._serialized_end=281
  _globals['_VIEWPORT']._serialized_start=283
  _globals['_VIEWPORT']._serialized_end=324
  _globals['_BROWSERSETTINGS']._serialized_start=327
  _globals['_BROWSERSETTINGS']._serialized_end=659
  _globals['_UPDATEBROWSERSETTINGSREQUEST']._serialized_start=662
  _globals['_UPDATEBROWSERSETTINGSREQUEST']._serialized_end=1042
  _globals['_BROWSERSERVICE']._serialized_start=1045
  _globals['_BROWSERSERVICE']._serialized_end=1407
# @@protoc_insertion_point(module_scope)
