# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: cline/ui.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'cline/ui.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from cline_core.proto.cline import common_pb2 as cline_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0e\x63line/ui.proto\x12\x05\x63line\x1a\x12\x63line/common.proto\"I\n\x1f\x43onversationHistoryDeletedRange\x12\x13\n\x0bstart_index\x18\x01 \x01(\x05\x12\x11\n\tend_index\x18\x02 \x01(\x05\"\xb2\x01\n\x0c\x43lineSayTool\x12%\n\x04tool\x18\x01 \x01(\x0e\x32\x17.cline.ClineSayToolType\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x0c\n\x04\x64iff\x18\x03 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x04 \x01(\t\x12\r\n\x05regex\x18\x05 \x01(\t\x12\x14\n\x0c\x66ile_pattern\x18\x06 \x01(\t\x12)\n!operation_is_located_in_workspace\x18\x07 \x01(\x08\"_\n\x15\x43lineSayBrowserAction\x12$\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32\x14.cline.BrowserAction\x12\x12\n\ncoordinate\x18\x02 \x01(\t\x12\x0c\n\x04text\x18\x03 \x01(\t\"l\n\x13\x42rowserActionResult\x12\x12\n\nscreenshot\x18\x01 \x01(\t\x12\x0c\n\x04logs\x18\x02 \x01(\t\x12\x13\n\x0b\x63urrent_url\x18\x03 \x01(\t\x12\x1e\n\x16\x63urrent_mouse_position\x18\x04 \x01(\t\"\x89\x01\n\x14\x43lineAskUseMcpServer\x12\x13\n\x0bserver_name\x18\x01 \x01(\t\x12)\n\x04type\x18\x02 \x01(\x0e\x32\x1b.cline.McpServerRequestType\x12\x11\n\ttool_name\x18\x03 \x01(\t\x12\x11\n\targuments\x18\x04 \x01(\t\x12\x0b\n\x03uri\x18\x05 \x01(\t\"L\n\x15\x43linePlanModeResponse\x12\x10\n\x08response\x18\x01 \x01(\t\x12\x0f\n\x07options\x18\x02 \x03(\t\x12\x10\n\x08selected\x18\x03 \x01(\t\"G\n\x10\x43lineAskQuestion\x12\x10\n\x08question\x18\x01 \x01(\t\x12\x0f\n\x07options\x18\x02 \x03(\t\x12\x10\n\x08selected\x18\x03 \x01(\t\"\"\n\x0f\x43lineAskNewTask\x12\x0f\n\x07\x63ontext\x18\x01 \x01(\t\"d\n\x11\x41piReqRetryStatus\x12\x0f\n\x07\x61ttempt\x18\x01 \x01(\x05\x12\x14\n\x0cmax_attempts\x18\x02 \x01(\x05\x12\x11\n\tdelay_sec\x18\x03 \x01(\x05\x12\x15\n\rerror_snippet\x18\x04 \x01(\t\"\x8b\x02\n\x0f\x43lineApiReqInfo\x12\x0f\n\x07request\x18\x01 \x01(\t\x12\x11\n\ttokens_in\x18\x02 \x01(\x05\x12\x12\n\ntokens_out\x18\x03 \x01(\x05\x12\x14\n\x0c\x63\x61\x63he_writes\x18\x04 \x01(\x05\x12\x13\n\x0b\x63\x61\x63he_reads\x18\x05 \x01(\x05\x12\x0c\n\x04\x63ost\x18\x06 \x01(\x01\x12\x35\n\rcancel_reason\x18\x07 \x01(\x0e\x32\x1e.cline.ClineApiReqCancelReason\x12 \n\x18streaming_failed_message\x18\x08 \x01(\t\x12.\n\x0cretry_status\x18\t \x01(\x0b\x32\x18.cline.ApiReqRetryStatus\"\xc9\x06\n\x0c\x43lineMessage\x12\n\n\x02ts\x18\x01 \x01(\x03\x12%\n\x04type\x18\x02 \x01(\x0e\x32\x17.cline.ClineMessageType\x12\x1c\n\x03\x61sk\x18\x03 \x01(\x0e\x32\x0f.cline.ClineAsk\x12\x1c\n\x03say\x18\x04 \x01(\x0e\x32\x0f.cline.ClineSay\x12\x0c\n\x04text\x18\x05 \x01(\t\x12\x11\n\treasoning\x18\x06 \x01(\t\x12\x0e\n\x06images\x18\x07 \x03(\t\x12\r\n\x05\x66iles\x18\x08 \x03(\t\x12\x0f\n\x07partial\x18\t \x01(\x08\x12\x1c\n\x14last_checkpoint_hash\x18\n \x01(\t\x12!\n\x19is_checkpoint_checked_out\x18\x0b \x01(\x08\x12&\n\x1eis_operation_outside_workspace\x18\x0c \x01(\x08\x12\"\n\x1a\x63onversation_history_index\x18\r \x01(\x05\x12R\n\"conversation_history_deleted_range\x18\x0e \x01(\x0b\x32&.cline.ConversationHistoryDeletedRange\x12%\n\x08say_tool\x18\x0f \x01(\x0b\x32\x13.cline.ClineSayTool\x12\x38\n\x12say_browser_action\x18\x10 \x01(\x0b\x32\x1c.cline.ClineSayBrowserAction\x12\x39\n\x15\x62rowser_action_result\x18\x11 \x01(\x0b\x32\x1a.cline.BrowserActionResult\x12\x37\n\x12\x61sk_use_mcp_server\x18\x12 \x01(\x0b\x32\x1b.cline.ClineAskUseMcpServer\x12\x38\n\x12plan_mode_response\x18\x13 \x01(\x0b\x32\x1c.cline.ClinePlanModeResponse\x12-\n\x0c\x61sk_question\x18\x14 \x01(\x0b\x32\x17.cline.ClineAskQuestion\x12,\n\x0c\x61sk_new_task\x18\x15 \x01(\x0b\x32\x16.cline.ClineAskNewTask\x12,\n\x0c\x61pi_req_info\x18\x16 \x01(\x0b\x32\x16.cline.ClineApiReqInfo*$\n\x10\x43lineMessageType\x12\x07\n\x03\x41SK\x10\x00\x12\x07\n\x03SAY\x10\x01*\xbb\x02\n\x08\x43lineAsk\x12\x0c\n\x08\x46OLLOWUP\x10\x00\x12\x15\n\x11PLAN_MODE_RESPOND\x10\x01\x12\x0b\n\x07\x43OMMAND\x10\x02\x12\x12\n\x0e\x43OMMAND_OUTPUT\x10\x03\x12\x15\n\x11\x43OMPLETION_RESULT\x10\x04\x12\x08\n\x04TOOL\x10\x05\x12\x12\n\x0e\x41PI_REQ_FAILED\x10\x06\x12\x0f\n\x0bRESUME_TASK\x10\x07\x12\x19\n\x15RESUME_COMPLETED_TASK\x10\x08\x12\x19\n\x15MISTAKE_LIMIT_REACHED\x10\t\x12\x19\n\x15\x42ROWSER_ACTION_LAUNCH\x10\n\x12\x12\n\x0eUSE_MCP_SERVER\x10\x0b\x12\x0c\n\x08NEW_TASK\x10\x0c\x12\x0c\n\x08\x43ONDENSE\x10\r\x12\x0e\n\nREPORT_BUG\x10\x0e\x12\x12\n\x0eSUMMARIZE_TASK\x10\x0f*\xe8\x04\n\x08\x43lineSay\x12\x08\n\x04TASK\x10\x00\x12\t\n\x05\x45RROR\x10\x01\x12\x13\n\x0f\x41PI_REQ_STARTED\x10\x02\x12\x14\n\x10\x41PI_REQ_FINISHED\x10\x03\x12\x08\n\x04TEXT\x10\x04\x12\r\n\tREASONING\x10\x05\x12\x19\n\x15\x43OMPLETION_RESULT_SAY\x10\x06\x12\x11\n\rUSER_FEEDBACK\x10\x07\x12\x16\n\x12USER_FEEDBACK_DIFF\x10\x08\x12\x13\n\x0f\x41PI_REQ_RETRIED\x10\t\x12\x0f\n\x0b\x43OMMAND_SAY\x10\n\x12\x16\n\x12\x43OMMAND_OUTPUT_SAY\x10\x0b\x12\x0c\n\x08TOOL_SAY\x10\x0c\x12\x1d\n\x19SHELL_INTEGRATION_WARNING\x10\r\x12\x1d\n\x19\x42ROWSER_ACTION_LAUNCH_SAY\x10\x0e\x12\x12\n\x0e\x42ROWSER_ACTION\x10\x0f\x12\x19\n\x15\x42ROWSER_ACTION_RESULT\x10\x10\x12\x1e\n\x1aMCP_SERVER_REQUEST_STARTED\x10\x11\x12\x17\n\x13MCP_SERVER_RESPONSE\x10\x12\x12\x14\n\x10MCP_NOTIFICATION\x10\x13\x12\x16\n\x12USE_MCP_SERVER_SAY\x10\x14\x12\x0e\n\nDIFF_ERROR\x10\x15\x12\x14\n\x10\x44\x45LETED_API_REQS\x10\x16\x12\x15\n\x11\x43LINEIGNORE_ERROR\x10\x17\x12\x16\n\x12\x43HECKPOINT_CREATED\x10\x18\x12\x1a\n\x16LOAD_MCP_DOCUMENTATION\x10\x19\x12\x08\n\x04INFO\x10\x1a\x12\x11\n\rTASK_PROGRESS\x10\x1b\x12\x0f\n\x0b\x45RROR_RETRY\x10\x1c*\xc6\x01\n\x10\x43lineSayToolType\x12\x18\n\x14\x45\x44ITED_EXISTING_FILE\x10\x00\x12\x14\n\x10NEW_FILE_CREATED\x10\x01\x12\r\n\tREAD_FILE\x10\x02\x12\x18\n\x14LIST_FILES_TOP_LEVEL\x10\x03\x12\x18\n\x14LIST_FILES_RECURSIVE\x10\x04\x12\x1e\n\x1aLIST_CODE_DEFINITION_NAMES\x10\x05\x12\x10\n\x0cSEARCH_FILES\x10\x06\x12\r\n\tWEB_FETCH\x10\x07*[\n\rBrowserAction\x12\n\n\x06LAUNCH\x10\x00\x12\t\n\x05\x43LICK\x10\x01\x12\x08\n\x04TYPE\x10\x02\x12\x0f\n\x0bSCROLL_DOWN\x10\x03\x12\r\n\tSCROLL_UP\x10\x04\x12\t\n\x05\x43LOSE\x10\x05*A\n\x14McpServerRequestType\x12\x10\n\x0cUSE_MCP_TOOL\x10\x00\x12\x17\n\x13\x41\x43\x43\x45SS_MCP_RESOURCE\x10\x01*Z\n\x17\x43lineApiReqCancelReason\x12\x14\n\x10STREAMING_FAILED\x10\x00\x12\x12\n\x0eUSER_CANCELLED\x10\x01\x12\x15\n\x11RETRIES_EXHAUSTED\x10\x02\x32\xd8\x08\n\tUiService\x12=\n\x10scrollToSettings\x12\x14.cline.StringRequest\x1a\x13.cline.KeyValuePair\x12\x46\n\x18setTerminalExecutionMode\x12\x15.cline.BooleanRequest\x1a\x13.cline.KeyValuePair\x12<\n\x15onDidShowAnnouncement\x12\x13.cline.EmptyRequest\x1a\x0e.cline.Boolean\x12=\n\x15subscribeToAddToInput\x12\x13.cline.EmptyRequest\x1a\r.cline.String0\x01\x12\x42\n\x1bsubscribeToMcpButtonClicked\x12\x13.cline.EmptyRequest\x1a\x0c.cline.Empty0\x01\x12\x46\n\x1fsubscribeToHistoryButtonClicked\x12\x13.cline.EmptyRequest\x1a\x0c.cline.Empty0\x01\x12\x43\n\x1csubscribeToChatButtonClicked\x12\x13.cline.EmptyRequest\x1a\x0c.cline.Empty0\x01\x12\x46\n\x1fsubscribeToAccountButtonClicked\x12\x13.cline.EmptyRequest\x1a\x0c.cline.Empty0\x01\x12G\n subscribeToSettingsButtonClicked\x12\x13.cline.EmptyRequest\x1a\x0c.cline.Empty0\x01\x12G\n\x19subscribeToPartialMessage\x12\x13.cline.EmptyRequest\x1a\x13.cline.ClineMessage0\x01\x12\x36\n\x11initializeWebview\x12\x13.cline.EmptyRequest\x1a\x0c.cline.Empty\x12\x43\n\x1csubscribeToRelinquishControl\x12\x13.cline.EmptyRequest\x1a\x0c.cline.Empty0\x01\x12@\n\x19subscribeToFocusChatInput\x12\x13.cline.EmptyRequest\x1a\x0c.cline.Empty0\x01\x12\x42\n\x1bsubscribeToDidBecomeVisible\x12\x13.cline.EmptyRequest\x1a\x0c.cline.Empty0\x01\x12\x34\n\x0egetWebviewHtml\x12\x13.cline.EmptyRequest\x1a\r.cline.String\x12-\n\x07openUrl\x12\x14.cline.StringRequest\x1a\x0c.cline.Empty\x12\x34\n\x0fopenWalkthrough\x12\x13.cline.EmptyRequest\x1a\x0c.cline.EmptyB3\n\x0f\x62ot.cline.protoP\x01Z\x1egithub.com/cline/grpc-go/clineb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cline.ui_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\017bot.cline.protoP\001Z\036github.com/cline/grpc-go/cline'
  _globals['_CLINEMESSAGETYPE']._serialized_start=2051
  _globals['_CLINEMESSAGETYPE']._serialized_end=2087
  _globals['_CLINEASK']._serialized_start=2090
  _globals['_CLINEASK']._serialized_end=2405
  _globals['_CLINESAY']._serialized_start=2408
  _globals['_CLINESAY']._serialized_end=3024
  _globals['_CLINESAYTOOLTYPE']._serialized_start=3027
  _globals['_CLINESAYTOOLTYPE']._serialized_end=3225
  _globals['_BROWSERACTION']._serialized_start=3227
  _globals['_BROWSERACTION']._serialized_end=3318
  _globals['_MCPSERVERREQUESTTYPE']._serialized_start=3320
  _globals['_MCPSERVERREQUESTTYPE']._serialized_end=3385
  _globals['_CLINEAPIREQCANCELREASON']._serialized_start=3387
  _globals['_CLINEAPIREQCANCELREASON']._serialized_end=3477
  _globals['_CONVERSATIONHISTORYDELETEDRANGE']._serialized_start=45
  _globals['_CONVERSATIONHISTORYDELETEDRANGE']._serialized_end=118
  _globals['_CLINESAYTOOL']._serialized_start=121
  _globals['_CLINESAYTOOL']._serialized_end=299
  _globals['_CLINESAYBROWSERACTION']._serialized_start=301
  _globals['_CLINESAYBROWSERACTION']._serialized_end=396
  _globals['_BROWSERACTIONRESULT']._serialized_start=398
  _globals['_BROWSERACTIONRESULT']._serialized_end=506
  _globals['_CLINEASKUSEMCPSERVER']._serialized_start=509
  _globals['_CLINEASKUSEMCPSERVER']._serialized_end=646
  _globals['_CLINEPLANMODERESPONSE']._serialized_start=648
  _globals['_CLINEPLANMODERESPONSE']._serialized_end=724
  _globals['_CLINEASKQUESTION']._serialized_start=726
  _globals['_CLINEASKQUESTION']._serialized_end=797
  _globals['_CLINEASKNEWTASK']._serialized_start=799
  _globals['_CLINEASKNEWTASK']._serialized_end=833
  _globals['_APIREQRETRYSTATUS']._serialized_start=835
  _globals['_APIREQRETRYSTATUS']._serialized_end=935
  _globals['_CLINEAPIREQINFO']._serialized_start=938
  _globals['_CLINEAPIREQINFO']._serialized_end=1205
  _globals['_CLINEMESSAGE']._serialized_start=1208
  _globals['_CLINEMESSAGE']._serialized_end=2049
  _globals['_UISERVICE']._serialized_start=3480
  _globals['_UISERVICE']._serialized_end=4592
# @@protoc_insertion_point(module_scope)
